@@ -19,9 +19,8 @@ define('io.ox/calendar/actions',
      'io.ox/core/notifications',
      'io.ox/core/print',
      'settings!io.ox/core',
-     'settings!io.ox/contacts',
      'gettext!io.ox/calendar'
-    ], function (ext, links, api, util, notifications, print, coreSettings, settings, gt) {
+    ], function (ext, links, api, util, notifications, print, coreSettings, gt) {
 
     'use strict';
 
@@ -41,7 +40,7 @@ define('io.ox/calendar/actions',
 
     new Action('io.ox/calendar/actions/switch-to-month-view', {
         requires: function () {
-            return _.device('!small');
+            return true;
         },
         action: function (baton) {
             ox.ui.Perspective.show(baton.app, 'month');
@@ -76,10 +75,10 @@ define('io.ox/calendar/actions',
     new Action('io.ox/calendar/detail/actions/sendmail', {
         capabilities: 'webmail',
         action: function (baton) {
-            util.createArrayOfRecipients(baton.data.participants).done(function (arrayOfRecipients) {
+            util.createRecipientsArray(baton.data.participants).done(function (recipients) {
                 ox.load(['io.ox/mail/write/main']).done(function (m) {
                     m.getApp().launch().done(function () {
-                        this.compose({to: arrayOfRecipients, subject: baton.data.title});
+                        this.compose({to: recipients, subject: baton.data.title});
                     });
                 });
             });
@@ -94,8 +93,7 @@ define('io.ox/calendar/actions',
                     // open create dialog with same participants
                     var data = {
                         folder_id: coreSettings.get('folder/calendar'),
-                        participants: baton.data.participants,
-                        title: baton.data.title
+                        participants: baton.data.participants
                     };
                     this.create(data);
                     this.model.toSync = data;
@@ -107,10 +105,10 @@ define('io.ox/calendar/actions',
     new Action('io.ox/calendar/detail/actions/save-as-distlist', {
         capabilities: 'contacts',
         action: function (baton) {
-            util.createDistlistArrayFromPartisipantList(baton.data.participants).done(function (initdata) {
+            util.createDistlistArray(baton.data.participants).done(function (distlist) {
                 ox.load(['io.ox/contacts/distrib/main']).done(function (m) {
                     m.getApp().launch().done(function () {
-                        this.create(coreSettings.get('folder/contacts'), initdata);
+                        this.create(coreSettings.get('folder/contacts'), { distribution_list: distlist });
                     });
                 });
             });
@@ -120,15 +118,17 @@ define('io.ox/calendar/actions',
     new Action('io.ox/calendar/detail/actions/edit', {
         id: 'edit',
         requires: function (e) {
-            var exists = e.baton && e.baton.data ? e.baton.data.id !== undefined : true;
-            var allowed = e.collection.has('one') && e.collection.has('create');
+            var exists = e.baton && e.baton.data ? e.baton.data.id !== undefined : true,
+                allowed = e.collection.has('one', 'create');
             if (allowed) {
                 //if you have no permission to edit you don't have a folder id (see calendar/freebusy response)
                 if (!e.baton.data.folder_id) {//you need to have a folder id to edit
                     allowed = false;
                 }
             }
-            return allowed && exists;
+            return util.isBossyAppointmentHandling({ app: e.baton.data }).then(function (isBossy) {
+                return allowed && exists && isBossy;
+            });
         },
         action: function (baton) {
             var params = baton.data,
@@ -147,9 +147,9 @@ define('io.ox/calendar/actions',
                             .text(gt('Do you want to edit the whole series or just one appointment within the series?'))
                             .addPrimaryButton('series',
                                 //#. Use singular in this context
-                                gt('Series'))
-                            .addButton('appointment', gt('Appointment'))
-                            .addButton('cancel', gt('Cancel'))
+                                gt('Series'), 'series', {tabIndex: '1'})
+                            .addButton('appointment', gt('Appointment'), 'appointment', {tabIndex: '1'})
+                            .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'})
                             .show()
                             .done(function (action) {
 
@@ -197,7 +197,11 @@ define('io.ox/calendar/actions',
 
     new Action('io.ox/calendar/detail/actions/delete', {
         id: 'delete',
-        requires: 'delete',
+        requires: function (e) {
+            return util.isBossyAppointmentHandling({ app: e.baton.data }).then(function (isBossy) {
+                return e.collection.has('delete') && isBossy;
+            });
+        },
         multiple: function (list) {
 
             var apiCalls = [];
@@ -253,9 +257,9 @@ define('io.ox/calendar/actions',
                         if (hasRec) {
                             new dialogs.ModalDialog()
                                 .text(gt('Do you want to delete the whole series or just one appointment within the series?'))
-                                .addPrimaryButton('appointment', gt('Delete appointment'))
-                                .addPrimaryButton('series', gt('Delete whole series'))
-                                .addButton('cancel', gt('Cancel'))
+                                .addPrimaryButton('appointment', gt('Delete appointment'), 'appointment', {tabIndex: '1'})
+                                .addPrimaryButton('series', gt('Delete whole series'), 'series', {tabIndex: '1'})
+                                .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'})
                                 .show()
                                 .done(function (action) {
                                     if (action === 'cancel') {
@@ -266,8 +270,8 @@ define('io.ox/calendar/actions',
                         } else {
                             new dialogs.ModalDialog()
                                 .text(gt('Do you want to delete this appointment?'))
-                                .addPrimaryButton('ok', gt('Delete'))
-                                .addButton('cancel', gt('Cancel'))
+                                .addPrimaryButton('ok', gt('Delete'), 'ok', {tabIndex: '1'})
+                                .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'})
                                 .show()
                                 .done(function (action) {
                                     if (action === 'cancel') {
@@ -285,7 +289,7 @@ define('io.ox/calendar/actions',
     new Action('io.ox/calendar/detail/actions/create', {
         id: 'create',
         requires: function (e) {
-            return e.collection.has('one') && e.collection.has('create');
+            return e.collection.has('one', 'create');
         },
         action: function (baton, obj) {
             // FIXME: if this action is invoked by the menu button, both
@@ -317,7 +321,9 @@ define('io.ox/calendar/actions',
                     }
                 }
             }
-            return iamUser && e.collection.has('one');
+            return util.isBossyAppointmentHandling({ app: e.baton.data, invert: true }).then(function (isBossy) {
+                return e.collection.has('one') && iamUser && isBossy;
+            });
         },
         action: function (baton) {
             // load & call
@@ -374,7 +380,7 @@ define('io.ox/calendar/actions',
 
             var vGrid = baton.grid || (baton.app && baton.app.getGrid());
 
-            ox.load(['io.ox/core/tk/dialogs', 'io.ox/core/tk/folderviews', 'io.ox/core/api/folder']).done(function (dialogs, views, folderAPI) {
+            ox.load(['io.ox/core/tk/dialogs', 'io.ox/core/tk/folderviews', 'io.ox/core/api/folder', 'settings!io.ox/contacts']).done(function (dialogs, views, folderAPI, contactSettings) {
 
                 function commit(target) {
                     if (type === 'move' && vGrid) vGrid.busy();
@@ -396,22 +402,24 @@ define('io.ox/calendar/actions',
                 } else {
                     var dialog = new dialogs.ModalDialog()
                         .header($('<h4>').text(title))
-                        .addPrimaryButton('ok', gt('Move'))
-                        .addButton('cancel', gt('Cancel'));
+                        .addPrimaryButton('ok', gt('Move'), 'ok', {tabIndex: '1'})
+                        .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
                     dialog.getBody().css('height', '250px');
                     var folderId = String(list[0].folder_id),
-                        id = settings.get('folderpopup/last') || folderId,
+                        id = contactSettings.get('folderpopup/last') || folderId,
                         tree = new views.FolderList(dialog.getBody(), {
                             type: 'calendar',
-                            open: settings.get('folderpopup/open', []),
+                            open: contactSettings.get('folderpopup/open', []),
                             tabindex: 0,
                             toggle: function (open) {
-                                settings.set('folderpopup/open', open).save();
+                                contactSettings.set('folderpopup/open', open).save();
                             },
                             select: function (id) {
-                                settings.set('folderpopup/last', id).save();
-                            }
+                                contactSettings.set('folderpopup/last', id).save();
+                            },
+                            dialogmode: true
                         });
+
                     dialog.show(function () {
                         tree.paint().done(function () {
                             tree.select(id).done(function () {
@@ -437,7 +445,12 @@ define('io.ox/calendar/actions',
 
     new Action('io.ox/calendar/detail/actions/move', {
         id: 'move',
-        requires: 'some delete',
+        requires: function (e) {
+            return util.isBossyAppointmentHandling({ app: e.baton.data }).then(function (isBossy) {
+                var isSeries = e.baton.data.recurrence_type > 0;
+                return e.collection.has('some', 'delete') && isBossy && !isSeries;
+            });
+        },
         multiple: copyMove('move', gt('Move'))
     });
 
@@ -575,6 +588,7 @@ define('io.ox/calendar/actions',
         prio: 'lo',
         id: 'move',
         label: gt('Move'),
+        drawDisabled: true,
         ref: 'io.ox/calendar/detail/actions/move'
     }));
 
