@@ -18,8 +18,9 @@ define('io.ox/calendar/api',
      'settings!io.ox/core',
      'io.ox/core/notifications',
      'io.ox/core/date',
-     'io.ox/core/api/factory'
-    ], function (http, Events, coreConfig, notifications, date, factory) {
+     'io.ox/core/api/factory',
+     'io.ox/core/capabilities'
+    ], function (http, Events, coreConfig, notifications, date, factory, capabilities) {
 
     'use strict';
 
@@ -31,23 +32,6 @@ define('io.ox/calendar/api',
         DAY = HOUR * 24;
     // object to store appointments, that have attachments uploading atm
     var uploadInProgress = {},
-        //grepRemove equivalent
-        grepRemove = function (pattern, cache) {
-            var keys = Object.keys(cache),
-                cache = cache || {};
-
-            if (typeof pattern === 'string') {
-                pattern = new RegExp(_.escapeRegExp(pattern));
-            }
-
-            if (_.isRegExp(pattern)) {
-                _.each(keys, function (key) {
-                    if (pattern.test(key)) {
-                        delete cache[key];
-                    }
-                });
-            }
-        },
 
         checkForNotification = function (obj, removeAction) {
             if (removeAction) {
@@ -221,7 +205,7 @@ define('io.ox/calendar/api',
          * @return {deferred} returns current appointment object
          */
         update: function (o) {
-            var folder_id = o.folder_id || o.folder, pattern,
+            var folder_id = o.folder_id || o.folder,
                 key = folder_id + '.' + o.id + '.' + (o.recurrence_position || 0),
                 attachmentHandlingNeeded = o.tempAttachmentIndicator;
             delete o.tempAttachmentIndicator;
@@ -234,12 +218,14 @@ define('io.ox/calendar/api',
                         action: 'update',
                         id: o.id,
                         folder: folder_id,
-                        timestamp: o.timestamp || _.now(),
+                        timestamp: o.timestamp || _.then(),
                         timezone: 'UTC'
                     },
-                    data: o
+                    data: o,
+                    appendColumns: false
                 })
                 .then(function (obj) {
+                    // check for conflicts
                     if (!_.isUndefined(obj.conflicts)) {
                         return $.Deferred().reject(obj);
                     }
@@ -250,26 +236,21 @@ define('io.ox/calendar/api',
                         id: obj.id || o.id,
                         folder: folder_id
                     };
-                    all_cache = {};
 
-                    if (o.recurrence_position !== null && obj.id === o.id) {
+                    if (o.recurrence_position && o.recurrence_position !== null && obj.id === o.id) {
                         getObj.recurrence_position = o.recurrence_position;
                     }
 
+                    // clear caches
+                    all_cache = {};
                     delete get_cache[key];
+
                     return api.get(getObj)
                         .then(function (data) {
                             if (attachmentHandlingNeeded) {
                                 //to make the detailview show the busy animation
                                 api.addToUploadList(_.ecid(data));
                             }
-                            //series master changed?
-                            if (data.recurrence_type > 0 && !data.recurrence_position) {
-                                //id without specified recurrence_position
-                                pattern = (o.folder || o.folder_id) + '.' + o.id + '.';
-                                grepRemove(pattern, get_cache);
-                                api.trigger('update:series:' + _.ecid(pattern), data);
-                            }
                             api.trigger('update', data);
                             api.trigger('update:' + _.ecid(o), data);
                             return data;
@@ -289,11 +270,16 @@ define('io.ox/calendar/api',
          * @return {deferred}
          */
         attachmentCallback: function (o) {
-            all_cache = {};
-            var key = (o.folder || o.folder_id) + '.' + o.id + '.' + (o.recurrence_position || 0);
-            delete get_cache[key];
-            return api.get(o)
-                .pipe(function (data) {
+            var doCallback = api.uploadInProgress(_.ecid(o));
+
+            // clear caches
+            if (doCallback) {
+                all_cache = {};
+                delete get_cache[_.ecid(o)];
+            }
+
+            return api.get(o, !doCallback)
+                .then(function (data) {
                     api.trigger('update', data);
                     //to make the detailview remove the busy animation
                     api.removeFromUploadList(_.ecid(data));
@@ -316,7 +302,8 @@ define('io.ox/calendar/api',
                     action: 'new',
                     timezone: 'UTC'
                 },
-                data: o
+                data: o,
+                appendColumns: false
             })
             .then(function (obj) {
                 if (!_.isUndefined(obj.conflicts)) {
@@ -331,7 +318,7 @@ define('io.ox/calendar/api',
                 };
                 all_cache = {};
 
-                if (o.recurrence_position !== null) {
+                if (o.recurrence_position && o.recurrence_position !== null) {
                     getObj.recurrence_position = o.recurrence_position;
                 }
 
@@ -358,6 +345,8 @@ define('io.ox/calendar/api',
             // pause http layer
             http.pause();
 
+            api.trigger('beforedelete', o);
+
             _(o).each(function (obj) {
                 keys.push((obj.folder_id || obj.folder) + '.' + obj.id + '.' + (obj.recurrence_position || 0));
                 return http.PUT({
@@ -366,7 +355,8 @@ define('io.ox/calendar/api',
                         action: 'delete',
                         timestamp: _.then()
                     },
-                    data: obj
+                    data: obj,
+                    appendColumns: false
                 })
                 .done(function () {
                     all_cache = {};
@@ -418,7 +408,8 @@ define('io.ox/calendar/api',
                     timestamp: _.now(),
                     timezone: 'UTC'
                 },
-                data: o.data
+                data: o.data,
+                appendColumns: false
             })
             .then(function (resp, timestamp) {
                 if (alarm === -1) return;
@@ -431,8 +422,8 @@ define('io.ox/calendar/api',
             })
             .then(function () {
                 get_cache = {};
-                api.trigger('mark:invite:confirmed', o); //redraw detailview to be responsive and remove invites
                 all_cache = {};
+                api.trigger('mark:invite:confirmed', o); //redraw detailview to be responsive and remove invites
                 delete get_cache[key];
                 return api.get(o).then(function (data) {
                     api.trigger('update', data);
@@ -480,7 +471,7 @@ define('io.ox/calendar/api',
             timestamp: 0,
             recurrence_master: true
         })
-        .pipe(function (list) {
+        .then(function (list) {
             // sort by start_date & look for unconfirmed appointments
             // exclude appointments that already ended
             var invites = _.chain(list)
@@ -527,7 +518,7 @@ define('io.ox/calendar/api',
         });
         // resume & trigger refresh
         return http.resume()
-            .pipe(function (result) {
+            .then(function (result) {
 
                 var def = $.Deferred();
 
@@ -637,7 +628,7 @@ define('io.ox/calendar/api',
             appendColumns: false,
             'continue': true
         })
-        .pipe(function (response) {
+        .then(function (response) {
             return _(result).map(function (obj) {
                 if (_.isString(obj)) {
                     // use fresh server data
@@ -688,14 +679,17 @@ define('io.ox/calendar/api',
      * @return {promise}
      */
     api.refresh = function () {
-        api.getInvites().done(function () {
-            // clear caches
-            all_cache = {};
-            get_cache = {};
-            participant_cache = {};
-            // trigger local refresh
-            api.trigger('refresh.all');
-        });
+        // check capabilities
+        if (capabilities.has('calendar')) {
+            api.getInvites().done(function () {
+                // clear caches
+                all_cache = {};
+                get_cache = {};
+                participant_cache = {};
+                // trigger local refresh
+                api.trigger('refresh.all');
+            });
+        }
     };
 
     ox.on('refresh^', function () {
