@@ -1,30 +1,30 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
-define("io.ox/calendar/edit/recurrence-view",
-    ["io.ox/calendar/model",
-     "io.ox/core/tk/config-sentence",
-     "io.ox/core/date",
-     "gettext!io.ox/calendar/edit/main",
-     "io.ox/core/tk/mobiscroll",
-     "less!io.ox/calendar/edit/style.less"], function (model, ConfigSentence, dateAPI, gt) {
+define('io.ox/calendar/edit/recurrence-view',
+    ['io.ox/calendar/model',
+     'io.ox/core/tk/config-sentence',
+     'io.ox/core/date',
+     'gettext!io.ox/calendar/edit/main',
+     'less!io.ox/calendar/edit/style.less'
+    ], function (model, ConfigSentence, dateAPI, gt) {
 
-    "use strict";
+    'use strict';
 
     var DAYS = model.DAYS,
         RECURRENCE_TYPES = model.RECURRENCE_TYPES;
 
     var CalendarWidgets = {
-        days: function ($anchor, attribute, options) {
+        days: function ($anchor, attribute) {
             var self = this,
                 nodes = {},
                 now = new dateAPI.Local(),
@@ -39,17 +39,17 @@ define("io.ox/calendar/edit/recurrence-view",
                     selectedDays = [];
 
                 _(nodes).each(function (node, day) {
-                    node.find("span").removeClass("icon-ok icon-remove");
+                    node.find('span').removeClass('icon-ok icon-remove');
                     if (value[day]) {
                         selectedDays.push(DAYS.i18n[day]);
-                        node.find("span").addClass("icon-ok");
+                        node.find('span').addClass('icon-ok');
                     } else {
-                        node.find("span").addClass("icon-remove");
+                        node.find('span').addClass('icon-remove');
                     }
                 });
 
-                $anchor.text(selectedDays.join(", ")).focus();
-                self.trigger("redraw", self);
+                $anchor.text(selectedDays.join(', ')).focus();
+                self.trigger('redraw', self);
             }
 
             // Now build the menu
@@ -66,14 +66,14 @@ define("io.ox/calendar/edit/recurrence-view",
                             .attr({ tabindex: $anchor.attr('tabindex') })
                             .text(DAYS.i18n[day])
                             .append('<span class="icon-ok pull-left"></span>')
-                            .on("click", function (e) {
+                            .on('click', function (e) {
                                 e.preventDefault();
                                 var bitmask = self[attribute];
                                 bitmask = bitmask ^ DAYS[day];
                                 if (bitmask) {
                                     self[attribute] = bitmask;
-                                    self.trigger("change", self);
-                                    self.trigger("change:" + attribute, self);
+                                    self.trigger('change', self);
+                                    self.trigger('change:' + attribute, self);
                                     drawState();
                                 }
                                 return false;
@@ -92,14 +92,13 @@ define("io.ox/calendar/edit/recurrence-view",
 
             $anchor.dropdown();
 
-            this.on("change:" + attribute, drawState);
+            this.on('change:' + attribute, drawState);
         },
 
         dateFormat: dateAPI.getFormat(dateAPI.DATE).replace(/\by\b/, 'yyyy').toLowerCase(),
 
         datePicker: function ($anchor, attribute, options) {
-            var self = this,
-                originalContent = $anchor.html();
+            var self = this;
 
             // check options
             if (!options || !options.model) {
@@ -133,7 +132,7 @@ define("io.ox/calendar/edit/recurrence-view",
                 }
                 var value = renderDate();
                 $anchor.text(value).focus();
-                self.trigger("redraw", self);
+                self.trigger('redraw', self);
             }
 
             $anchor.on('click', function (e) {
@@ -143,14 +142,17 @@ define("io.ox/calendar/edit/recurrence-view",
                     }).val(renderDate());
 
                 if (_.device('small')) {
-                    $dateInput.mobiscroll({
-                        preset: 'date',
-                        onSelect: function () {
-                            updateValue();
-                        },
-                        onCancel: function () {
-                            updateValue();
-                        }
+                    require(['io.ox/core/tk/mobiscroll'], function (defaultSettings) {
+                        var now = new dateAPI.Local();
+                        $dateInput.mobiscroll().date($.extend(defaultSettings, {
+                            onSelect: function () {
+                                updateValue();
+                            },
+                            onCancel: function () {
+                                updateValue();
+                            },
+                            minDate: new Date(now.getYear(), now.getMonth(), now.getDate())
+                        })).mobiscroll('show');
                     });
                 } else {
                     $dateInput.datepicker({
@@ -161,14 +163,7 @@ define("io.ox/calendar/edit/recurrence-view",
                         todayHighlight: true,
                         todayBtn: true
                     });
-                }
-
-                $anchor.after($dateInput);
-                $anchor.hide();
-
-                if (_.device('small')) {
-                    $dateInput.mobiscroll('show');
-                } else {
+                    $anchor.after($dateInput).hide();
                     $dateInput.select();
                 }
 
@@ -177,13 +172,13 @@ define("io.ox/calendar/edit/recurrence-view",
                     var value = dateAPI.Local.parse($dateInput.val(), dateAPI.DATE);
                     if (!_.isNull(value) && value.getTime() !== 0) {
                         self[attribute] = dateAPI.Local.localTime(value.getTime());
-                        self.trigger("change", self);
-                        self.trigger("change:" + attribute, self);
+                        self.trigger('change', self);
+                        self.trigger('change:' + attribute, self);
                         drawState();
                     }
                     try {
                         if (_.device('small')) {
-                            // $dateInput.mobiscroll('destroy');
+                            $dateInput.mobiscroll('destroy');
                         } else {
                             $dateInput.datepicker('remove');
                         }
@@ -192,27 +187,27 @@ define("io.ox/calendar/edit/recurrence-view",
                     $anchor.show().focus();
                 }
 
-                $dateInput.on("hide", function (e) {
+                $dateInput.on('hide', function () {
                     updateValue();
                 });
 
                 // Enter
-                $dateInput.on("keydown", function (e) {
+                $dateInput.on('keydown', function (e) {
                     if (e.which === 13) {
                         updateValue();
                     }
                 });
             });
 
-            this.on("change:" + attribute, drawState);
+            this.on('change:' + attribute, drawState);
         }
     };
 
     // Mark a few translations, so the buildsystem picks up on them
-    gt.ngettext("every %1$d day", "every %1$d days", 2);
-    gt.ngettext("every %1$d week", "every %1$d weeks", 2);
-    gt.ngettext("every %1$d month", "every %1$d months", 2);
-    gt.ngettext("after %1$d appointment", 'after %1$d appointments', 2);
+    gt.ngettext('every %1$d day', 'every %1$d days', 2);
+    gt.ngettext('every %1$d week', 'every %1$d weeks', 2);
+    gt.ngettext('every %1$d month', 'every %1$d months', 2);
+    gt.ngettext('after %1$d appointment', 'after %1$d appointments', 2);
 
     var RecurrenceView = function (options) {
         _.extend(this, {
@@ -248,17 +243,17 @@ define("io.ox/calendar/edit/recurrence-view",
 
                 // Config Sentences
                 this.sentences = {
-                    useLinksHint: gt("Click on the links to change the values."),
-                    chooseSentenceHint: gt("Click on a sentence to choose when to repeat the appointment."),
+                    useLinksHint: gt('Click on the links to change the values.'),
+                    chooseSentenceHint: gt('Click on a sentence to choose when to repeat the appointment.'),
                     rectype: new ConfigSentence(gt('The appointment is repeated <a href="#" data-attribute="recurrenceType" data-widget="options">weekly</a>.'), {
                         id: 'recurrenceType',
                         tabindex: self.tabindex,
                         recurrenceType: {
                             options: {
-                                1: gt("daily"),
-                                2: gt("weekly"),
-                                3: gt("monthly"),
-                                4: gt("yearly")
+                                1: gt('daily'),
+                                2: gt('weekly'),
+                                3: gt('monthly'),
+                                4: gt('yearly')
                             },
                             initial: 2
                         },
@@ -271,7 +266,7 @@ define("io.ox/calendar/edit/recurrence-view",
                             if (n === 1) {
                                 //#. as in: The appointment is repeated every day
                                 //#. This is inserted into an HTML construct and is the form without the number
-                                return gt("every day");
+                                return gt('every day');
                             }
 
                             //#. as in: The appointment is repeated every day, or The appointment is repeated every %1$d days.
@@ -293,7 +288,7 @@ define("io.ox/calendar/edit/recurrence-view",
                                 if (n === 1) {
                                     //#. as in: The appointment is repeated every week
                                     //#. This is inserted into an HTML construct and is the form without the number
-                                    return gt("every week");
+                                    return gt('every week');
                                 }
                                 //#. as in: The appointment is repeated every week, or The appointment is repeated every %1$d weeks.
                                 //#. This is inserted into an HTML construct.
@@ -317,7 +312,7 @@ define("io.ox/calendar/edit/recurrence-view",
                                 if (n === 1) {
                                     //#. as in: The appointment is repeated every month
                                     //#. This is inserted into an HTML construct and is the form without the number
-                                    return gt("every month");
+                                    return gt('every month');
                                 }
                                 //#. as in: The appointment is repeated on day 12 every month, or The appointment is repeated on day 12 every %1$d months.
                                 //#. This is inserted into an HTML construct.
@@ -343,35 +338,35 @@ define("io.ox/calendar/edit/recurrence-view",
                         ordinal: {
                             options: {
                                 '-1': //#. As in last monday, tuesday, wednesday ... , day of the week, day of the weekend
-                                    gt("last"),
+                                    gt('last'),
 
                                 1:  //#. As in first monday, tuesday, wednesday ... , day of the week, day of the weekend
-                                    gt("first"),
+                                    gt('first'),
 
                                 2:  //#. As in second monday, tuesday, wednesday ... , day of the week, day of the weekend
-                                    gt("second"),
+                                    gt('second'),
 
                                 3:  //#. As in third monday, tuesday, wednesday ... , day of the week, day of the weekend
-                                    gt("third"),
+                                    gt('third'),
 
                                 4:  //#. As in fourth monday, tuesday, wednesday ... , day of the week, day of the weekend
-                                    gt("fourth")
+                                    gt('fourth')
 
                                 // 5:  //#. As in last monday, tuesday, wednesday ... , day of the week, day of the weekend
-                                //     gt("last")
+                                //     gt('last')
                             }
                         },
                         day: {
                             options: {
-                                1: gt("Sunday"),
-                                2: gt("Monday"),
-                                4: gt("Tuesday"),
-                                8: gt("Wednesday"),
-                                16: gt("Thursday"),
-                                32: gt("Friday"),
-                                64: gt("Saturday"),
-                                62: gt("day of the week"),
-                                65: gt("day of the weekend")
+                                1: gt('Sunday'),
+                                2: gt('Monday'),
+                                4: gt('Tuesday'),
+                                8: gt('Wednesday'),
+                                16: gt('Thursday'),
+                                32: gt('Friday'),
+                                64: gt('Saturday'),
+                                62: gt('day of the week'),
+                                65: gt('day of the weekend')
                             },
                             initial: 2
                         },
@@ -379,7 +374,7 @@ define("io.ox/calendar/edit/recurrence-view",
                             phrase: function (n) {
                                 n = Math.max(1, n);
                                 if (n === 1) {
-                                    return gt("every month");
+                                    return gt('every month');
                                 }
                                 return gt.format(gt.ngettext('every %1$d month', 'every %1$d months', n), n);
                             },
@@ -399,18 +394,18 @@ define("io.ox/calendar/edit/recurrence-view",
                         },
                         month: {
                             options: {
-                                0: gt("January"),
-                                1: gt("February"),
-                                2: gt("March"),
-                                3: gt("April"),
-                                4: gt("May"),
-                                5: gt("June"),
-                                6: gt("July"),
-                                7: gt("August"),
-                                8: gt("September"),
-                                9: gt("October"),
-                                10: gt("November"),
-                                11: gt("December")
+                                0: gt('January'),
+                                1: gt('February'),
+                                2: gt('March'),
+                                3: gt('April'),
+                                4: gt('May'),
+                                5: gt('June'),
+                                6: gt('July'),
+                                7: gt('August'),
+                                8: gt('September'),
+                                9: gt('October'),
+                                10: gt('November'),
+                                11: gt('December')
                             },
                             initial: 2
                         }
@@ -421,45 +416,45 @@ define("io.ox/calendar/edit/recurrence-view",
                         ordinal: {
                             options: {
                                 1:  //#. as in: first week or first Monday
-                                    gt("first"),
+                                    gt('first'),
                                 2:  //#. as in: second week or second Monday
-                                    gt("second"),
+                                    gt('second'),
                                 3:  //#. as in: third week or third Monday
-                                    gt("third"),
+                                    gt('third'),
                                 4:  //#. as in: fourth week or fourth Monday
-                                    gt("fourth"),
+                                    gt('fourth'),
                                 5:  //#. as in: last week or last Monday
-                                    gt("last")
+                                    gt('last')
                             }
                         },
                         day: {
                             options: {
-                                1: gt("Sunday"),
-                                2: gt("Monday"),
-                                4: gt("Tuesday"),
-                                8: gt("Wednesday"),
-                                16: gt("Thursday"),
-                                32: gt("Friday"),
-                                64: gt("Saturday"),
-                                62: gt("day of the week"),
-                                65: gt("day of the weekend")
+                                1: gt('Sunday'),
+                                2: gt('Monday'),
+                                4: gt('Tuesday'),
+                                8: gt('Wednesday'),
+                                16: gt('Thursday'),
+                                32: gt('Friday'),
+                                64: gt('Saturday'),
+                                62: gt('day of the week'),
+                                65: gt('day of the weekend')
                             },
                             initial: 2
                         },
                         month: {
                             options: {
-                                0: gt("January"),
-                                1: gt("February"),
-                                2: gt("March"),
-                                3: gt("April"),
-                                4: gt("May"),
-                                5: gt("June"),
-                                6: gt("July"),
-                                7: gt("August"),
-                                8: gt("September"),
-                                9: gt("October"),
-                                10: gt("November"),
-                                11: gt("December")
+                                0: gt('January'),
+                                1: gt('February'),
+                                2: gt('March'),
+                                3: gt('April'),
+                                4: gt('May'),
+                                5: gt('June'),
+                                6: gt('July'),
+                                7: gt('August'),
+                                8: gt('September'),
+                                9: gt('October'),
+                                10: gt('November'),
+                                11: gt('December')
                             },
                             initial: 2
                         }
@@ -474,7 +469,7 @@ define("io.ox/calendar/edit/recurrence-view",
                         2: gt('ends on a specific date'),
                         3: gt('ends after a certain number of appointments')
                     },
-                    chooseLabel: function (value) {
+                    chooseLabel: function () {
                         return gt('ends');
                     }
                 };
@@ -483,11 +478,11 @@ define("io.ox/calendar/edit/recurrence-view",
                         id: 'never',
                         tabindex: self.tabindex,
                         ending: _.extend({}, endingOptions, {
-                            chooseLabel: function (value) {
+                            chooseLabel: function () {
                                 return gt('never ends');
                             }
                         })
-                    }).on("change:ending", this.endingChanged, this).on("change", this.updateModel, this),
+                    }).on('change:ending', this.endingChanged, this).on('change', this.updateModel, this),
                     date: new ConfigSentence(gt('The series <a href="#" data-attribute="ending" data-widget="options">ends</a> on <a href="#" data-attribute="until" data-widget="custom">11/03/2013</a>.'), {
                         id: 'date',
                         tabindex: self.tabindex,
@@ -498,7 +493,7 @@ define("io.ox/calendar/edit/recurrence-view",
                             //tasks may not have a start date at this point
                             return (self.model.get('start_date') || _.now()) + (4 * dateAPI.WEEK);
                         }
-                    }).on("change:ending", this.endingChanged, this).on("change", this.updateModel, this),
+                    }).on('change:ending', this.endingChanged, this).on('change', this.updateModel, this),
                     after: new ConfigSentence(gt('The series <a href="#" data-attribute="ending" data-widget="options">ends</a> <a href="#" data-attribute="occurrences" data-widget="number">after <span class="number-control">2</span> appointments</a>.'), {
                         id: 'after',
                         tabindex: self.tabindex,
@@ -513,13 +508,13 @@ define("io.ox/calendar/edit/recurrence-view",
                             initial: 3,
                             gt: gt
                         }
-                    }).on("change:ending", this.endingChanged, this).on("change", this.updateModel, this)
+                    }).on('change:ending', this.endingChanged, this).on('change', this.updateModel, this)
                 };
 
                 // Events
-                this.controls.checkbox.on("change", function (e) {
+                this.controls.checkbox.on('change', function (e) {
                     e.preventDefault();
-                    if (self.controls.checkbox.is(":checked")) {
+                    if (self.controls.checkbox.is(':checked')) {
                         if (self.lastConfiguration) {
                             self.model.set(self.lastConfiguration, {validate: true});
                         } else {
@@ -542,17 +537,17 @@ define("io.ox/calendar/edit/recurrence-view",
                 });
 
                 this.nodes.summary.on('click', function (e) {
-                    if (self.controls.checkbox.is(":checked")) {
+                    if (self.controls.checkbox.is(':checked')) {
                         e.preventDefault();
                     }
                     self.toggle();
                 });
 
-                _("recurrence_type days month day_in_month interval occurrences until".split(" ")).each(function (attr) {
-                    self.observeModel("change:" + attr, self.updateView, self);
+                _('recurrence_type days month day_in_month interval occurrences until'.split(' ')).each(function (attr) {
+                    self.observeModel('change:' + attr, self.updateView, self);
                 });
 
-                self.observeModel("change:start_date", self.updateSuggestions, self);
+                self.observeModel('change:start_date', self.updateSuggestions, self);
 
                 this.updateView();
                 this.updateSuggestions();
@@ -571,12 +566,12 @@ define("io.ox/calendar/edit/recurrence-view",
                     type = this.model.get('recurrence_type');
 
                 if (type === RECURRENCE_TYPES.NO_RECURRENCE) {
-                    this.controls.checkbox.removeAttr("checked");
+                    this.controls.checkbox.prop('checked', false);
                 } else {
-                    this.controls.checkbox.attr('checked', 'checked');
+                    this.controls.checkbox.prop('checked', true);
                     this.lastConfiguration = {};
 
-                    _(["recurrence_type", "days", "day_in_month", "interval", "occurrences", "until"]).each(function (attr) {
+                    _(['recurrence_type', 'days', 'day_in_month', 'interval', 'occurrences', 'until']).each(function (attr) {
                         if (self.model.isSet(attr)) {
                             self.lastConfiguration[attr] = self.model.get(attr);
                         }
@@ -597,7 +592,7 @@ define("io.ox/calendar/edit/recurrence-view",
                     case RECURRENCE_TYPES.WEEKLY:
                         this.nodes.alternative1.append(this.sentences.weekly.$el);
                         this.setChoice(this.sentences.weekly);
-                        if (this.model.isSet("interval")) {
+                        if (this.model.isSet('interval')) {
                             this.choice.set('interval', this.model.get('interval'));
                         }
                         if (this.model.isSet('days')) {
@@ -613,23 +608,23 @@ define("io.ox/calendar/edit/recurrence-view",
                             this.createGhost(this.sentences.monthlyDate)
                         );
                         this.setHint(this.sentences.useLinksHint);
-                        if (this.model.isSet("days")) {
+                        if (this.model.isSet('days')) {
                             this.setChoice(this.sentences.monthlyDay);
-                            this.choice.set("ordinal", this.model.get("day_in_month"));
-                            this.choice.set("day", this.model.get("days"));
-                            this.choice.set("interval", this.model.get("interval"));
+                            this.choice.set('ordinal', this.model.get('day_in_month'));
+                            this.choice.set('day', this.model.get('days'));
+                            this.choice.set('interval', this.model.get('interval'));
                             this.nodes.alternative1.children().detach();
                             this.nodes.alternative1.append(this.sentences.monthlyDay.$el);
-                        } else if (this.model.isSet("day_in_month")) {
+                        } else if (this.model.isSet('day_in_month')) {
                             this.setChoice(this.sentences.monthlyDate);
-                            this.choice.set("dayInMonth", this.model.get("day_in_month"));
-                            this.choice.set("interval", this.model.get("interval"));
+                            this.choice.set('dayInMonth', this.model.get('day_in_month'));
+                            this.choice.set('interval', this.model.get('interval'));
                             this.nodes.alternative2.children().detach();
                             this.nodes.alternative2.show().append(this.sentences.monthlyDate.$el);
                         } else {
                             this.setHint(this.sentences.chooseSentenceHint);
-                            this.nodes.alternative1.find(".muted").removeClass("muted");
-                            this.nodes.alternative2.find(".muted").removeClass("muted");
+                            this.nodes.alternative1.find('.muted').removeClass('muted');
+                            this.nodes.alternative2.find('.muted').removeClass('muted');
                             this.setChoice(null);
                         }
                         break;
@@ -641,23 +636,23 @@ define("io.ox/calendar/edit/recurrence-view",
                             this.createGhost(this.sentences.yearlyDate)
                         );
                         this.setHint(this.sentences.useLinksHint);
-                        if (this.model.isSet("days")) {
+                        if (this.model.isSet('days')) {
                             this.setChoice(this.sentences.yearlyDay);
-                            this.choice.set("ordinal", this.model.get("day_in_month"));
-                            this.choice.set("day", this.model.get("days"));
-                            this.choice.set("month", this.model.get("month"));
+                            this.choice.set('ordinal', this.model.get('day_in_month'));
+                            this.choice.set('day', this.model.get('days'));
+                            this.choice.set('month', this.model.get('month'));
                             this.nodes.alternative1.children().detach();
                             this.nodes.alternative1.append(this.sentences.yearlyDay.$el);
-                        } else if (this.model.isSet("day_in_month")) {
+                        } else if (this.model.isSet('day_in_month')) {
                             this.setChoice(this.sentences.yearlyDate);
-                            this.choice.set("month", this.model.get("month"));
-                            this.choice.set("dayInMonth", this.model.get("day_in_month"));
+                            this.choice.set('month', this.model.get('month'));
+                            this.choice.set('dayInMonth', this.model.get('day_in_month'));
                             this.nodes.alternative2.children().detach();
                             this.nodes.alternative2.show().append(this.sentences.yearlyDate.$el);
                         } else {
                             this.setHint(this.sentences.chooseSentenceHint);
-                            this.nodes.alternative1.find(".muted").removeClass("muted");
-                            this.nodes.alternative2.find(".muted").removeClass("muted");
+                            this.nodes.alternative1.find('.muted').removeClass('muted');
+                            this.nodes.alternative2.find('.muted').removeClass('muted');
                             this.setChoice(null);
                         }
                         break;
@@ -666,11 +661,11 @@ define("io.ox/calendar/edit/recurrence-view",
                     this.nodes.endsChoice.children().detach();
                     if (this.model.get('occurrences')) {
                         this.nodes.endsChoice.append(this.ends.after.$el);
-                        this.ends.after.set('occurrences', this.model.get("occurrences"));
+                        this.ends.after.set('occurrences', this.model.get('occurrences'));
                         this.endsChoice = this.ends.after;
                     } else if (this.model.get('until')) {
                         this.nodes.endsChoice.append(this.ends.date.$el);
-                        this.ends.date.set("until", this.model.get("until"));
+                        this.ends.date.set('until', this.model.get('until'));
                         this.endsChoice = this.ends.date;
                     } else {
                         this.nodes.endsChoice.append(this.ends.never.$el);
@@ -686,7 +681,7 @@ define("io.ox/calendar/edit/recurrence-view",
                 this.nodes.summary
                     .empty()
                     .append(
-                        $("<span>&nbsp;</span>"),
+                        $('<span>&nbsp;</span>'),
                         sum = $('<a href="#" tabindex="' + this.tabindex + '">')
                             .css('fontSize', 'small')
                     );
@@ -694,8 +689,8 @@ define("io.ox/calendar/edit/recurrence-view",
                     this.controls.checkboxLabel.css('display', 'inline-block');
                     sum.append(
                         this.choice.ghost(),
-                        (this.choice && this.choice.id === "no-choice") ? $() : this.endsChoice.ghost(),
-                        $("<span>&nbsp;</span>")
+                        (this.choice && this.choice.id === 'no-choice') ? $() : this.endsChoice.ghost(),
+                        $('<span>&nbsp;</span>')
                     );
                 } else {
                     this.controls.checkboxLabel.css('display', 'block');
@@ -715,7 +710,7 @@ define("io.ox/calendar/edit/recurrence-view",
                 this.model.unset('occurrences');
                 this.model.unset('until');
 
-                if (this.controls.checkbox.is(":checked")) {
+                if (this.controls.checkbox.is(':checked')) {
                     var recType = parseInt(this.sentences.rectype.recurrenceType, 10);
 
                     switch (recType) {
@@ -738,7 +733,7 @@ define("io.ox/calendar/edit/recurrence-view",
                         var monthly =  {
                             recurrence_type: recType
                         };
-                        if (this.choice.id === "monthlyDate") {
+                        if (this.choice.id === 'monthlyDate') {
                             _.extend(monthly, {
                                 recurrence_type: recType,
                                 day_in_month: this.choice.dayInMonth,
@@ -758,7 +753,7 @@ define("io.ox/calendar/edit/recurrence-view",
                         var yearly =  {
                             recurrence_type: recType
                         };
-                        if (this.choice.id === "yearlyDate") {
+                        if (this.choice.id === 'yearlyDate') {
                             _.extend(yearly, {
                                 day_in_month: this.choice.dayInMonth,
                                 month: this.choice.month,
@@ -782,19 +777,19 @@ define("io.ox/calendar/edit/recurrence-view",
 
                     if (this.endsChoice) {
                         switch (this.endsChoice.id) {
-                        case "never":
+                        case 'never':
                             // remove this when backend bug 24870 is fixed
                             this.model.set({
                                 until: null
                             }, {validate: true});
                             // ----
                             break;
-                        case "date":
+                        case 'date':
                             this.model.set({
                                 until: this.endsChoice.until
                             }, {validate: true});
                             break;
-                        case "after":
+                        case 'after':
                             if (this.endsChoice.occurrences <= 0) {
                                 this.endsChoice.occurrences = 1;
                             }
@@ -827,14 +822,14 @@ define("io.ox/calendar/edit/recurrence-view",
                     .css({cursor: 'pointer'});
             },
             endingChanged: function (sentence) {
-                switch (sentence.ending + "") {
-                case "1":
+                switch (sentence.ending + '') {
+                case '1':
                     this.endsChoice = this.ends.never;
                     break;
-                case "2":
+                case '2':
                     this.endsChoice = this.ends.date;
                     break;
-                case "3":
+                case '3':
                     this.endsChoice = this.ends.after;
                     break;
                 }
@@ -848,7 +843,7 @@ define("io.ox/calendar/edit/recurrence-view",
                     this.choice = {
                         id: 'no-choice',
                         ghost: function () {
-                            return $('<span>').text(gt("Please choose a sentence below."));
+                            return $('<span>').text(gt('Please choose a sentence below.'));
                         },
                         on: $.noop,
                         off: $.noop
@@ -856,7 +851,7 @@ define("io.ox/calendar/edit/recurrence-view",
                     return;
                 }
                 this.choice = sentence;
-                this.choice.on("change", this.updateModel, this);
+                this.choice.on('change', this.updateModel, this);
             },
             showMore: function () {
                 this.more = true;
@@ -871,7 +866,7 @@ define("io.ox/calendar/edit/recurrence-view",
                 $('a:first', this.nodes.summary).focus();
             },
             toggle: function () {
-                if (this.controls.checkbox.is(":checked")) {
+                if (this.controls.checkbox.is(':checked')) {
                     if (this.more) {
                         this.showLess();
                     } else {
@@ -880,11 +875,11 @@ define("io.ox/calendar/edit/recurrence-view",
                 }
             },
             updateSuggestions: function () {
-                if (!this.model.get("start_date")) {
+                if (!this.model.get('start_date')) {
                     return;
                 }
                 var self = this,
-                    startDate = new dateAPI.Local(dateAPI.Local.utc(this.model.get("start_date"))),
+                    startDate = new dateAPI.Local(dateAPI.Local.utc(this.model.get('start_date'))),
                     dayBits = 1 << startDate.getDay(),
                     dayInMonth = startDate.getDate(),
                     month = startDate.getMonth(),
@@ -969,7 +964,7 @@ define("io.ox/calendar/edit/recurrence-view",
                         $('<div class="row-fluid">').append(
                             this.controls.checkboxLabel.append(
                                 this.controls.checkbox,
-                                $.txt(gt("Repeat"))
+                                $.txt(gt('Repeat'))
                             ),
                             this.nodes.summary
                         ),
