@@ -212,7 +212,7 @@ define('io.ox/calendar/edit/template',
         index: 700,
         className: 'span12',
         labelClassName: 'control-label desc',
-        control: '<textarea class="note">',
+        control: '<textarea class="note input-block-level">',
         attribute: 'note',
         label: gt('Description')
     }));
@@ -418,7 +418,7 @@ define('io.ox/calendar/edit/template',
         id: 'notify',
         labelClassName: 'control-label desc',
         //headerClassName: 'control-label desc',
-        className: 'span6',
+        className: 'span5 offset1',
         //header: gt('Notify all participants via email.'),
         label: gt('Notify all participants by email.'),
         attribute: 'notification',
