@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
@@ -12,7 +13,8 @@
 
 define('io.ox/calendar/freebusy/templates',
     ['io.ox/core/notifications',
-     'gettext!io.ox/calendar/freebusy'], function (notifications, gt) {
+     'gettext!io.ox/calendar/freebusy'
+    ], function (notifications, gt) {
 
     'use strict';
 
@@ -67,7 +69,7 @@ define('io.ox/calendar/freebusy/templates',
 
         getIntervalDropdown: function () {
             return $('<div class="view-dropdown dropdown pull-right">').append(
-                $('<a class="dropdown-toggle" data-toggle="dropdown" href="#" tabindex="4">').text(gt('Change view')),
+                $('<a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" tabindex="4">').text(gt('Change view')),
                 $.txt(' '), $('<b class="caret">'),
                 $('<ul class="dropdown-menu dropdown-right" role="menu">').append(
                     $('<li>').append($('<a role="menuitem" href="#" data-action="day">').text(gt('Day'))),
