@@ -137,9 +137,12 @@ define('io.ox/calendar/view-detail',
             isPerson = hash[key] || obj.folder_id,
             personClass = isPerson ? 'person' : '',
             display_name, name, node, name_lc,
+            comment = conf.comment || conf.message || '',
             mail_lc = String(obj.mail || obj.mailaddress || '').toLowerCase();
         // external participant?
         if (obj.type === 5) {
+            //remove id or we get autogenerated data instead of address book data in the halo view
+            delete obj.id;
             // beautify
             name_lc = String(obj.display_name).toLowerCase();
             if (name_lc === mail_lc) {
@@ -158,7 +161,7 @@ define('io.ox/calendar/view-detail',
             .append($('<span>').addClass('status ' + statusClass).html(' ' + confirm))
             .data(_.extend(obj, { display_name: display_name, email1: mail_lc }));
         // has confirmation comment?
-        if (conf.comment !== '') {
+        if (comment !== '') {
             node.append($('<span>').addClass('comment').text(gt.noI18n(conf.comment)));
         }
         return node;
@@ -364,7 +367,7 @@ define('io.ox/calendar/view-detail',
             this.append(
                 $('<span>')
                     .addClass('detail-label')
-                    .append($.txt(gt('Show as')), $.txt(gt.noI18n(':\u00A0'))),
+                    .append($.txt(gt('Shown as')), $.txt(gt.noI18n(':\u00A0'))),
                 $('<span>')
                     .addClass('detail shown_as ' + util.getShownAsClass(baton.data))
                     .text(gt.noI18n('\u00A0')),
