@@ -161,8 +161,10 @@ define('io.ox/contacts/actions',
                                 },
                                 select: function (id) {
                                     settings.set('folderpopup/last', id).save();
-                                }
+                                },
+                                dialogmode: true
                             });
+
                         dialog.show(function () {
                             tree.paint().done(function () {
                                 tree.select(id).done(function () {
@@ -278,7 +280,12 @@ define('io.ox/contacts/actions',
 
     new Action('io.ox/contacts/actions/print', {
         requires: function (e) {
-            return e.collection.has('some', 'read') && _.device('!small') && !e.context.mark_as_distributionlist;
+            if (_.device('small')) return false;
+            // check if collection has min 1 contact
+            return e.collection.has('some', 'read') &&
+                (settings.get('features/printList') === 'list' || (_.filter([].concat(e.context), function (el) {
+                    return !el.mark_as_distributionlist;
+                })).length > 0);
         },
         multiple: function (list) {
             print.request('io.ox/contacts/print', list);
@@ -551,7 +558,7 @@ define('io.ox/contacts/actions',
                      'io.ox/preview/main',
                      'io.ox/core/api/attachment'], function (dialogs, p, attachmentAPI) {
                 //build Sidepopup
-                new dialogs.SidePopup().show(baton.e, function (popup) {
+                new dialogs.SidePopup({ tabTrap: true }).show(baton.e, function (popup) {
                     _(list).each(function (data) {
                         data.dataURL = attachmentAPI.getUrl(data, 'view');
                         var pre = new p.Preview(data, {
@@ -576,7 +583,7 @@ define('io.ox/contacts/actions',
 
     new Action('io.ox/contacts/actions/open-attachment', {
         id: 'open',
-        requires: 'some',
+        requires: 'one',
         multiple: function (list) {
             require(['io.ox/core/api/attachment'], function (attachmentAPI) {
                 _(list).each(function (data) {
@@ -805,7 +812,7 @@ define('io.ox/contacts/actions',
     ext.point('io.ox/contacts/attachment/links').extend(new links.Link({
         id: 'save',
         index: 400,
-        label: gt('Save in file store'),
+        label: gt('Save to drive'),
         ref: 'io.ox/contacts/actions/save-attachment'
     }));
 });
