@@ -17,10 +17,11 @@ define('io.ox/contacts/api',
      'io.ox/core/api/factory',
      'io.ox/core/notifications',
      'io.ox/core/cache',
+     'io.ox/core/api/user',
      'io.ox/contacts/util',
      'l10n/ja_JP/io.ox/collation',
      'settings!io.ox/contacts'
-    ], function (ext, http, apiFactory, notifications, cache, util, collation, settings) {
+    ], function (ext, http, apiFactory, notifications, cache, userApi, util, collation, settings) {
 
     'use strict';
 
@@ -51,12 +52,12 @@ define('io.ox/contacts/api',
                 sort: '607', // 607 = magic field
                 order: 'asc',
                 admin: function () {
-                    return settings.get('showAdmin');
+                    return settings.get('showAdmin', false);
                 }
             },
             list: {
                 action: 'list',
-                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607',
+                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607,5',
                 extendColumns: 'io.ox/contacts/api/list'
             },
             get: {
@@ -72,6 +73,7 @@ define('io.ox/contacts/api',
                     query = query + '*';
                     var data = {
                         orSearch: true,
+                        admin: settings.get('showAdmin', false),
                         emailAutoComplete: !!opt.emailAutoComplete
                     },
                     defaultBehaviour = true,
@@ -144,9 +146,9 @@ define('io.ox/contacts/api',
                 columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607',
                 extendColumns: 'io.ox/contacts/api/list',
                 sort: '607', // magic sort field - ignores asc/desc
-                getData: function (query, opt) {
+                getData: function (originalQuery, opt) {
                     var queryFields = {
-                            names: ('display_name first_name last_name yomiFirstName yomiLastName company yomiCompany ' +
+                            names: ('display_name first_name last_name yomiFirstName yomiLastName company department yomiCompany ' +
                             'email1 email2 email3').split(' '),
                             addresses: ('street_home postal_code_home city_home state_home country_home ' +
                             'street_business postal_code_business city_business state_business country_business ' +
@@ -159,18 +161,23 @@ define('io.ox/contacts/api',
                         },
                         filter = ['or'],
                         data,
-                        defaultBehaviour = true;
+                        defaultBehaviour = true,
+                        includes_display_name = false,
+                        words = [],
+                        query = '';
 
                     opt = opt || {};
-                    //add wildcards to front and back if none is specified
-                    if ((query.indexOf('*') + query.indexOf('?')) < -1) {
-                        query = '*' + query + '*';
+
+                    // add wildcards to front and back if none is specified
+                    if ((originalQuery.indexOf('*') + originalQuery.indexOf('?')) < -1) {
+                        query = '*' + originalQuery + '*';
                     }
 
                     _(opt).each(function (value, key) {
                         if (_(queryFields).chain().keys().contains(key).value() && value === 'on') {
                             _(queryFields[key]).each(function (name) {
-                                filter.push(['=', {'field': name}, query]);
+                                filter.push(['=', { 'field': name }, query]);
+                                if (name === 'display_name') includes_display_name = true;
                             });
                             defaultBehaviour = false;
                         }
@@ -181,9 +188,21 @@ define('io.ox/contacts/api',
                             filter.push(['=', {'field': name}, query]);
                         });
                     }
+
+                    // client-side display_name fix
+                    if (originalQuery.indexOf('*') === -1 && includes_display_name) {
+                        words = String(originalQuery).trim().split(/\s+/);
+                        if (words.length > 1) {
+                            filter.push(
+                                ['and'].concat(_(words).map(function (word) {
+                                    return ['=', { 'field': 'display_name' }, '*' + word + '*'];
+                                }))
+                            );
+                        }
+                    }
+
                     data = { 'filter': filter };
-                    ext.point('io.ox/contacts/api/search')
-                        .invoke('getData', data, query, opt);
+                    ext.point('io.ox/contacts/api/search').invoke('getData', data, query, opt);
                     return data;
                 }
             }
@@ -206,10 +225,30 @@ define('io.ox/contacts/api',
                     response = response.slice(count).concat(response.slice(0, count));
                 }
                 return response;
+            },
+            listPost: function (data) {
+                _(data).each(function (obj) {
+                    // remove from cache if get cache is outdated
+                    api.caches.get.dedust(obj, 'last_modified');
+                });
+                api.trigger('list:ready');
+                return data;
             }
         }
     });
 
+    /**
+    * clear userapi cache
+    * @returns defered
+    */
+    function clearUserApiCache(data) {
+        return $.when(
+            userApi.caches.get.remove({ id: data.user_id }),
+            userApi.caches.all.clear(),
+            userApi.caches.list.remove({ id: data.user_id })
+        );
+    }
+
     /**
      * fix backend WAT
      * @param  {object} data
@@ -305,7 +344,7 @@ define('io.ox/contacts/api',
 
         if (_.isEmpty(o.data)) {
             if (attachmentHandlingNeeded) {
-                return $.when().pipe(function () {
+                return $.when().then(function () {
                     api.addToUploadList(_.ecid(o));//to make the detailview show the busy animation
                     api.trigger('update:' + _.ecid(o));
                     return { folder_id: o.folder, id: o.id };
@@ -334,7 +373,8 @@ define('io.ox/contacts/api',
                         api.caches.get.add(data),
                         api.caches.all.grepRemove(o.folder + api.DELIM),
                         api.caches.list.remove({ id: o.id, folder: o.folder }),
-                        fetchCache.clear()
+                        fetchCache.clear(),
+                        data.user_id ? clearUserApiCache(data) : ''
                     )
                     .done(function () {
                         if (attachmentHandlingNeeded) {
@@ -368,7 +408,7 @@ define('io.ox/contacts/api',
                 api.caches.list.clear(),
                 fetchCache.clear()
             )
-            .pipe(function () {
+            .then(function () {
                 api.trigger('refresh.list');
                 api.trigger('update:image', { // TODO needs a switch for created by hand or by test
                     id: o.id,
@@ -390,7 +430,7 @@ define('io.ox/contacts/api',
                 data: form,
                 fixPost: true
             })
-            .pipe(filter);
+            .then(filter);
         } else {
             return http.FORM({
                 module: 'contacts',
@@ -399,7 +439,7 @@ define('io.ox/contacts/api',
                 data: changes,
                 params: {id: o.id, folder: o.folder_id, timestamp: _.then() }
             })
-            .pipe(filter);
+            .then(filter);
         }
     };
 
@@ -424,7 +464,7 @@ define('io.ox/contacts/api',
                     return { folder: data.folder_id, id: data.id };
                 })
             })
-            .pipe(function () {
+            .then(function () {
                 return $.when(
                     api.caches.all.clear(),
                     api.caches.list.remove(list),
@@ -477,6 +517,7 @@ define('io.ox/contacts/api',
                 module: 'contacts',
                 params: {
                     action: 'search',
+                    admin: settings.get('showAdmin', false),
                     columns: '20,1,500,501,502,505,520,555,556,557,569,602,606,524,592',
                     timezone: 'UTC'
                 },
@@ -522,210 +563,87 @@ define('io.ox/contacts/api',
         });
     };
 
-    /**
-    * get contact redced/filtered contact data; manages caching
-    * @param  {string} phone (phonenumber)
-    * @return {deferred} returns exactyl one contact object
-    */
-    //api.getByPhone = function (phone) {
-    // phone = phone || '';
-    // return fetchCache.get(phone).pipe(function (data) {
-    //     if (data !== null) {
-    //         return data;
-    //     } else if (phone === '') {
-    //         return {};
-    //     } else {
-    //         //search in all msisdn supported fields
-    //         var filter = _.map(api.getMapping('msisdn', 'names'), function (column) {
-    //             return [].concat(['=', { 'field': column }, phone ]);
-    //         });
-    //         if (!filter.length) {
-    //             return fetchCache.add(phone, {});
-    //         }
-    //         //server request
-    //         return http.PUT({
-    //             module: 'contacts',
-    //             params: {
-    //                 action: 'advancedSearch',
-    //                 columns: '20,1,500,501,502,505,520,555,556,557,569,602,606,524,592',
-    //                 timezone: 'UTC'
-    //             },
-    //             sort: 609,
-    //             data: {
-    //                 'filter': [
-    //                     'or'
-    //                 ].concat(filter)
-    //             }
-    //         }).pipe(function (data) {
-    //             //TODO: use smarter server request instead
-    //             if (data.length) {
-    //                 // favor contacts with an image
-    //                 data.sort(function (a, b) {
-    //                     return !!b.image1_url ? +1 : -1;
-    //                 });
-    //                 // favor contacts in global address book
-    //                 data.sort(function (a, b) {
-    //                     return b.folder_id === '6' ? +1 : -1;
-    //                 });
-    //                 // remove host
-    //                 if (data[0].image1_url) {
-    //                     data[0].image1_url = data[0].image1_url
-    //                         .replace(/^https?\:\/\/[^\/]+/i, '')
-    //                         .replace(/^\/ajax/, ox.apiRoot);
-    //                 }
-    //                 // use first contact
-    //                 return fetchCache.add(phone, {
-    //                     image1_url: data[0].image1_url,
-    //                     display_name: data[0].display_name,
-    //                     internal_userid: data[0].internal_userid,
-    //                     email1: data[0].email1
-    //                 });
-    //             } else {
-    //                 // no data found
-    //                 return fetchCache.add(phone, {});
-    //             }
-    //         });
-    //     }
-    // });
-    //};
+    // node is optional. if missing function returns just the URL
+    api.pictureHalo = function (/* [node], options */) {
 
-    /**
-     * TODO: dirty copy/paste hack until I know hat fetchCache is good for
-     * @param  {object} obj
-     * @param  {object} options
-     * @return {string} url
-     */
-    api.getPictureURLSync = function (obj, options) {
-
-        var defaultUrl = ox.base + '/apps/themes/default/dummypicture.png';
-        if (!_.isObject(obj)) { return defaultUrl; }
+        var args = _(arguments).toArray(), node, options, params, fallback, url, img;
+        // use copy of data object because of delete-statements
+        if (args.length === 1) {
+            options = _.clone(args[0]);
+        } else {
+            node = args[0];
+            options = _.clone(args[1]);
+        }
 
         // duck checks
-        if (api.looksLikeResource(obj)) {
-            return ox.base + '/apps/themes/default/dummypicture_resource.png';
-        } else if (api.looksLikeDistributionList(obj)) {
-            return ox.base + '/apps/themes/default/dummypicture_group.png';
-        } else if (obj.image1_url) {
-            return obj.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param(options || {});
+        if (api.looksLikeResource(options)) {
+            url = ox.base + '/apps/themes/default/dummypicture_resource.png';
+        }
+        else if (api.looksLikeGroup(options) || api.looksLikeDistributionList(options)) {
+            url = ox.base + '/apps/themes/default/dummypicture_group.png';
+        }
+        else if (_.isString(options.image1_url) && options.image1_url !== '') {
+            params = $.param($.extend({}, {
+                // scale
+                width: options.width,
+                height: options.height,
+                scaleType: options.scaleType
+            }));
+            url = options.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param(params);
+        }
+
+        // already done?
+        if (url) return node ? node.css('background-image', 'url(' + url + ')') : url;
+
+        // preference; internal_userid must not be undefined, null, or zero
+        if (options.internal_userid || options.userid || options.user_id) {
+            delete options.contact_id;
+            delete options.folder_id;
+            delete options.folder;
+            delete options.id;
         } else {
-            return defaultUrl;
+            delete options.internal_userid;
+            delete options.userid;
+            delete options.user_id;
         }
-    };
 
-    /**
-    * gets deferred for fetching picture url
-    * @param  {string|object} obj (emailaddress or data object)
-    * @param  {object} options (height, width, scaleType)
-    * @fires  api#fail
-    * @return {deferred}
-    */
-    api.getPictureURL = function (obj, options) {
-        var deferred = $.Deferred(),
-            defaultUrl = ox.base + '/apps/themes/default/dummypicture.png',
-            id,
-            fail = function () {
-                api.trigger('fail');
-                deferred.resolve(defaultUrl);
-            },
-            success = function (data) {
-                //do not set data.image1_url (would also update cached object)
-                var url = data.image1_url ? data.image1_url + '&' + $.param($.extend({}, options)) : defaultUrl;
-                deferred.resolve(url);
-            };
+        // empty extend trick to restrict to non-undefined values
+        params = $.extend({}, {
+            // identifier
+            email: options.email && String(options.email).toLowerCase() || options.mail && String(options.mail).toLowerCase() || options.email1 && String(options.email1).toLowerCase(),
+            folder: options.folder_id || options.folder,
+            id: options.contact_id || options.id,
+            internal_userid: options.internal_userid || options.userid || options.user_id,
+            // scale
+            width: options.width,
+            height: options.height,
+            scaleType: options.scaleType
+        });
+        // remove options
+        options = null;
 
-        // param empty/null
-        if ((typeof obj === 'string' && obj === '') || (typeof obj === 'object' && obj === null)) {
-            return deferred.resolve(defaultUrl);
-        }
-        // normalize
-        if (typeof obj === 'string') {
-            if (/\@/.test(obj))
-                obj = { email: obj };
-            else
-                return deferred.resolve(defaultUrl);
-        }
-        if (!_.isUndefined(obj.image1_url) && !_.isEmpty(obj.image1_url)) {
-            return deferred.resolve(obj.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param($.extend({}, options)));
-        }
-        if (obj.id || obj.contact_id) {
-            // duck checks
-            if (api.looksLikeResource(obj)) {
-                defaultUrl = ox.base + '/apps/themes/default/dummypicture_resource.png';
-            } else if (api.looksLikeDistributionList(obj)) {
-                defaultUrl = ox.base + '/apps/themes/default/dummypicture_group.png';
+        // remove empty values
+        for (var k in params) {
+            if (params.hasOwnProperty(k) && !params[k]) {
+                delete params[k];
             }
-            // also look for contact_id to support user objects directly
-            var id = obj.contact_id || obj.id,
-                folder = obj.folder_id || obj.folder,
-                key = folder + '|' + id;
-            if (id && folder) { // need both; folder might be null/0 if from halo view
-                fetchCache.get(key).pipe(function (url) {
-                    if (url) {
-                        deferred.resolve(url);
-                    } else {
-                        api.get({ id: id, folder: folder }).then(
-                            function (data) {
-                                var url;
-                                if (data.image1_url) {
-                                    url = data.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param($.extend({}, options));
-                                    fetchCache.add(key, url);
-                                    deferred.resolve(url);
-                                } else {
-                                    fetchCache.add(key, defaultUrl);
-                                    fail();
-                                }
-                            },
-                            fail
-                        );
-                    }
-                });
-            } else {
-                fail();
-            }
-        } else if (obj.email) {
-            api.getByEmailadress(obj.email).done(success).fail(fail);
-        //} else if (obj.phone) {
-        //    api.getByPhone(obj.phone).done(success).fail(fail);
-        } else {
-            fail();
         }
 
-        return deferred;
-    };
+        fallback = ox.base + '/apps/themes/default/dummypicture.png';
+        url = ox.apiRoot + '/halo/contact/picture?' + $.param(params);
+
+        // just return URL
+        if (!node) return url;
+
+        // load image and return node
+        img = new Image();
+        $(img).one('load error', function (e) {
+            var fail = img.width === 1 || e.type === 'error';
+            node.css('background-image', 'url(' + (fail ? fallback : url) + ')');
+            node = img = null;
+        });
+        img.src = url;
 
-    /**
-    * get div node with callbacks managing fetching/updating
-    * @param  {string|object} obj (emailaddress)
-    * @param  {object} options (height, with, scaleType)
-    * @return {object} div node with callbacks
-    */
-    api.getPicture = function (obj, options) {
-        var node, set, clear, cont;
-        node = $('<div>');
-        set = function (e) {
-            node.css('backgroundImage', 'url(' + e.data.url + ')');
-            if (/dummypicture\.png$/.test(e.data.url)) {
-                node.addClass('default-picture');
-            }
-            clear();
-        };
-        clear = function () {
-            _.defer(function () { // use defer! otherwise we return null on cache hit
-                node = set = clear = cont = null; // don't leak
-            });
-        };
-        cont = function (url) {
-            // use image instance to make sure that the image exists
-            $(new Image())
-                .on('load', { url: url }, set)
-                .on('error', { url: ox.base + '/apps/themes/default/dummypicture.png' }, set)
-                .prop('src', url);
-        };
-        if (obj && _.isString(obj.image1_url) && obj.image1_url !== '') {
-            cont(obj.image1_url.replace(/^\/ajax/, ox.apiRoot) + '&' + $.param($.extend({}, options)));
-        } else {
-            api.getPictureURL(obj, options).done(cont).fail(clear);
-        }
         return node;
     };
 
@@ -825,7 +743,7 @@ define('io.ox/contacts/api',
         });
         // resume & trigger refresh
         return http.resume()
-            .pipe(function (result) {
+            .then(function (result) {
 
                 var def = $.Deferred();
 
@@ -881,9 +799,9 @@ define('io.ox/contacts/api',
 
         var now = _.now(),
             params = _.extend({
+            action: 'birthdays',
             start: now,
             end: now + 604800000, // now + WEEK
-            action: 'birthdays',
             columns: '1,20,500,501,502,503,504,505,511',
             timezone: 'UTC'
         }, options || {});
@@ -903,6 +821,15 @@ define('io.ox/contacts/api',
         return 'mailaddress' in obj && 'description' in obj;
     };
 
+    /**
+     * is ressource (duck check)
+     * @param  {object} obj (contact)
+     * @return {boolean}
+     */
+    api.looksLikeGroup = function (obj) {
+        return 'members' in obj;
+    };
+
     /**
      * is distribution list
      * @param  {object} obj (contact)
