@@ -15,21 +15,18 @@
 define('io.ox/contacts/edit/view-form',
     ['io.ox/contacts/model',
      'io.ox/backbone/views',
-     'io.ox/backbone/forms',
      'io.ox/core/extPatterns/actions',
      'io.ox/core/extPatterns/links',
      'io.ox/contacts/widgets/pictureUpload',
-     'io.ox/core/tk/attachments',
      'io.ox/contacts/api',
      'io.ox/contacts/util',
-     'gettext!io.ox/contacts',
      'io.ox/core/capabilities',
      'io.ox/core/extensions',
-     'io.ox/core/date',
      'io.ox/backbone/mini-views',
      'io.ox/backbone/mini-views/attachments',
+     'gettext!io.ox/contacts',
      'less!io.ox/contacts/edit/style.less'
-    ], function (model, views, forms, actions, links, PictureUpload, attachments, api, util, gt, capabilities, ext, date, mini, attachmentViews) {
+    ], function (model, views, actions, links, PictureUpload, api, util, capabilities, ext, mini, attachmentViews, gt) {
 
     'use strict';
 
@@ -159,14 +156,10 @@ define('io.ox/contacts/edit/view-form',
             id: ref + '/edit/picture',
             index: 100,
             customizeNode: function () {
-                //access to global address book?
-                if (isMyContactData && !capabilities.has('gab')) {
-                    this.$el = $('');
-                } else {
-                    this.$el
-                        .css({ display: 'inline-block' })
-                        .addClass('contact-picture-upload f6-target');
-                }
+                // before 7.4.2 (?) we had to check if global address book is available
+                // apparently the user API has been improved and handles the contact image as well
+                // so we just go on here
+                this.$el.addClass('contact-picture-upload f6-target');
             }
         }));
 
@@ -193,6 +186,23 @@ define('io.ox/contacts/edit/view-form',
             }));
         }
 
+        point.basicExtend({
+            id: 'autoExpand',
+            index: 'last',
+            draw: function (baton) {
+                baton.parentView.on('restore', function () {
+                    var diff = _.chain(baton.model.changed)
+                        .keys().without('id', 'folder', 'display_name')
+                        .difference(meta.alwaysVisible)
+                        .value()
+                        .length;
+                    if (diff > 0) {
+                        toggle.call(this.$el);
+                    }
+                });
+            }
+        });
+
         /*
          * extension point for mobile toolbar on the bottom of the page
          */
@@ -212,7 +222,9 @@ define('io.ox/contacts/edit/view-form',
 
         function toggle(e) {
 
-            e.preventDefault();
+            if (e) {
+                e.preventDefault();
+            }
 
             var node = $(this).closest('.edit-contact');
 
@@ -451,24 +463,38 @@ define('io.ox/contacts/edit/view-form',
             );
         }
 
-        function propagateAttachmentChange(model, id) {
+        function propagateAttachmentChange(model, id, errors) {
 
-            var folder_id = model.get('folder_id'), id = model.get('id') || id;
+            var folder_id = model.get('folder_id'), id = model.get('id') || id,
+                upload = api.uploadInProgress(_.ecid(model.attributes));
 
-            return api.get({ id: id, folder: folder_id }, false)
-                .then(function (data) {
-                    return $.when(
-                        api.caches.get.add(data),
-                        api.caches.all.grepRemove(folder_id + api.DELIM),
-                        api.caches.list.remove({ id: id, folder: folder_id }),
-                        api.clearFetchCache()
-                    )
-                    .done(function () {
-                        // to make the detailview remove the busy animation:
-                        api.removeFromUploadList(_.ecid(data));
-                        api.trigger('refresh.list');
+            //if there are errors show them
+            if (errors.length > 0) {
+                require(['io.ox/core/notifications'], function (notifications) {
+                    _(errors).each(function (error) {
+                        notifications.yell('error', error.error);
                     });
                 });
+            }
+
+            return api.get({ id: id, folder: folder_id }, !upload)
+                .then(function (data) {
+                    if (upload) {//don't delete caches if there is no upload
+                        return $.when(
+                            api.caches.get.add(data),
+                            api.caches.all.grepRemove(folder_id + api.DELIM),
+                            api.caches.list.remove({ id: id, folder: folder_id }),
+                            api.clearFetchCache()
+                        )
+                        .done(function () {
+                            // to make the detailview remove the busy animation:
+                            api.removeFromUploadList(_.ecid(data));
+                            api.trigger('refresh.list');
+                        });
+                    } else {
+                        return $.when();
+                    }
+                });
         }
 
         function drawAttachments(options, model, baton) {
