@@ -40,23 +40,9 @@ define('io.ox/contacts/util',
 
     var that = {
 
-        getImage: function (obj, options) {
-            if (obj.mark_as_distributionlist) {
-                return ox.base + '/apps/themes/default/dummypicture_group.png';
-            } else if (obj.image1_url) {
-                return obj.image1_url
-                    .replace(/^https?\:\/\/[^\/]+/i, '')
-                    .replace(/\/ajax/, ox.apiRoot) + (options ? '&' + $.param(options) : '');
-            } else {
-                return ox.base + '/apps/themes/default/dummypicture.png';
-            }
-
-        },
-
         // variant of getFullName without title, all lowercase
         getSortName: function (obj) {
-            obj = _.extend({}, obj);
-            obj.title = '';
+            obj = _.extend(obj, { title: '' });
             return this.getFullName(obj).toLowerCase();
         },
 
@@ -124,7 +110,7 @@ define('io.ox/contacts/util',
 
         getFullName: function (obj) {
             var fmt = this.getFullNameFormat(obj);
-            return gt.format(fmt.format, fmt.params);
+            return _.escape(gt.format(fmt.format, fmt.params));
         },
 
         getDisplayName: function (obj) {
@@ -203,20 +189,13 @@ define('io.ox/contacts/util',
 
         getMail: function (obj) {
             // get the first mail address
-            return (obj.email1 || obj.email2 || obj.email3 || obj.mail || '').toLowerCase();
-        },
-
-        getDescription: function (obj) {
-            // try some combinations
-            var list = _([obj.company, obj.department, obj.position, obj.city_business, obj.city_home]).compact();
-            return list.length ? list.join(', ') : (obj.email1 || '');
+            return obj ? (obj.email1 || obj.email2 || obj.email3 || obj.mail || '').toLowerCase() : '';
         },
 
         getJob: function (obj) {
             // combine position and company
-            return obj.position && obj.company ?
-                obj.position + ', ' + obj.company :
-                obj.position || obj.company || '';
+            var list = _([obj.company, obj.position]).compact();
+            return list.length ? list.join(', ') : (obj.email1 || '');
         },
 
         nameSort: function (a, b) {
