@@ -14,7 +14,6 @@
 
 define('io.ox/contacts/view-detail',
     ['io.ox/core/extensions',
-     'gettext!io.ox/contacts',
      'io.ox/contacts/util',
      'io.ox/contacts/api',
      'io.ox/contacts/actions',
@@ -22,8 +21,10 @@ define('io.ox/contacts/view-detail',
      'io.ox/core/api/folder',
      'io.ox/core/extPatterns/links',
      'io.ox/core/date',
+     'gettext!io.ox/contacts',
+     'settings!io.ox/contacts',
      'less!io.ox/contacts/style.less'
-    ], function (ext, gt, util, api, actions, model, folderAPI, links, date) {
+    ], function (ext, util, api, actions, model, folderAPI, links, date, gt, settings) {
 
     'use strict';
 
@@ -37,24 +38,30 @@ define('io.ox/contacts/view-detail',
     };
 
     function getDescription(data) {
+
         function single(index, value, translated) {
             var params = new Array(index);
             params[index - 1] = translated ? value : _.noI18n(value);
             return { format: _.noI18n('%' + index + '$s'), params: params };
         }
+
         if (api.looksLikeDistributionList(data)) {
             return single(7, gt('Distribution list'), true);
         }
+
         if (api.looksLikeResource(data)) {
             return single(7, gt('Resource'), true);
         }
+
         if (data.position || data.profession) {
             return {
                 format: join(', ', data.position ? '%1$s' : '', data.profession ? '%2$s' : ''),
                 params: [_.noI18n(data.position), _.noI18n(data.profession)]
             };
         }
+
         return util.getMailFormat(data);
+
     }
 
     function createText(format, classes) {
@@ -115,11 +122,13 @@ define('io.ox/contacts/view-detail',
         index: 100,
         id: 'contact-picture',
         draw: function (baton) {
-            if (!api.looksLikeDistributionList(baton.data)) {
-                this.append(
-                    api.getPicture(baton.data, { scaleType: 'contain', width: 80, height: 80 }).addClass('picture')
-                );
-            }
+            if (api.looksLikeDistributionList(baton.data)) return;
+            this.append(
+                api.pictureHalo(
+                    $('<div class="picture">'),
+                    $.extend(baton.data, { width: 64, height: 64, scaleType: 'cover' })
+                )
+            );
         }
     });
 
@@ -138,9 +147,9 @@ define('io.ox/contacts/view-detail',
                 $('<div class="next-to-picture">').append(
                     // right side
                     $('<i class="icon-lock private-flag">').attr('title', gt('Private')).hide(),
-                    $('<h1 class="header-name">').append(name),
+                    name.length ? $('<h1 class="header-name">').append(name) : [],
                     company ? $('<h2 class="header-company">').append($('<span class="company">').text(company)) : [],
-                    $('<h2 class="header-job">').append(job),
+                    job.length ? $('<h2 class="header-job">').append(job) : [],
                     $('<section class="attachments-container clear-both">')
                         .append($('<span class="attachments-in-progress">').busy())
                         .hide()
@@ -217,7 +226,10 @@ define('io.ox/contacts/view-detail',
             // draw member
             this.append(
                 $('<div class="member">').append(
-                    api.getPicture(data, { scaleType: 'cover', width: 48, height: 48 }).addClass('member-picture'),
+                    api.pictureHalo(
+                        $('<div class="member-picture">'),
+                        $.extend(data, { width: 48, height: 48, scaleType: 'cover' })
+                    ),
                     $('<div class="member-name">').text(data.display_name),
                     $('<a href="#" class="halo-link">').data({ email1: data.mail }).text(data.mail)
                 )
@@ -257,34 +269,50 @@ define('io.ox/contacts/view-detail',
 
     function block() {
 
+        function removeAndSplice() {
+            rows.splice(-1, 1);
+            return args.slice(-1)[0];
+        }
+
         var args = _(arguments).toArray(),
-            rows = _(args.slice(1)).compact();
+            rows = _(args.slice(1)).compact(),
+            noDl = _.isBoolean(args.slice(-1)[0]) ? removeAndSplice() : false,
+            block = $('<fieldset class="block">'),
+            dl = $('<dl class="dl-horizontal">'),
+            self = noDl ? block : dl.appendTo(block);
 
-        if (rows.length === 0) return $();
+        // if block empty
+        if (rows.length < 1) return $();
 
-        return $('<div class="block">').append(
-            [$('<legend>').text(args[0])].concat(rows)
+        _.each(rows, function (el) {
+            self.append(el);
+        });
+
+        return block.prepend(
+            $('<legend>').text(args[0])
         );
     }
 
     function row(id, builder) {
-
         var build = builder();
         if (!build) return null;
-
-        return $('<div>').attr('data-property', id).append(
-            $('<label>').text(model.fields[id]),
-            _.isString(build) ? $.txt(build) : build
-        );
+        return function () {
+            $(this).append(
+                $('<dt>').text(model.fields[id]),
+                $('<dd>').append(_.isString(build) ? $.txt(build) : build)
+            );
+        };
     }
 
     function simple(data, id, label) {
         var value = $.trim(data[id]);
         if (!value) return null;
-        return $('<div>').attr('data-property', id).append(
-            $('<label>').text(label || model.fields[id]),
-            $('<span>').text(value)
-        );
+        return function () {
+            $(this).append(
+                $('<dt>').text(label || model.fields[id]),
+                $('<dd>').text(value)
+            );
+        };
     }
 
     function clickMail(e) {
@@ -299,61 +327,65 @@ define('io.ox/contacts/view-detail',
         });
     }
 
-    function mail(address, name, id) {
+    function mail(address, name) {
         if (!address) return null;
-        return $('<div>').attr('data-property', id).append(
-            $('<label>').text(gt('Email')),
-            $('<a>', { href: 'mailto:' + address })
-                .text(_.noI18n(address))
-                .on('click', { email: address, display_name: name }, clickMail)
-        );
-    }
-
-    function getMailAddresses(data) {
-        return _([data.email1, data.email2, data.email3])
-            .chain()
-            .compact()
-            .map(function (address) {
-                return $.trim(address).toLowerCase();
-            })
-            .uniq()
-            .value();
+        return function () {
+            $(this).append(
+                $('<dt>').text(gt('Email')),
+                $('<dd>').append(
+                    $('<a>', { href: 'mailto:' + address })
+                        .text(_.noI18n(address))
+                        .on('click', { email: address, display_name: name }, clickMail)
+                )
+            );
+        };
     }
 
     function phone(data, id, label) {
         var number = $.trim(data[id]);
         if (!number) return null;
-        return $('<div>').attr('data-property', id).append(
-            $('<label>').text(label || model.fields[id]),
-            $('<a>', { href: _.device('smartphone') ? 'tel:' + number : 'callto:' + number }).text(number)
-        );
+        return function () {
+            $(this).append(
+                $('<dt>').text(label || model.fields[id]),
+                $('<dd>').append(
+                    $('<a>', { href: _.device('smartphone') ? 'tel:' + number : 'callto:' + number }).text(number)
+                )
+            );
+        };
     }
 
     function IM(number, id) {
-
         number = $.trim(number);
         if (!number) return null;
 
-        var node = $('<div>').attr('data-property', id), obj = {};
+        var obj = {};
 
         if (/^skype:/.test(number)) {
             number = number.split('skype:')[1];
-            return node.append(
-                $('<label>').text('Skype'),
-                $('<a>', { href: 'callto:' + number + '?call' }).text(number)
-            );
+            return function () {
+                $(this).append(
+                    $('<dt>').text('Skype'),
+                    $('<dd>').append(
+                        $('<a>', { href: 'callto:' + number + '?call' }).text(number)
+                    )
+                );
+            };
         }
 
         if (/^x-apple:/.test(number)) {
             number = number.split('x-apple:')[1];
-            return node.append(
-                $('<label>').text('iMessage'),
-                $('<a>', { href: 'imessage://' + number + '@me.com' }).text(number)
-            );
+            return function () {
+                $(this).append(
+                    $('<dt>').text('iMessage'),
+                    $('<dd>').append(
+                        $('<a>', { href: 'imessage://' + number + '@me.com' }).text(number)
+                    )
+                );
+            };
         }
 
         obj[id] = number;
-        return simple(id, gt('Messenger'), obj);
+        return simple(obj, id, gt('Messenger'));
     }
 
     // data is full contact data
@@ -375,16 +407,20 @@ define('io.ox/contacts/view-detail',
             //#. %5$s is the country
             gt('%1$s\n%2$s %3$s\n%4$s\n%5$s', data);
 
-        return $('<a class="google-maps" target="_blank">')
-            .attr('href', 'http://www.google.com/maps?q=' + encodeURIComponent(text.replace('/\n/g', ', ')))
-            .attr('data-property', type)
-            .append(
-                $.txt($.trim(text)),
-                $('<caption>').append(
-                    $('<i class="icon-external-link">'),
-                    $.txt(' Google Maps \u2122') // \u2122 = &trade;
-                )
+        return function () {
+            $(this).append(
+                $('<a class="google-maps" target="_blank">')
+                    .attr('href', 'http://www.google.com/maps?q=' + encodeURIComponent(text.replace('/\n/g', ', ')))
+                    .attr('data-property', type)
+                    .append(
+                        $('<address>').text($.trim(text)),
+                        $('<p>').append(
+                            $('<i class="icon icon-external-link">'),
+                            $.txt(' Google Maps \u2122') // \u2122 = &trade;
+                        )
+                    )
             );
+        };
     }
 
     ext.point('io.ox/contacts/detail/content')
@@ -398,7 +434,10 @@ define('io.ox/contacts/view-detail',
                 var comment = $.trim(baton.data.note || '');
                 if (comment !== '') {
                     this.append(
-                        $('<div class="comment">').text(comment)
+                        $('<fieldset>').append(
+                            $('<legend class="sr-only">').text(gt('Comment')),
+                            _.nltobr(comment, $('<div class="comment">'))
+                        )
                     );
                 }
             }
@@ -429,7 +468,7 @@ define('io.ox/contacts/view-detail',
                                 }
                             }
                         }),
-                        row('URL', function () {
+                        row('url', function () {
                             if (baton.data.url) {
                                 return $('<a>', { href: baton.data.url, target: '_blank' }).text(baton.data.url);
                             }
@@ -466,8 +505,13 @@ define('io.ox/contacts/view-detail',
             draw: function (baton) {
 
                 var data = baton.data,
-                    fullname = util.getFullName(baton.data),
-                    addresses = getMailAddresses(data);
+                    fullname = util.getFullName(data),
+                    addresses = _([data.email1, data.email2, data.email3])
+                        .chain()
+                        .map(function (address) {
+                            return $.trim(address).toLowerCase();
+                        })
+                        .value();
 
                 this.append(
                     block(gt('Mail and Messaging'),
@@ -515,8 +559,10 @@ define('io.ox/contacts/view-detail',
                 var data = baton.data;
 
                 this.append(
-                    block(gt('Business Address'),
-                        address(data, 'business')
+                    block(
+                        gt('Business Address'),
+                        address(data, 'business'),
+                        true
                     )
                     .attr('data-block', 'business-address')
                 );
@@ -531,8 +577,10 @@ define('io.ox/contacts/view-detail',
                 var data = baton.data;
 
                 this.append(
-                    block(gt('Home Address'),
-                        address(data, 'home')
+                    block(
+                        gt('Home Address'),
+                        address(data, 'home'),
+                        true
                     )
                     .attr('data-block', 'home-address')
                 );
@@ -547,8 +595,10 @@ define('io.ox/contacts/view-detail',
                 var data = baton.data;
 
                 this.append(
-                    block(gt('Other Address'),
-                        address(data, 'other')
+                    block(
+                        gt('Other Address'),
+                        address(data, 'other'),
+                        true
                     )
                     .attr('data-block', 'other-address')
                 );
@@ -640,44 +690,49 @@ define('io.ox/contacts/view-detail',
         id: 'qr',
         draw: function (baton) {
             var data = baton.data;
-            if (Modernizr.canvas && !data.mark_as_distributionlist) {
-                var node = $('<div>').addClass('block'),
-                    show = function (e) {
-                        e.preventDefault();
-                        node.empty().busy();
-                        require(['io.ox/contacts/view-qrcode'], function (qr) {
-                            var vc = qr.getVCard(data);
-                            node.append(
-                                $('<span>').addClass('qrcode').append(
-                                    $('<i class="icon-qrcode">'), $.txt(' '),
-                                    $('<a>', { href: '#' })
-                                    .text(gt('Hide QR code'))
-                                    .on('click', hide)
-                                )
-                            );
-                            node.idle().qrcode(vc);
-                            vc = qr = null;
-                        });
-                    },
-                    hide = function (e) {
-                        e.preventDefault();
-                        node.empty();
+
+            // disabled?
+            if (!settings.get('features/qrcode', true)) return;
+            // not supported
+            if (!Modernizr.canvas || data.mark_as_distributionlist) return;
+
+            var node = $('<fieldset class="block">'),
+                show = function (e) {
+                    e.preventDefault();
+                    node.empty().busy();
+                    require(['io.ox/contacts/view-qrcode'], function (qr) {
+                        var vc = qr.getVCard(data);
                         node.append(
-                            $('<i class="icon-qrcode">'), $.txt(' '),
-                            showLink
+                            $('<span>').addClass('qrcode').append(
+                                $('<i class="icon-qrcode">'), $.txt(' '),
+                                $('<a>', { href: '#' })
+                                .text(gt('Hide QR code'))
+                                .on('click', hide)
+                            )
                         );
-                    },
-                    showLink = $('<a>', { href: '#' }).text(gt('Show QR code')).on('click', show);
+                        node.idle().qrcode(vc);
+                        vc = qr = null;
+                    });
+                },
+                hide = function (e) {
+                    e.preventDefault();
+                    node.empty();
+                    node.append(
+                        $('<i class="icon-qrcode">'), $.txt(' '),
+                        showLink
+                    );
+                },
+                showLink = $('<a>', { href: '#' }).text(gt('Show QR code')).on('click', show);
 
-                this.append(
-                    node
-                 );
+            this.append(
+                node
+             );
 
-                node.append(
-                    $('<i class="icon-qrcode">'), $.txt(' '),
-                    showLink
-                );
-            }
+            node.append(
+                $('<legend class="sr-only">').text(gt('Show QR code')),
+                $('<i class="icon icon-qrcode">'), $.txt(' '),
+                showLink
+            );
         }
     });
 
@@ -719,8 +774,11 @@ define('io.ox/contacts/view-detail',
 
                 var node = $.createViewContainer(baton.data, api)
                     .on('redraw', { view: this, data: baton.data }, redraw)
-                    .addClass('contact-detail view');
-
+                    .addClass('contact-detail view')
+                    .attr({
+                        'role': 'complementary',
+                        'aria-label': gt('Contact Details')
+                    });
                 ext.point('io.ox/contacts/detail').invoke('draw', node, baton);
 
                 return node;
