@@ -149,6 +149,13 @@ define('io.ox/core/api/account',
         return def;
     };
 
+    api.getUnifiedInbox = function () {
+        return this.getUnifiedMailboxName().then(function (id) {
+            if (id === null) return null;
+            return id + separator + 'INBOX';
+        });
+    };
+
     /**
      * check folder type
      * @param  {string} type (foldertype, example is 'drafts')
@@ -287,29 +294,18 @@ define('io.ox/core/api/account',
     };
 
     // make sure account's personal is set
-    var ensureDisplayName = (function () {
+    var ensureDisplayName = function (account) {
 
-        var defer = null;
+        // no account given or account already has "personal"
+        if (!account || (account.personal && $.trim(account.personal) !== '')) {
+            return $.Deferred().resolve(account);
+        }
 
-        return function (account) {
-
-            // no account given or account already has "personal"
-            if (!account || account.personal) {
-                return $.Deferred().resolve(account);
-            }
-
-            if (defer === null) {
-                // load personal once
-                defer = api.getDefaultDisplayName();
-            }
-
-            return defer.then(function (personal) {
-                account.personal = personal;
-                return account;
-            });
-        };
-
-    }());
+        return api.getDefaultDisplayName().then(function (personal) {
+            account.personal = personal;
+            return account;
+        });
+    };
 
     api.trimAddress = function (address) {
         address = $.trim(address);
@@ -337,8 +333,9 @@ define('io.ox/core/api/account',
             return [getAddressArray(account.personal, account.primary_address)];
         }
 
-        // looks like addresses continas primary address plus aliases
-        var addresses = String(account.addresses || '').split(',').sort();
+        // looks like addresses contains primary address plus aliases
+        var addresses = _(String(account.addresses || '').toLowerCase().split(',')).map($.trim).sort();
+
         // build common array of [display_name, email]
         return _(addresses).map(function (address) {
             return getAddressArray(account.personal, address);
@@ -392,7 +389,7 @@ define('io.ox/core/api/account',
      * get all accounts
      * @return {deferred} returns array of account object
      */
-    api.all = function () {
+    api.all = function (options) {
 
         var getter = function () {
             return http.GET({
@@ -400,24 +397,27 @@ define('io.ox/core/api/account',
                 params: { action: 'all' },
                 appendColumns: true,
                 processResponse: true
+            })
+            .then(function (data) {
+                data = process(data);
+                return accountsAllCache.add(data).then(function () {
+                    return data;
+                });
             });
         };
 
-        return accountsAllCache.keys().pipe(function (keys) {
-            if (keys.length > 0) {
+        options = options || {};
+
+        return accountsAllCache.keys().then(function (keys) {
+            if (options.cache !== false && keys.length > 0) {
                 return accountsAllCache.values();
             } else if (ox.online) {
-                return getter().pipe(function (data) {
-                    data = process(data);
-                    return accountsAllCache.add(data).then(function () {
-                        return data;
-                    });
-                });
+                return getter();
             } else {
                 return [];
             }
         })
-        .pipe(function (list) {
+        .then(function (list) {
 
             idHash = {};
             typeHash = {};
@@ -524,15 +524,16 @@ define('io.ox/core/api/account',
             module: 'account',
             appendColumns: false,
             params: params,
-            data: data
+            data: data,
+            processData: false//needed or http.js does not give the warnings back
         })
-        // always successful but either true or false
+        //make it always successful but either true or false, if false we give the warnings back
         .then(
-            function success(bool) {
-                return $.Deferred().resolve(bool);
+            function success(response) {
+                return $.Deferred().resolve(response.data);
             },
-            function fail() {
-                return $.Deferred().resolve(false);
+            function fail(response) {
+                return $.Deferred().resolve(response.data, response);
             }
         );
     };
