@@ -33,9 +33,7 @@ define('io.ox/core/api/apps',
     _(manifests.manager.apps).each(function (appManifest) {
 
         if (!appManifest.path || !appManifest.category) {
-            if (window.console && console.warn) {
-                console.warn('Ignored app. Missing path/category', appManifest);
-            }
+            if (ox.debug && _.device('!karma')) console.warn('Ignored app. Missing path/category', appManifest);
             return;
         }
 
@@ -211,6 +209,10 @@ define('io.ox/core/api/apps',
             return getSpecial('favorites', allFavorites);
         },
 
+        getAvailable: function () {
+            return getSpecial('installed');
+        },
+
         /**
          * checks if app is marked as favorite (special category)
          * @param  {object}  data (app object)
