@@ -1,12 +1,12 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
@@ -22,7 +22,8 @@
 */
 define('io.ox/core/api/snippets',
     ['io.ox/core/http',
-     'io.ox/core/event'], function (http, Events) {
+     'io.ox/core/event'
+    ], function (http, Events) {
 
     'use strict';
 
@@ -45,7 +46,7 @@ define('io.ox/core/api/snippets',
      * get all snippets
      * @return {deferred} array of snippet objects
      */
-    api.getAll = function (type) {
+    api.getAll = function () {
         return http.GET({
             module: 'snippet',
             params: {
