@@ -13,8 +13,11 @@
 
 define('io.ox/core/api/user',
     ['io.ox/core/http',
-     'io.ox/core/api/factory'
-    ], function (http, apiFactory) {
+     'io.ox/core/api/factory',
+     'io.ox/contacts/util',
+     'io.ox/core/date',
+     'io.ox/core/capabilities',
+    ], function (http, apiFactory, util, date, capabilities) {
 
     'use strict';
 
@@ -64,35 +67,48 @@ define('io.ox/core/api/user',
         if (_.isEmpty(o.data)) {
             return $.when();
         } else {
-            return http.PUT({
-                    module: 'user',
-                    params: {
-                        action: 'update',
-                        id: o.id,
-                        folder: o.folder,
-                        timestamp: o.timestamp || _.then()
-                    },
-                    data: o.data,
-                    appendColumns: false
-                })
-                .pipe(function () {
-                    // get updated contact
-                    return api.get({ id: o.id }, false)
-                        .pipe(function (data) {
-                            return $.when(
-                                api.caches.get.add(data),
-                                api.caches.all.clear(),
-                                api.caches.list.remove({ id: o.id })
-                                // TODO: What about the contacts cache?
-                            )
-                            .done(function () {
-                                api.trigger('update:' + _.ecid(data), data);
-                                api.trigger('update', data);
-                                api.trigger('refresh.list');
-                                // TODO: What about the corresponding contact events?
+            require(['io.ox/contacts/api'], function (contactsApi) {
+                return http.PUT({
+                        module: 'user',
+                        params: {
+                            action: 'update',
+                            id: o.id,
+                            folder: o.folder,
+                            timestamp: o.timestamp || _.then()
+                        },
+                        data: o.data,
+                        appendColumns: false
+                    })
+                    .pipe(function () {
+                        // get updated contact
+                        return api.get({ id: o.id }, false)
+                            .pipe(function (data) {
+                                return $.when(
+                                    api.caches.get.add(data),
+                                    api.caches.all.clear(),
+                                    api.caches.list.remove({ id: o.id }),
+                                    // update contact caches
+                                    contactsApi.caches.get.remove({folder_id: data.folder_id, id: data.contact_id}),//no add here because this userdata not contactdata (similar but not equal)
+                                    contactsApi.caches.all.grepRemove(o.folder + contactsApi.DELIM),
+                                    contactsApi.caches.list.remove({ id: data.contact_id, folder: o.folder }),
+                                    contactsApi.clearFetchCache()
+                                )
+                                .done(function () {
+                                    api.trigger('update:' + _.ecid(data), data);
+                                    api.trigger('update', data);
+                                    api.trigger('refresh.list');
+                                    // get new contact and trigger contact events
+                                    // skip this if GAB is missing
+                                    if (data.folder_id === 6 && capabilities.has('!gab')) return;
+                                    //get new contact and trigger contact events
+                                    contactsApi.get({folder_id: data.folder_id, id: data.contact_id}).done(function (contactData) {
+                                        contactsApi.trigger('update:' + _.ecid(contactData), contactData);
+                                        contactsApi.trigger('update', contactData);
+                                    });
+                                });
                             });
-                        });
-                });
+                    });
+            });
         }
     };
 
@@ -197,46 +213,6 @@ define('io.ox/core/api/user',
         return $('<a href="#" class="halo-link">').append(text).data({ internal_userid: id });
     };
 
-    /**
-    * gets deferred.promise for fetching picture url
-    * @param {string} id of a user
-    * @param {object} options height, width, scaleType
-    * @return {promise}
-    */
-    api.getPictureURL = function (id, options) {
-        //get contact object first (userId != contactId)
-        return $.when(api.get({ id: id }), require(['io.ox/contacts/api'])).then(
-            function (data, contactsAPI) {
-                //call contactsAPI to share a picture cache
-                return contactsAPI.getPictureURL(data[0] || data, options);
-            },
-            function () {
-                return ox.base + '/apps/themes/default/dummypicture.png';
-            }
-        );
-    };
-
-    /**
-    * get div node with callbacks managing fetching/updating
-    * @param {string} id of a user
-    * @param {object} options height, with, scaleType
-    * @return {object} div node with callbacks
-    */
-    api.getPicture = function (id, options) {
-        var node = $('<div>'),
-            clear = function () {
-                _.defer(function () { // use defer! otherwise we return null on cache hit
-                    node = clear = null; // don't leak
-                });
-            };
-        api.getPictureURL(id, options)
-            .done(function (url) {
-                node.css('backgroundImage', 'url(' + url + ')');
-            })
-            .always(clear);
-        return node;
-    };
-
     /**
      * get a contact model of the currently logged in user
      * @return {object} a contact model of the current user
