@@ -38,51 +38,11 @@ define('io.ox/core/cache',
             return $.when.apply($,
                 ext.point('io.ox/core/cache/storage').map(function (storage) {
                     return storage.clear && storage.isUsable() ? storage.clear() : $.when();
-                })
+                }).value()
             );
         }
     };
 
-    // listen for logout event
-    ext.point('io.ox/core/logout').extend({
-        id: 'clearCache',
-        logout: function (baton) {
-            var clear = function () {
-                return ox.cache.clear();
-            };
-            if (baton.autologout && baton.autologout === true) {
-                return clear();
-            } else {
-                return ox.ui.App.canRestore().then(function (canRestore) {
-                    if (canRestore && !ox.online) {
-                        return ox.load(['io.ox/core/tk/dialogs', 'gettext!io.ox/core']).then(function (dialogs, gt) {
-                            var def = $.Deferred();
-                            new dialogs.ModalDialog()
-                                .text(gt('Unsaved documents will be lost. Do you want to sign out now?'))
-                                .addPrimaryButton('Yes', gt('Yes'))
-                                .addButton('No', gt('No'))
-                                .show()
-                                .then(function (action) {
-                                    if (action === 'No') {
-                                        return def.reject();
-                                    } else {
-                                        clear().then(function () {
-                                            def.resolve();
-                                        });
-                                    }
-                                });
-                            return def;
-                        });
-                    } else {
-                        return clear();
-                    }
-                }, function () {
-                    return clear();
-                });
-            }
-        }
-    });
-
     ext.point('io.ox/core/cache/storage').each(function (storage) {
         if (storage.isUsable() && _.isNull(preferredPersistentCache)) {
             preferredPersistentCache = storage.id;
@@ -114,7 +74,7 @@ define('io.ox/core/cache',
                 persistentCache = storages[opt.persistent],
                 fluentCache = storages[opt.fluent],
                 // use persistent storage?
-                persist = (ox.secretCookie === true && persistentCache.isUsable() && _.url.hash('persistence') !== 'false' && persistent === true ?
+                persist = (persistent === true && ox.secretCookie === true && ox.serverConfig.persistence !== false && persistentCache.isUsable() && _.url.hash('persistence') !== 'false' ?
                         function () {
                             return ox.user !== '';
                         } :
