@@ -16,8 +16,9 @@ define('io.ox/core/commons',
      'io.ox/core/extPatterns/links',
      'gettext!io.ox/core',
      'io.ox/core/commons-folderview',
-     'io.ox/core/api/folder'
-    ], function (ext, links, gt, folderview, folderAPI) {
+     'io.ox/core/api/folder',
+     'io.ox/core/api/account'
+    ], function (ext, links, gt, FolderView, folderAPI, accountAPI) {
 
     'use strict';
 
@@ -128,21 +129,23 @@ define('io.ox/core/commons',
                     // or creaet a new one
                     container = $('<div>', {id: toolbarID});
                 }
-                if (selection.length > 0) {
-                    // update selection in toolbar
-                    buttons.hide();
-                    $('#' + toolbarID).remove();
-                    toolbar.append(container.append(draw(id, selection, grid)));
-                } else {
-                    // selection empty
-                    $('#' + toolbarID).remove();
-                    buttons.show();
-                }
+                _.defer(function () {
+                    if (selection.length > 0) {
+                        // update selection in toolbar
+                        buttons.hide();
+                        $('#' + toolbarID).remove();
+                        toolbar.append(container.append(draw(id, selection, grid)));
+                    } else {
+                        // selection empty
+                        $('#' + toolbarID).remove();
+                        buttons.show();
+                    }
+                }, 100);
             };
         }()),
 
         wireGridAndSelectionChange: function (grid, id, draw, node, api) {
-            var last = '';
+            var last = '', label;
             grid.selection.on('change', function (e, selection) {
 
                 var len = selection.length,
@@ -150,6 +153,20 @@ define('io.ox/core/commons',
                     flat = JSON.stringify(_([].concat(selection)).map(function (o) {
                         return { folder_id: String(o.folder_id || o.folder), id: String(o.id), recurrence_position: String(o.recurrence_position || 0) };
                     }));
+
+                function updateLabel() {
+                    var parent = node.parent();
+                    if (len <= 1 && label) {
+                        //reset label
+                        parent.attr('aria-label', label);
+                    } else if (len > 1) {
+                        //remember label
+                        label = label || parent.attr('aria-label');
+                        //overwrite
+                        parent.attr('aria-label', gt('Selection Details'));
+                    }
+                }
+
                 // has anything changed?
                 if (flat !== last) {
                     if (len === 1) {
@@ -171,13 +188,18 @@ define('io.ox/core/commons',
                                 )
                             )
                         );
-                        if (_.device('small')) {//don't stay in empty detail view
+                        if (_.device('small')) {
+                            //don't stay in empty detail view
                             var vsplit = node.closest('.vsplit');
-                            if (!vsplit.hasClass('vsplit-reverse')) {//only click if in detail view to prevent infinite loop
-                                vsplit.find('.rightside-navbar a').trigger('click');//trigger back button
+                            //only click if in detail view to prevent infinite loop
+                            if (!vsplit.hasClass('vsplit-reverse')) {
+                                //trigger back button
+                                vsplit.find('.rightside-navbar a>i').last().trigger('click');
                             }
                         }
                     }
+                    //landmark label
+                    updateLabel();
                     // remember current selection
                     last = flat;
                 }
@@ -216,11 +238,16 @@ define('io.ox/core/commons',
                 grid.selection.removeFromIndex(ids);
 
                 var list = grid.selection.get(), index;
-                if (list.length > 0 && !_.device('small')) {//don't jump to next item on mobile devices (jump back to grid view to be consistent)
-                    index = grid.selection.getIndex(list[0]);
-                    grid.selection.clear(true).selectIndex(index + 1);
-                    if (grid.getIds().length === list.length) {
-                        grid.selection.trigger('change', []);
+                if (list.length > 0) {
+                    if (_.device('small')) {
+                        //preparation to return to vgrid
+                        grid.selection.clear(true);
+                    } else {
+                        index = grid.selection.getIndex(list[0]);
+                        grid.selection.clear(true).selectIndex(index + 1);
+                        if (grid.getIds().length === list.length) {
+                            grid.selection.trigger('change', []);
+                        }
                     }
                 }
             });
@@ -367,6 +394,8 @@ define('io.ox/core/commons',
          * Wire first refresh
          */
         wireFirstRefresh: function (app, api) {
+            // don't need first refresh if persistence=false
+            if (ox.serverConfig.persistence === false) return;
             // open (first show)
             app.getWindow().on('open', function () {
                 if (api.needsRefresh(app.folder.get())) {
@@ -486,12 +515,24 @@ define('io.ox/core/commons',
 
             defaultFolderId = _.url.hash('folder') || defaultFolderId;
 
-            // explicit vs. default
-            if (defaultFolderId !== undefined) {
-                return app.folder.set(defaultFolderId).pipe(null, function () {
+            function apply(id) {
+                return app.folder.set(id).then(null, function () {
+                    // fallback to default on error
                     return app.folder.setDefault();
                 });
-            } else {
+            }
+
+            // explicit vs. default
+            if (defaultFolderId !== undefined) {
+                return apply(defaultFolderId);
+            }
+            else if (type === 'mail') {
+                return accountAPI.getUnifiedInbox().then(function (id) {
+                    if (id === null) return app.folder.setDefault();
+                    return apply(id);
+                });
+            }
+            else {
                 return app.folder.setDefault();
             }
         },
@@ -581,7 +622,7 @@ define('io.ox/core/commons',
             });
         },
 
-        addFolderView: folderview.add,
+        addFolderView: FolderView.add,
 
         vsplit: (function () {
             var selectionInProgress = false;
@@ -617,7 +658,12 @@ define('io.ox/core/commons',
                 var sides = {};
                 parent.addClass('vsplit').append(
                     // left
-                    sides.left = $('<div class="leftside">').on('select', select),
+                    sides.left = $('<div class="leftside">')
+                    .attr({
+                        'role': 'main',
+                        'aria-label': gt('Items')
+                    })
+                    .on('select', select),
                     // navigation
                     $('<div class="rightside-navbar">').append(
                         $('<div class="rightside-inline-actions">'),
@@ -652,7 +698,9 @@ define('io.ox/core/commons',
     $.createViewContainer = function (baton, api, getter) {
 
         var data = baton instanceof ext.Baton ? baton.data : baton,
-            cid, ecid, pattern,
+            cid = _.cid(data),
+            ecid = _.ecid(data),
+            shortecid = 'recurrence_position' in data ? _.ecid({ id: data.id, folder: (data.folder_id || data.folder) }) : null,
             node = $('<div>').attr('data-cid', _([].concat(data)).map(_.cid).join(',')),
 
             update = function (e, changed) {
@@ -705,42 +753,27 @@ define('io.ox/core/commons',
             // multiple items - just listen to generic events.
             // otherweise "select all" of some thousands items freezes browser
             folderAPI.on('update',  redraw);
-            api.on('delete', redraw);
-            api.on('update', redraw);
             // ignore move case for multiple
+            api.on('delete update', redraw);
         } else {
             // single item
-            cid = _.cid(data);
-            ecid = _.ecid(data);
             folderAPI.on('update',  { cid: cid, folder: data.folder_id }, checkFolder);
             api.on('delete:' + ecid, remove);
-            api.on('update:' + ecid, update);
+            api.on('create update:' + ecid + (shortecid ? ' update:' + shortecid : ''), update);
             api.on('move:' + ecid, move);
-            api.on('create', update);
-            //calendar: update element of a series if master changes
-            if (data.recurrence_position && data.recurrence_position > 0 && (data.recurrence_id === data.id)) {
-                pattern = (data.folder || data.folder_id) + '.' + data.id + '.';
-                api.on('update:series:' + _.ecid(pattern), update);
-            }
         }
 
         return node.one('dispose', function () {
                 if (_.isArray(data)) {
                     folderAPI.off('update', redraw);
-                    api.off('delete', redraw);
-                    api.off('update', redraw);
+                    api.off('delete update', redraw);
                 } else {
-                    cid = _.cid(data);
-                    ecid = _.ecid(data);
                     folderAPI.off('update', checkFolder);
                     api.off('delete:' + ecid, remove);
-                    api.off('update:' + ecid, update);
+                    api.off('create update:' + ecid + (shortecid ? ' update:' + shortecid : ''), update);
                     api.off('move:' + ecid, move);
-                    api.off('create', update);
-                    if (pattern)
-                        api.off('update:series:' + _.ecid(pattern));
                 }
-                api = update = data = node = getter = cid = ecid = pattern = null;
+                api = update = data = node = getter = cid = ecid = null;
             });
     };
 
