@@ -218,7 +218,7 @@ define('io.ox/core/desktop',
 
                     getData: function () {
 
-                        if (folder === null) return $.Deferred.resolve({});
+                        if (folder === null) return $.Deferred().resolve({});
 
                         return require(['io.ox/core/api/folder']).pipe(function (api) {
                             return api.get({ folder: folder });
@@ -332,7 +332,7 @@ define('io.ox/core/desktop',
 
         setState: function (obj) {
             for (var id in obj) {
-                _.url.hash(id, String(obj[id]));
+                _.url.hash(id, ((obj[id] !== null) ? String(obj[id]) : null));
             }
         },
 
@@ -344,14 +344,15 @@ define('io.ox/core/desktop',
 
             var deferred = $.when(),
                 self = this,
-                isDisabled = ox.manifests.isDisabled(this.getName() + '/main');
+                name = this.getName(),
+                isDisabled = ox.manifests.isDisabled(name + '/main');
 
             // update hash
-            if (this.get('name') !== _.url.hash('app')) {
+            if (name !== _.url.hash('app')) {
                 _.url.hash({ folder: null, perspective: null, id: null });
             }
-            if (this.has('name')) {
-                _.url.hash('app', this.get('name'));
+            if (name) {
+                _.url.hash('app', name);
             }
 
             if (this.get('state') === 'ready') {
@@ -359,19 +360,25 @@ define('io.ox/core/desktop',
                 if (isDisabled) {
                     deferred = $.Deferred().reject();
                 } else {
-                    deferred = this.get('launch').call(this, options || {}) || $.when();
+                    options = options || {};
+                    if (name) {
+                        ext.point(name + '/main').invoke('launch', this, options);
+                    }
+                    deferred = this.get('launch').call(this, options) || $.when();
                 }
-                deferred
-                .done(function () {
-                    ox.ui.apps.add(self);
-                    self.set('state', 'running');
-                    self.trigger('launch', self);
-                })
-                .fail(function () {
-                    ox.launch(
-                        require('settings!io.ox/core').get('autoStart')
-                    );
-                });
+                deferred.then(
+                    function success() {
+                        ox.ui.apps.add(self);
+                        self.set('state', 'running');
+                        self.trigger('launch', self);
+                        ox.trigger('app:start', self);
+                    },
+                    function fail() {
+                        ox.launch(
+                            require('settings!io.ox/core').get('autoStart')
+                        );
+                    }
+                );
             } else if (this.has('window')) {
                 // toggle app window
                 this.get('window').show();
@@ -392,7 +399,7 @@ define('io.ox/core/desktop',
                     self.destroy();
                 }
                 // update hash but don't delete information of other apps that might already be open at this point (async close when sending a mail for exsample);
-                if (!_.url.hash('app') || self.getName() === _.url.hash('app').split(':', 1)[0]) {
+                if (self.getWindow().state.visible && (!_.url.hash('app') || self.getName() === _.url.hash('app').split(':', 1)[0])) {
                     //we are still in the app to close so we can clear the URL
                     _.url.hash({ app: null, folder: null, perspective: null, id: null });
                 }
@@ -405,6 +412,7 @@ define('io.ox/core/desktop',
                 if (self.has('window')) {
                     win = self.get('window');
                     win.trigger('quit');
+                    ox.trigger('app:stop', self);
                     ox.ui.windowManager.trigger('window.quit', win);
                     win.destroy();
                 }
@@ -475,21 +483,20 @@ define('io.ox/core/desktop',
 
         getSavePoints: function () {
             return appCache.get('savepoints').then(function (list) {
-                if (!list) {
+                if (!list || _.isEmpty(list)) {
                     list = coreConfig.get('savepoints', []);
                 }
                 return _(list || []).filter(function (obj) {
                     var hasPoint = 'point' in obj,
-                        sameVersion = obj.version === ox.version,
                         sameUA = obj.ua === navigator.userAgent;
-                    return (hasPoint && sameVersion && sameUA);
+                    return (hasPoint && sameUA);
                 });
             });
         },
 
         setSavePoints: function (list) {
             list = list || [];
-            coreConfig.set('savepoints', list);
+            coreConfig.set('savepoints', list).save();
             return appCache.add('savepoints', list);
         },
 
@@ -924,7 +931,11 @@ define('io.ox/core/desktop',
                 ext.point(name + '/window-toolbar').extend({
                     id: 'default',
                     draw: function () {
-                        return $('<div class="window-toolbar">');
+                        return $('<div class="window-toolbar">')
+                            .attr({
+                                'role': 'navigation',
+                                'aria-label': gt('Application Toolbar')
+                            });
                     }
                 });
 
@@ -993,18 +1004,16 @@ define('io.ox/core/desktop',
                             self.state.open = true;
                             self.trigger('show');
                             if (_.device('!small')) {
-                                document.temptitle = gt.format(
+                                document.title = document.customTitle = gt.format(
                                     //#. Title of the browser window
                                     //#. %1$s is the name of the page, e.g. OX App Suite
                                     //#. %2$s is the title of the active app, e.g. Calendar
                                     gt.pgettext('window title', '%1$s %2$s'),
                                     _.noI18n(ox.serverConfig.pageTitle),
-                                    self.getTitle());
-                                if (document.fixedtitle !== true) {//to prevent erasing the New Mail title
-                                    document.title = document.temptitle;
-                                }
+                                    self.getTitle()
+                                );
                             } else {
-                                document.title = _.noI18n(ox.serverConfig.pageTitle);
+                                document.title = document.customTitle = _.noI18n(ox.serverConfig.pageTitle);
                             }
 
                             if (firstShow) {
@@ -1013,6 +1022,7 @@ define('io.ox/core/desktop',
                                 self.trigger('open');
                                 self.state.running = true;
                                 ox.ui.windowManager.trigger('window.open', self);
+                                ox.trigger('app:ready', self.app);
                                 firstShow = false;
                             }
                             ox.ui.windowManager.trigger('window.show', self);
@@ -1039,14 +1049,7 @@ define('io.ox/core/desktop',
                     ox.ui.windowManager.trigger('window.hide', this);
                     if (currentWindow === this) {
                         currentWindow = null;
-                        if (_.device('!small')) {
-                            document.temptitle = _.noI18n(ox.serverConfig.pageTitle);
-                            if (document.fixedtitle !== true) {//to prevent erasing the New Mail title
-                                document.title = document.temptitle;
-                            }
-                        } else {
-                            document.title = _.noI18n(ox.serverConfig.pageTitle);
-                        }
+                        document.title = document.customTitle = _.noI18n(ox.serverConfig.pageTitle);
                     }
                     return this;
                 };
@@ -1168,19 +1171,16 @@ define('io.ox/core/desktop',
                         self.nodes.title.find('span').first().text(title);
                         if (this === currentWindow) {
                             if (_.device('!small')) {
-                                document.temptitle = gt.format(
+                                document.title = document.customTitle = gt.format(
                                     //#. Title of the browser window
                                     //#. %1$s is the name of the page, e.g. OX App Suite
                                     //#. %2$s is the title of the active app, e.g. Calendar
                                     gt.pgettext('window title', '%1$s %2$s'),
                                     _.noI18n(ox.serverConfig.pageTitle),
-                                    title);
-                                if (document.fixedtitle !== true) {//to prevent erasing the New Mail title
-                                    document.title = document.temptitle;
-                                }
-
+                                    title
+                                );
                             } else {
-                                document.title = _.noI18n(ox.serverConfig.pageTitle);
+                                document.title = document.customTitle = _.noI18n(ox.serverConfig.pageTitle);
                             }
                         }
                         this.trigger('change:title');
@@ -1246,7 +1246,7 @@ define('io.ox/core/desktop',
                     },
 
                     getQuery: function () {
-                        return $.trim(self.nodes.searchField.val());
+                        return self.nodes.searchField.val();
                     },
 
                     setQuery: function (query) {
@@ -1287,6 +1287,10 @@ define('io.ox/core/desktop',
 
                 this.addPerspective = function (pers) {
                     var id = pers.name, node;
+                    // remove default main node if empty
+                    if (this.nodes.main && this.nodes.main.not(':empty')) {
+                        this.nodes.main.remove();
+                    }
                     if (this.nodes[id] === undefined) {
                         this.nodes.body.append(
                             node = $('<div class="abs window-content">').hide()
@@ -1447,7 +1451,11 @@ define('io.ox/core/desktop',
                     }
                 };
 
-                $('<form class="form-search form-inline">').append(
+                $('<form class="form-search form-inline" role="search">')
+                .attr({
+                    'aria-label': gt('Search for items')
+                })
+                .append(
                     $('<div class="input-append">').append(
                         $('<label>', { 'for': searchId }).addClass('search-query-container').append(
                             // search field
@@ -1499,6 +1507,10 @@ define('io.ox/core/desktop',
 
                     new links.Action(opt.name + '/actions/search', {
                         action:  function (baton) {
+                            //hide open sidepopup
+                            var $sidepopup = $(baton.window.nodes.body).find('.io-ox-sidepopup');
+                            if ($sidepopup.is(':visible'))
+                                $sidepopup.trigger('remove');
                             baton.window.search.toggle();
                         }
                     });
