@@ -24,12 +24,11 @@ define('io.ox/core/main',
      'io.ox/core/upsell',
      'io.ox/core/capabilities',
      'io.ox/core/ping',
-     'io.ox/tours/main',
      'settings!io.ox/core',
      'gettext!io.ox/core',
      'io.ox/core/relogin',
      'io.ox/core/bootstrap/basics'
-    ], function (desktop, session, http, appAPI, ext, Stage, date, notifications, commons, upsell, capabilities, ping, tours, settings, gt) {
+    ], function (desktop, session, http, appAPI, ext, Stage, date, notifications, commons, upsell, capabilities, ping, settings, gt) {
 
     'use strict';
 
@@ -39,6 +38,7 @@ define('io.ox/core/main',
     var debug = _.url.hash('debug') === 'boot' ? function () { console.log.apply(console, arguments); } : $.noop;
 
     debug('core: Loaded');
+    ox.trigger('core:load');
 
     _.stepwiseInvoke = function (list, method, context) {
         if (!_.isArray(list)) return $.when();
@@ -94,10 +94,67 @@ define('io.ox/core/main',
         });
     };
 
+    // listen for logout event
+    ext.point('io.ox/core/logout').extend({
+        id: 'saveSettings',
+        logout: function () {
+            // force save requests for all pending settings
+            var pending = settings.getAllPendingSettings(),
+                defs = [];
+            if (!_.isEmpty(pending)) {
+                _(pending).each(function (setting) {
+                    defs.push(setting.save(undefined, { force: true }));
+                });
+            }
+            return $.when(defs);
+        }
+    });
+
+    ext.point('io.ox/core/logout').extend({
+        id: 'clearCache',
+        logout: function (baton) {
+            var clear = function () {
+                return ox.cache.clear();
+            };
+            if (baton.autologout && baton.autologout === true) {
+                return clear();
+            } else {
+                return ox.ui.App.canRestore().then(
+                    function success(canRestore) {
+                        if (canRestore && !ox.online) {
+                            return ox.load(['io.ox/core/tk/dialogs']).then(function (dialogs) {
+                                var def = $.Deferred();
+                                new dialogs.ModalDialog()
+                                    .text(gt('Unsaved documents will be lost. Do you want to sign out now?'))
+                                    .addPrimaryButton('Yes', gt('Yes'))
+                                    .addButton('No', gt('No'))
+                                    .show()
+                                    .then(function (action) {
+                                        if (action === 'No') {
+                                            return def.reject();
+                                        } else {
+                                            clear().then(function () {
+                                                def.resolve();
+                                            });
+                                        }
+                                    });
+                                return def;
+                            });
+                        } else {
+                            return clear();
+                        }
+                    },
+                    function fail() {
+                        return clear();
+                    }
+                );
+            }
+        }
+    });
+
     //
     // handle online/offline mode
     //
-
     function showIndicator(text) {
         $('#io-ox-offline').text(text).stop().show().animate({ bottom: '0px' }, 200);
     }
@@ -134,6 +191,10 @@ define('io.ox/core/main',
         launchers = $('.launchers', topbar),
         launcherDropdown = $('.launcher-dropdown ul', topbar);
 
+    topbar.attr({
+        'aria-label': gt('Applications')
+    });
+
     $('a.dropdown-toggle', topbar).attr({
         'aria-label': gt('Launcher dropdown. Press [enter] to jump to the dropdown.'),
         'role': 'button',
@@ -147,7 +208,7 @@ define('io.ox/core/main',
     gt.pgettext('app', 'Calendar');
     gt.pgettext('app', 'Scheduling');
     gt.pgettext('app', 'Tasks');
-    gt.pgettext('app', 'Files');
+    gt.pgettext('app', 'Drive');
     gt.pgettext('app', 'Conversations');
 
     var tabManager = _.debounce(function () {
@@ -246,7 +307,7 @@ define('io.ox/core/main',
 
         var count = 0,
             timer = null,
-            useSpinner = _.device('webkit || firefox'),
+            useSpinner = _.device('webkit || firefox || ie > 9'),
             duration = useSpinner ? 500 : 1500,
             refreshIcon = null;
 
@@ -501,6 +562,7 @@ define('io.ox/core/main',
                 quitApp = $('<a href="#" class="closelink" tabindex="1" role="button" aria-label="' + ariaBasicLabel + '">')
                     .append($('<i class="icon-remove">'))
                     .on('click', function (e) {
+                        e.preventDefault();
                         e.stopImmediatePropagation();
                         model.getWindow().app.quit();
                     })
@@ -598,12 +660,10 @@ define('io.ox/core/main',
                 // we don't need this right from the start,
                 // so let's delay this for responsiveness
                 if (ox.online) {
-                    //setTimeout(function () {
                     _.defer(function () {
                         self.prepend(notifications.attach(addLauncher));
                         tabManager();
                     });
-                    //}, 5000);
                 }
             }
         });
@@ -638,11 +698,30 @@ define('io.ox/core/main',
             }
         });
 
+        ext.point('io.ox/core/topbar/right/dropdown').extend({
+            id: 'change-user-data',
+            index: 150,
+            draw: function () {
+                this.append(
+                    $('<li>').append(
+                        $('<a href="#" data-app-name="io.ox/settings" role="menuitem" aria-haspopup="true" tabindex="1">')
+                        .text(gt('My contact data'))
+                    )
+                    .on('click', function (e) {
+                        e.preventDefault();
+                        require(['io.ox/core/settings/user'], function (userSettings) {
+                            userSettings.openModalDialog();
+                        });
+                    })
+                );
+            }
+        });
+
         ext.point('io.ox/core/topbar/right/dropdown').extend({
             id: 'app-specific-help',
             index: 200,
             draw: function () { //replaced by module
-                var helpDir = 'help/' + ox.language + '/',
+                var helpDir = 'help/l10n/' + ox.language + '/',
                     node = this,
                     startingPoints = {
                     'io.ox/contacts': 'ox.appsuite.user.chap.contacts.html',
@@ -668,53 +747,6 @@ define('io.ox/core/main',
             }
         });
 
-        ext.point('io.ox/core/topbar/right/dropdown').extend({
-            id: 'intro-tour',
-            index: 280,
-            draw: function () { //replaced by module
-                var node = this;
-                if (_.device('mobileOS') || _.device('touch')) {
-                    return;
-                }
-                node.append(
-                    $('<li>', {'class': 'io-ox-specificHelp'}).append(
-                        $('<a target="_blank" href="" role="menuitem" tabindex="1">').text(
-                            //#. Tour name; general introduction
-                            gt('Getting started')
-                        )
-                        .on('click', function (e) {
-                            tours.runTour('io.ox/intro');
-                            e.preventDefault();
-                        })
-                    )
-                );
-            }
-        });
-
-        ext.point('io.ox/core/topbar/right/dropdown').extend({
-            id: 'app-specific-tour',
-            index: 281,
-            draw: function () { //replaced by module
-                var node = this;
-                if (_.device('mobileOS') || _.device('touch')) {
-                    return;
-                }
-                node.append(
-                    $('<li>', {'class': 'io-ox-specificHelp'}).append(
-                        $('<a target="_blank" href="" role="menuitem" tabindex="1">').text(
-                            //#. app-specific
-                            gt('Guided tour for this app')
-                        )
-                        .on('click', function (e) {
-                            var currentApp = ox.ui.App.getCurrentApp(),
-                                currentType = currentApp.attributes.name;
-                            tours.runTour(currentType);
-                            e.preventDefault();
-                        })
-                    )
-                );
-            }
-        });
 
         ext.point('io.ox/core/topbar/right/dropdown').extend({
             id: 'divider-before-fullscreen',
@@ -772,22 +804,24 @@ define('io.ox/core/main',
             }
         });
 
-        ext.point('io.ox/core/topbar/right/dropdown').extend({
-            id: 'logout',
-            index: 1000,
-            draw: function () {
-                this.append(
-                    $('<li class="divider" aria-hidden="true" role="presentation"></li>'),
-                    $('<li>').append(
-                        $('<a href="#" data-action="logout" role="menuitem" tabindex="1">').text(gt('Sign out'))
-                    )
-                    .on('click', function (e) {
-                        e.preventDefault();
-                        logout();
-                    })
-                );
-            }
-        });
+        if (settings.get('features/dedicatedLogoutButton', false) === false) {
+            ext.point('io.ox/core/topbar/right/dropdown').extend({
+                id: 'logout',
+                index: 1000,
+                draw: function () {
+                    this.append(
+                        $('<li class="divider" aria-hidden="true" role="presentation"></li>'),
+                        $('<li>').append(
+                            $('<a href="#" data-action="logout" role="menuitem" tabindex="1">').text(gt('Sign out'))
+                        )
+                        .on('click', function (e) {
+                            e.preventDefault();
+                            logout();
+                        })
+                    );
+                }
+            });
+        }
 
         ext.point('io.ox/core/topbar/right').extend({
             id: 'dropdown',
@@ -799,7 +833,7 @@ define('io.ox/core/main',
                         a = $('<a class="dropdown-toggle" data-toggle="dropdown" href="#" role="button" aria-haspopup="true" tabindex="1">').append(
                             $('<i class="icon-cog icon-white launcher-icon" aria-hidden="true">')
                         ),
-                        ul = $('<ul class="dropdown-menu" role="menu">')
+                        ul = $('<ul id="topbar-settings-dropdown" class="dropdown-menu pull-right" role="menu">')
                     )
                 );
                 if (!Modernizr.touch) {
@@ -814,6 +848,20 @@ define('io.ox/core/main',
             }
         });
 
+        if (settings.get('features/dedicatedLogoutButton', false) === true) {
+            ext.point('io.ox/core/topbar/right').extend({
+                id: 'logout-button',
+                index: 2000,
+                draw: function () {
+                    this.append(
+                        addLauncher('right', $('<i class="icon-off launcher-icon">').attr('aria-hidden', 'true'), function () {
+                            logout();
+                        },  gt('Sign out'))
+                    );
+                }
+            });
+        }
+
         ext.point('io.ox/core/topbar/right').extend({
             id: 'logo',
             index: 10000,
@@ -847,11 +895,35 @@ define('io.ox/core/main',
         ext.point('io.ox/core/topbar/favorites').extend({
             id: 'default',
             draw: function () {
-                var favorites = appAPI.getAllFavorites();
-                favorites.sort(function (a, b) {
-                    return ext.indexSorter(a, b);
-                });
-                _(favorites).each(function (obj) {
+
+                var topbar = settings.get('topbar/order'),
+                    apps = [],
+                    hash = {};
+
+                // use custom order?
+                if (topbar) {
+                    // get apps
+                    apps = appAPI.getAvailable();
+                    // get hash of exisiting favorites
+                    _(apps).each(function (obj) { hash[obj.id] = obj; });
+                    // get proper order
+                    apps = _(topbar.split(','))
+                        .chain()
+                        .map(function (id) {
+                            return hash[id];
+                        })
+                        .compact()
+                        .value();
+                } else {
+                    // get apps
+                    apps = appAPI.getAllFavorites();
+                    // sort by index
+                    apps.sort(function (a, b) {
+                        return ext.indexSorter(a, b);
+                    });
+                }
+
+                _(apps).each(function (obj) {
                     if (upsell.visible(obj.requires)) {
                         ox.ui.apps.add(new ox.ui.AppPlaceholder({
                             id: obj.id,
@@ -919,8 +991,9 @@ define('io.ox/core/main',
         var getAutoLaunchDetails = function (str) {
             var pair = (str || '').split(/:/), app = pair[0], method = pair[1] || '';
             return { app: (/\/main$/).test(app) ? app : app + '/main', method: method };
-        },
-        mobileAutoLaunchArray = function () {
+        };
+
+        var mobileAutoLaunchArray = function () {
             var autoStart = _([].concat(settings.get('autoStartMobile', 'io.ox/portal'))).filter(function (o) {
                 return !_.isUndefined(o) && !_.isNull(o);
             });
@@ -1013,8 +1086,8 @@ define('io.ox/core/main',
             };
         }
 
-        requirejs.onError = function () {
-            console.error('requirejs', arguments);
+        requirejs.onError = function (e) {
+            console.error('requirejs', e.message, arguments);
         };
 
         // start loading stuff
@@ -1129,13 +1202,23 @@ define('io.ox/core/main',
                     // draw savepoints to allow the user removing them
                     ox.ui.App.getSavePoints().done(function (list) {
                         _(list).each(function (item) {
+                            var info = item.description || item.module,
+                                versionInfo = $();
+                            if (item.version !== ox.version) {
+                                var version = item.version || '';
+                                version = version.split('.').slice(0, -2).join('.');
+                                if (version) {
+                                    versionInfo = $('<span>').addClass('oldversion').text(gt.noI18n('(' + version + ')'));
+                                }
+                            }
                             this.append(
                                 $('<li class="restore-item">').append(
                                     $('<a href="#" role="button" class="remove">').data(item).append(
                                         $('<i class="icon-trash">')
                                     ),
                                     item.icon ? $('<i class="' + item.icon + '">') : $(),
-                                    $('<span>').text(gt.noI18n(item.description || item.module))
+                                    $('<span>').text(gt.noI18n(info)),
+                                    versionInfo
                                 )
                             );
                         }, dialog.find('.content'));
@@ -1269,6 +1352,14 @@ define('io.ox/core/main',
             }
         });
 
+        new Stage('io.ox/core/stages', {
+            id: 'ready',
+            index: 'last',
+            run: function () {
+                ox.trigger('core:ready');
+            }
+        });
+
         debug('core: launch > run stages');
         Stage.run('io.ox/core/stages', baton);
     }
