@@ -27,7 +27,8 @@ define('io.ox/core/tk/autocomplete',
     $.fn.autocomplete = function (o) {
 
         o = $.extend({
-            minLength: settings.get('search/minimumQueryLength', 3),
+            // use Math.max here to make sure we don't get a zero (strange behavior then & look-up is too expensive)
+            minLength: Math.max(1, settings.get('search/minimumQueryLength', 3)),
             maxResults: 25,
             delay: 100,
             collection: null,
@@ -166,6 +167,12 @@ define('io.ox/core/tk/autocomplete',
                     if (isOpen) {
                         // toggle blur handlers
                         self.on('blur', o.blur).off('blur', fnBlur);
+                        //check if input or dropdown has focus otherwise user has clicked somewhere else to close the dropdown. See Bug 32949
+                        //body.has(self) is needed to check if the input is still attached (may happen if you close mail compose with opened dropdown for example)
+                        if (self.val() && $('body').has(self).length && !self.is(document.activeElement) && !popup.has(document.activeElement).length) {
+                            //focus is outside so this can be handled as a blur
+                            self.trigger('blur');
+                        }
                         scrollpane.empty();
                         popup.detach();
                         isOpen = false;
@@ -283,8 +290,7 @@ define('io.ox/core/tk/autocomplete',
                     case 9:  // tab
                         e.preventDefault();
                         if (!e.shiftKey) { // ignore back-tab
-                            update();
-                            $(this).trigger('selected', scrollpane.children().eq(Math.max(0, index)).data());
+                            val = $.trim($(this).val(''));
                             close();
                         }
                         break;
