@@ -16,18 +16,21 @@ define('io.ox/core/tk/folderviews',
     ['io.ox/core/tk/selection',
      'io.ox/core/api/folder',
      'io.ox/core/api/user',
+     'io.ox/core/api/account',
      'io.ox/core/extensions',
      'io.ox/core/event',
      'io.ox/core/notifications',
      'io.ox/core/http',
      'io.ox/core/capabilities',
+     'settings!io.ox/core',
      'gettext!io.ox/core'
-    ], function (Selection, api, userAPI, ext, Events, notifications, http, capabilities, gt) {
+    ], function (Selection, api, userAPI, accountAPI, ext, Events, notifications, http, capabilities, settings, gt) {
 
     'use strict';
 
-    var OPEN = 'icon-chevron-right',
-        CLOSE = 'icon-chevron-down',
+    var OPEN = 'icon icon-chevron-right',
+        CLOSE = 'icon icon-chevron-down',
+        hasFolderIcons = settings.get('features/folderIcons', false),
 
         SMALL_FOLDER_PADDING = 15, // for small devices like smartphons
         DESKTOP_FOLDER_PADDING = 30, // for mouse-based devices (could be smaller but irrelevant) and for fat finger support
@@ -151,6 +154,21 @@ define('io.ox/core/tk/folderviews',
                     nodes.folder.removeAttr('aria-expanded');
                 }
                 nodes.arrow.find('i').attr('class', className);
+                if (hasFolderIcons) {
+                    var folderClass = 'icon icon-';
+                    if (accountAPI.is('trash', id)) {
+                        folderClass += 'trash special';
+                    } else if (accountAPI.is('inbox', id)) {
+                        folderClass += 'inbox special';
+                    } else if (accountAPI.is('sent', id)) {
+                        folderClass += 'upload-alt';
+                    } else if (accountAPI.is('drafts', id)) {
+                        folderClass += 'file-alt special';
+                    } else {
+                        folderClass += isOpen() ? 'folder-open-alt' : 'folder-close-alt';
+                    }
+                    nodes.icon.find('i').attr('class', folderClass);
+                }
                 if (childrenLoaded && !children) {
                     hideArrow();
                 }
@@ -394,7 +412,8 @@ define('io.ox/core/tk/folderviews',
 
                 if (nodes && nodes.arrow === undefined) {
                     // create DOM nodes
-                    nodes.arrow = $('<div class="folder-arrow" role="presentation"><i class="icon-chevron-right"></i></div>');
+                    nodes.arrow = $('<div class="folder-arrow" role="presentation"><i class="icon icon-chevron-right"></i></div>');
+                    nodes.icon = hasFolderIcons ? $('<div class="folder-icon" role="presentation"><i class="icon icon-folder"></i></div>') : $();
                     nodes.label = $('<div class="folder-label">');
                     nodes.counter = $('<div class="folder-counter">').append('<span class="folder-counter-badge">');
                     nodes.subscriber = $('<input>').attr({ 'type': 'checkbox', 'name': 'folder', tabindex: -1, 'value': data.id });
@@ -416,9 +435,9 @@ define('io.ox/core/tk/folderviews',
                         nodes.subscriber.prop('disabled', true);
                         nodes.subscriber.prop('checked', false);
                     }
-                    nodes.folder.append(nodes.arrow, $('<div>').addClass('subscribe-wrapper').append(nodes.subscriber), nodes.label, nodes.counter);
+                    nodes.folder.append(nodes.arrow, nodes.icon, $('<div>').addClass('subscribe-wrapper').append(nodes.subscriber), nodes.label, nodes.counter);
                 } else {
-                    nodes.folder.append(nodes.arrow, nodes.label, nodes.counter);
+                    nodes.folder.append(nodes.arrow, nodes.icon, nodes.label, nodes.counter);
                 }
                 // customize
                 self.customize();
@@ -473,7 +492,7 @@ define('io.ox/core/tk/folderviews',
         var self = this;
 
         $(container)
-            .addClass('io-ox-foldertree f6-target')
+            .addClass('io-ox-foldertree f6-target' + (hasFolderIcons ? ' folder-icons' : ''))
             .attr({ role: 'tree', 'aria-label': gt('Folder view') })
             // add tree container
             .append(this.container = $('<div class="folder-root">'));
@@ -521,7 +540,18 @@ define('io.ox/core/tk/folderviews',
                     self.selection.updateIndex();
                     self.trigger('repaint');
                     if (self.activeElement) {
+                        var folderview = self.activeElement.parents('.foldertree-container'),
+                            node, vertical, position;
+                        //identify usage: folder view or dialog
+                        node = (folderview.length ? folderview : self.activeElement.parents('.io-ox-foldertree')) || $();
+                        //set data to restore state
+                        vertical = node.scrollTop();
+                        position = node.css('position');
+                        //in some cases IE flickers without this hack
+                        node.css('position', 'fixed');
                         self.activeElement.focus();
+                        node.css('position', position)
+                            .scrollTop(vertical);
                     }
                     p.running = self.activeElement = null;
                 });
@@ -564,29 +594,25 @@ define('io.ox/core/tk/folderviews',
         }
 
         this.removeProcess = function (folder) {
-            api.remove({ folder: folder.id });
+            api.remove({ folder: folder.id }).fail(notifications.yell);
         };
 
         this.remove = function () {
-            var self = this,
-            folder_id = String(this.selection.get());
-            if (folder_id) {
-                $.when(
-                    api.get({ folder: folder_id }),
-                    require(['io.ox/core/tk/dialogs'])
-                ).done(function (folder, dialogs) {
-                    new dialogs.ModalDialog()
-                        .text(gt('Do you really want to delete folder "%s"?', folder.title))
-                        .addPrimaryButton('delete', gt('Delete'))
-                        .addButton('cancel', gt('Cancel'))
-                        .show()
-                        .done(function (action) {
-                            if (action === 'delete') {
-                                self.removeProcess(folder);
-                            }
-                        });
+            var self = this, folder_id = String(this.selection.get());
+            if (!folder_id) return;
+            $.when(
+                api.get({ folder: folder_id }),
+                require(['io.ox/core/tk/dialogs'])
+            ).done(function (folder, dialogs) {
+                new dialogs.ModalDialog()
+                .text(gt('Do you really want to delete folder "%s"?', folder.title))
+                .addPrimaryButton('delete', gt('Delete'))
+                .addButton('cancel', gt('Cancel'))
+                .show()
+                .done(function (action) {
+                    if (action === 'delete') self.removeProcess(folder);
                 });
-            }
+            });
         };
 
         this.renameProcess = function (folder, changes) {
@@ -623,7 +649,6 @@ define('io.ox/core/tk/folderviews',
                     }
                     new dialogs.ModalDialog({
                         async: true,
-                        easyOut: true,
                         width: 400
                     })
                     .header(
@@ -837,7 +862,7 @@ define('io.ox/core/tk/folderviews',
             }
 
             // set title
-            var shortTitle = api.getFolderTitle(data.title, 15);
+            var shortTitle = api.getFolderTitle(data.title, 20);
             label.attr('title', data.title).empty().append(
                 $('<span class="short-title">').text(_.noI18n(shortTitle)),
                 $('<span class="long-title">').text(_.noI18n(data.title))
@@ -846,13 +871,12 @@ define('io.ox/core/tk/folderviews',
 
             // set counter (mail only)
             if (options.type === 'mail') {
-                if (_.device('!small') && data.id === 'default0/INBOX' && (!data.unread  || data.unread === 0)) {//remove new mail title if inbox new-mail counter is 0
-                    document.fixedtitle = false;
-                    document.title = document.temptitle;
+                if (_.device('!small') && data.id === 'default0/INBOX' && (!data.unread  || data.unread === 0)) {
+                    // remove new mail title if inbox new-mail counter is 0
+                    require('io.ox/mail/api').newMailTitle(false);
                 }
                 if (data.unread && !options.checkbox) {
                     this.addClass('show-counter');
-
                     counter.find('span').text(gt.noI18n(data.unread || ''));
                 } else {
                     this.removeClass('show-counter');
@@ -1040,7 +1064,7 @@ define('io.ox/core/tk/folderviews',
             return $.when();
         };
 
-        api.on('delete', function () {
+        api.on('delete create', function () {
             self.repaint();
         });
     }
