@@ -1,30 +1,31 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
 
-define("io.ox/core/tk/keys", ["io.ox/core/event"], function (Events) {
-    "use strict";
+define('io.ox/core/tk/keys', ['io.ox/core/event'], function (Events) {
+
+    'use strict';
 
     var KEY_MAP = {
-        8: "backspace",
-        9: "tab",
-        13: "enter",
-        27: "esc",
-        32: "space",
-        37: "leftarrow",
-        38: "uparrow",
-        39: "rightarrow",
-        40: "downarrow",
-        46: "del"
+        8: 'backspace',
+        9: 'tab',
+        13: 'enter',
+        27: 'esc',
+        32: 'space',
+        37: 'leftarrow',
+        38: 'uparrow',
+        39: 'rightarrow',
+        40: 'downarrow',
+        46: 'del'
     };
 
     function translate(charCode) {
@@ -39,7 +40,7 @@ define("io.ox/core/tk/keys", ["io.ox/core/event"], function (Events) {
         } else {
             $node.on('dispose', function () {
                 if (included) {
-                    $node.off("keydown", handleEvent);
+                    $node.off('keydown', handleEvent);
                 }
             });
         }
@@ -47,16 +48,16 @@ define("io.ox/core/tk/keys", ["io.ox/core/event"], function (Events) {
         function handleEvent(evt) {
             var keys = [], expr;
             if (evt.shiftKey) {
-                keys.push("shift");
+                keys.push('shift');
             }
 
             if (evt.metaKey || evt.ctrlKey) {
-                keys.push("ctrl");
+                keys.push('ctrl');
             }
 
             keys.push(translate(evt.which));
 
-            expr = _.chain(keys).invoke("toLowerCase").sort().join("+").value();
+            expr = _.chain(keys).invoke('toLowerCase').sort().join('+').value();
             events.trigger(expr, evt);
         }
 
@@ -65,7 +66,7 @@ define("io.ox/core/tk/keys", ["io.ox/core/event"], function (Events) {
                 return;
             }
             included = true;
-            $node.on("keydown", handleEvent);
+            $node.on('keydown', handleEvent);
             return this;
         };
 
@@ -75,17 +76,17 @@ define("io.ox/core/tk/keys", ["io.ox/core/event"], function (Events) {
                 return;
             }
             included = false;
-            $node.off("keydown", handleEvent);
+            $node.off('keydown', handleEvent);
             return this;
         };
 
         function normalizeExpression(keyExpr) {
-            return _.chain(keyExpr.split(/[ +]+/)).invoke("toLowerCase").sort().join("+").value();
+            return _.chain(keyExpr.split(/[ +]+/)).invoke('toLowerCase').sort().join('+').value();
         }
 
         this.on = function (keyExpr, fn) {
             if (!keyExpr) {
-                throw new Error("Please specify a key expression");
+                throw new Error('Please specify a key expression');
             }
             events.on(normalizeExpression(keyExpr), fn);
             return this;
