@@ -61,7 +61,17 @@ define('io.ox/core/tk/vgrid',
         };
 
         this.getHeight = function () {
-            return isEmpty ? 0 : getHeight(this.getClone().node);
+            if (isEmpty) {
+                return 0;
+            } else {
+                // not sure if template ever contains more than one element
+                if (template[0].getHeight) {
+                    return template[0].getHeight();
+                } else {
+                    return getHeight(this.getClone().node);
+                }
+            }
+
         };
 
         this.getDefaultClassName = function () {
@@ -183,6 +193,24 @@ define('io.ox/core/tk/vgrid',
         this.reset();
     };
 
+    var onResize = function (e) {
+        e.preventDefault();
+        var left = $(this).closest('.leftside'),
+            right = left.siblings('.rightside'),
+            base = e.pageX - left.width(),
+            limitX = $(document).width() - 250;
+        $(document).on({
+            'mousemove.resize': function (e) {
+                var width = Math.max(250, Math.min(e.pageX, limitX) - base);
+                left.css('width', width);
+                right.css('left', width);
+            },
+            'mouseup.resize': function () {
+                $(this).off('mousemove.resize mouseup.resize');
+            }
+        });
+    };
+
     var VGrid = function (target, options) {
 
         options = _.extend({
@@ -341,6 +369,13 @@ define('io.ox/core/tk/vgrid',
                 return load.call(self, subset);
             });
 
+        // make resizalbe (unless touch device)
+        if (!_.device('touch')) {
+            node.append(
+                $('<div class="resizebar">').on('mousedown', onResize)
+            );
+        }
+
         // add label class
         template.node.addClass('selectable');
         label.node.addClass('vgrid-label').attr({ 'aria-hidden': 'true' });
@@ -350,6 +385,17 @@ define('io.ox/core/tk/vgrid',
             container.css('webkitTransform', 'translate3d(0, 0, 0)');
         }
 
+        // IE focus fix for bug 31617.
+        // "The focus event does not bubble in Internet Explorer"
+        // http://api.jquery.com/focus/
+        if (_.device('IE')) {
+            container.on('click', function () {
+                var top = scrollpane.scrollTop();
+                container.focus();
+                scrollpane.scrollTop(top);
+            });
+        }
+
         // add event hub
         Events.extend(this);
 
@@ -465,7 +511,7 @@ define('io.ox/core/tk/vgrid',
             return $.when.apply($, defs).pipe(function () {
                 var i, obj, node, top,
                     //isVisible is only needed in for loop; visible selectors are slow, avoid them if possible
-                    isVisible = $i > 0 ? container.is(':visible') : undefined,
+                    isVisible = $i > 0 ? container.show().is(':visible') : undefined,
                     height;
                 for (i = 0; i < $i; i++) {
                     obj = labels.list[i];
@@ -590,7 +636,7 @@ define('io.ox/core/tk/vgrid',
                     node = row.node[0];
                     node.className = defaultClassName + ' ' + ((offset + i) % 2 ? 'odd' : 'even');
                     // update fields
-                    row.update(data[i], offset + i, self.selection.serialize(data[i]), data[i - 1] || {});
+                    row.update(data[i], offset + i, self.selection.serialize(data[i]), data[i - 1] || {}, self);
                     node.style.top = shift + (offset + i) * itemHeight + 'px';
                     tmp[i] = row.node;
                 }
@@ -740,7 +786,7 @@ define('io.ox/core/tk/vgrid',
                 // non-existing items that cannot be resolved in selections
                 ids = _(ids).map(deserialize);
                 var selectionChanged = !self.selection.equals(ids), cid, index;
-                if (selectionChanged) {
+                if (selectionChanged && !self.selection.getMobileSelectMode()) {
                     // set
                     self.selection.set(ids);
                 }
@@ -847,6 +893,8 @@ define('io.ox/core/tk/vgrid',
                         .done(function () {
                             var hasChanged = !_.isEqual(all, list);
                             updateSelection(hasChanged);
+                            // global event
+                            ox.trigger('grid:stop', _.clone(props), list);
                         });
                 } else {
                     console.warn('VGrid.all() must provide an array!');
@@ -855,6 +903,8 @@ define('io.ox/core/tk/vgrid',
             }
 
             return function () {
+                // global event
+                ox.trigger('grid:start', _.clone(props));
                 // get all IDs
                 if (responsiveChange || all.length === 0) self.busy();
                 var load = loadIds[currentMode] || loadIds.all;
@@ -1206,6 +1256,7 @@ define('io.ox/core/tk/vgrid',
                 node.detach();
             });
             pool = [];
+            if (!initialized) return; // no need to update if not yet initialized
             init();
             this.repaint();
         };
