@@ -122,82 +122,3 @@ define('io.ox/core/util', function () {
         }())
     };
 });
-
-/*
-function test(val, expected) {
-    var util = require('io.ox/core/util'),
-        valid = util.isValidMailAddress(val) === expected;
-    console[valid ? 'log' : 'error'](val);
-}
-test('name@domain.com', true);
-test('name@host', true);
-test('name@1337', true);
-test('name@[1.2.3.4]', true);
-test('name@[1.2.3.4.5]', false);
-test('name@[1.2.3.A]', false);
-test('name@[1.2.3.4444]', false);
-test('name@[IPv6:2001:db8:1ff::a0b:dbd0]', true);
-test('name@[2001:db8:1ff::a0b:dbd0]', false);
-test('@domain.com', false);
-test('name@', false);
-test('@', false);
-test('name@abc@domain.com', false);
-test('first.last@domain.com', true);
-test('first,last@domain.com', false);
-test('first last@domain.com', false);
-test('first\\last@domain.com', false);
-test('first"last@domain.com', false);
-test('first..last@domain.com', false);
-test('.first.last@domain.com', false);
-test('"quoted"@domain.com', true);
-test('"another@"@domain.com', true);
-test('"but"not"@domain.com', false);
-*/
-
-/*
-function test(val, expected) {
-    var util = require('io.ox/core/util'),
-        valid = util.isValidPhoneNumber(val) === expected;
-    console[valid ? 'log' : 'error'](val);
-}
-test('', true);
-test(' ', true);
-test('01234567', true);
-test('0123 4567', true);
-test('+491234567', true);
-test('0123+4567', false);
-test('+49 (0) 1234567', true);
-test('+1', false);
-test('+49', false);
-test('+49 0 1234567', true);
-test('+49-0-1234567', true);
-test('+49-0-1234567#1', true);
-test('+49-0-1234567,1,2', true);
-test('+49.0.1234567', true);
-test('+49 0 / 1234567', true);
-test('+49 0 / 123456 - 7', true);
-test('+49 0 / 123456 - ABC', false);
-test('+49 0::1234567', false);
-test('+49 0 1234 [567]', false);
-test('++49 0 1234567', false);
-test('+49_0_1234567', false);
-test('+49 0 1234567 \\ 23', false);
-*/
-
-/*
-function test(val, expected) {
-    var util = require('io.ox/core/util'),
-        actual = util.breakableHTML(val),
-        valid = actual === expected;
-    if (valid) console.log(val)
-    else console.error(val, 'actual', actual, 'expected', expected);
-}
-test('', '');
-test(' ', ' ');
-test('Hello World', 'Hello World');
-test('Hello<br>World', 'Hello&lt;br&gt;World');
-test('com.openexchange.session.contextId=1337', 'com.<wbr>openexchange.<wbr>session.<wbr>contextId=<wbr>1337<wbr>');
-test('com.openexchange 01234567890123456789 01234567890123456789', 'com.openexchange 01234567890123456789 01234567890123456789');
-test('com.openexchange.0123456789012345678901234567890123456789', 'com.<wbr>openexchange.<wbr>012345678901234567890123456789<wbr>0123456789');
-
-*/
