@@ -1,17 +1,18 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
- * Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Francisco Laguna <francisco.laguna@open-xchange.com>
  */
-define("io.ox/dev/utils/live-coding-extension", ["io.ox/backbone/views"], function (views) {
-    "use strict";
+define('io.ox/dev/utils/live-coding-extension', ['io.ox/backbone/views'], function (views) {
+
+    'use strict';
 
     function LiveCodingExtension(options) {
         var self = this;
@@ -22,7 +23,7 @@ define("io.ox/dev/utils/live-coding-extension", ["io.ox/backbone/views"], functi
             }
             self.pending = true;
             $.ajax(options.url, {
-                dataType: "text",
+                dataType: 'text',
                 ifModified: true // E-Tag and LastModified Magic
             }).done(function (code) {
                 if (code) {
