@@ -33,8 +33,7 @@ define('io.ox/mail/accounts/settings',
 
         myView.dialog = new dialogs.ModalDialog({
             width: 600,
-            async: true,
-            tabTrap: true
+            async: true
         });
 
         myView.dialog.append(
@@ -193,6 +192,9 @@ define('io.ox/mail/accounts/settings',
                                 successDialog();
                                 def.resolve(response);
                             }
+                        }).fail(function (response) {
+                            popup.close();
+                            failDialog(response.error);
                         });
                     }
                 },
@@ -205,13 +207,18 @@ define('io.ox/mail/accounts/settings',
         },
 
         autoconfigApiCall = function (args, newMailaddress, newPassword, popup, def) {
+
             api.autoconfig({
                 'email': newMailaddress,
                 'password': newPassword
-            }).done(function (data) {
+            })
+            .done(function (data) {
                 if (data.login) {
                     data.primary_address = newMailaddress;
                     data.password = newPassword;
+                    // make sure not to set the SMTP credentials
+                    delete data.transport_login;
+                    delete data.transport_password;
                     validateMailaccount(data, popup, def);
                 } else {
                     var data = {};
@@ -247,8 +254,7 @@ define('io.ox/mail/accounts/settings',
                 new dialogs.ModalDialog({
                     width: 400,
                     async: true,
-                    enter: 'add',
-                    tabTrap: true
+                    enter: 'add'
                 })
                 .header(
                     $('<h4>').text(gt('Add mail account'))
@@ -302,8 +308,7 @@ define('io.ox/mail/accounts/settings',
             require(['io.ox/core/tk/dialogs'], function (dialogs) {
                 var successDialogbox = new dialogs.ModalDialog({
                         width: 400,
-                        async: true,
-                        tabTrap: true
+                        async: true
                     });
                 successDialogbox.header()
                 .append(
@@ -325,8 +330,7 @@ define('io.ox/mail/accounts/settings',
             require(['io.ox/core/tk/dialogs'], function (dialogs) {
                 var failDialogbox = new dialogs.ModalDialog({
                         width: 400,
-                        async: true,
-                        tabTrap: true
+                        async: true
                     });
                 failDialogbox.header()
                 .append(
