@@ -12,18 +12,17 @@
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
-define('io.ox/mail/accounts/view-form',
+define.async('io.ox/mail/accounts/view-form',
     ['io.ox/core/tk/view',
      'io.ox/core/notifications',
      'io.ox/core/api/account',
      'text!io.ox/mail/accounts/account_detail.html',
      'settings!io.ox/mail',
      'gettext!io.ox/settings/settings'
-    ], function (View, notifications, AccountAPI, tmpl, settings, gt) {
+    ], function (View, notifications, accountAPI, tmpl, settings, gt) {
 
     'use strict';
 
-
     var staticStrings =  {
             TITLE_ACCOUNT_SETTINGS: gt('Account settings'),
             ACCOUNT_NAME: gt('Account name'),
@@ -59,6 +58,11 @@ define('io.ox/mail/accounts/view-form',
 
         optionsRefreshRatePop = _([3, 5, 10, 15, 30, 60, 360]).map(gt.noI18n),
 
+        portDefaults = {
+            mail_port: '143',
+            transport_port: '587'
+        },
+
         //conditional defaults
         defaults = {
             pop3: {
@@ -72,16 +76,24 @@ define('io.ox/mail/accounts/view-form',
 
         validationCheck = function (data) {
 
-            data = _.extend({
-                unified_inbox_enabled: false,
-                transport_credentials: false
-            }, data);
-
+            data = _.extend({ unified_inbox_enabled: false /*, transport_auth: true */ }, data);
             data.name = data.personal = data.primary_address;
-
-            return AccountAPI.validate(data);
+            return accountAPI.validate(data);
         },
 
+        returnPortMail = function (model) {
+            var secure = model.get('mail_secure'),
+                protocol = model.get('mail_protocol') || 'imap';
+
+            if (protocol === 'imap') {
+                return secure ? '993' : '143';
+            } else {
+                return secure ? '995' : '110';
+            }
+        },
+
+        defaultDisplayName = '',
+
         AccountDetailView = Backbone.View.extend({
             tagName: 'div',
             _modelBinder: undefined,
@@ -93,9 +105,17 @@ define('io.ox/mail/accounts/view-form',
                 //check if login and mailaddress are synced
                 this.inSync = false;
 
-                oldModel = _.copy(this.model.attributes, true);
+                // use mail display name?
+                var personal = this.model.get('personal');
+                if (!personal) {
+                    this.model.set('personal', defaultDisplayName);
+                } else if (personal === ' ') {
+                    this.model.set('personal', '');
+                }
 
-                Backbone.Validation.bind(this, {selector: 'data-property', forceUpdate: true});//forceUpdate needed otherwise model is always valid even if inputfields contain wrong values
+                oldModel = _.copy(this.model.attributes, true);
+                // forceUpdate needed otherwise model is always valid even if inputfields contain wrong values
+                Backbone.Validation.bind(this, { selector: 'data-property', forceUpdate: true });
             },
             render: function () {
                 var self = this,
@@ -121,6 +141,28 @@ define('io.ox/mail/accounts/view-form',
                     model.set('login', value, {validate: true});
                 }
 
+                //just change port settings if this is a new account
+                if (self.model.get('id') === undefined) {
+
+                    //setting port defefaults
+                    _.each(portDefaults, function (value, key) {
+                        self.model.set(key, value);
+                    });
+
+                    self.model.on('change:mail_protocol', function (model) {
+                        self.model.set('mail_port', returnPortMail(model));
+                    });
+
+                    self.model.on('change:mail_secure', function (model) {
+                        self.model.set('mail_port', returnPortMail(model));
+                    });
+
+                    self.model.on('change:transport_secure', function (model, value) {
+                        var portValue = value ? '465' : '587';
+                        self.model.set('transport_port', portValue);
+                    });
+                }
+
                 if (self.model.get('id') !== 0) {//check for primary account
 
                     //refreshrate field needs to be toggled
@@ -207,40 +249,84 @@ define('io.ox/mail/accounts/view-form',
                         // dialog is already gone, tell the user that something is happening
                         notifications.yell('busy', gt('Updating account data. This might take a few seconds.'));
                     }
-                    self.model.save()
-                    .done(function (data) {
-                        self.dialog.close();
-                        if (self.collection) {
-                            self.collection.add([data]);
+
+                    // revert default display name
+                    var personal = self.model.get('personal');
+                    if (personal === defaultDisplayName) {
+                        self.model.set('personal', null, { silent: true }); // empty!
+                    } else if ($.trim(personal) === '') {
+                        self.model.set('personal', ' ', { silent: true }); // yep, one space!
+                    }
+
+                    self.model.save().then(
+                        function success(data) {
+                            self.dialog.close();
+                            if (self.collection) {
+                                self.collection.add([data]);
+                            }
+                            if (self.model.isNew()) {
+                                self.succes();
+                            } else {
+                                notifications.yell('success', gt('Account updated'));
+                            }
+                        },
+                        function fail(data) {
+                            if (data.code === 'ACC-0004' && data.error_params[0].substring(8, 13) === 'login') {//string comparison is ugly, maybe backend has a translated version of this
+                                notifications.yell('error', gt('Username must not be empty.'));
+                            } else if (data.code === 'SVL-0002') {
+                                notifications.yell('error',
+                                   //#. %1$s the missing request parameter
+                                   //#, c-format
+                                   gt('Please enter the following data: %1$s', _.noI18n(data.error_params[0])));
+                            } else {
+                                notifications.yell('error', _.noI18n(data.error));
+                            }
+                            self.dialog.idle();
                         }
-                        if (self.model.isNew()) {
-                            self.succes();
-                        } else {
-                            notifications.yell('success', gt('Account updated'));
-                        }
-                    })
-                    .fail(function (data) {
-                        if (data.code === 'ACC-0004' && data.error_params[0].substring(8, 13) === 'login') {//string comparison is ugly, maybe backend has a translated version of this
-                            notifications.yell('error', gt('Username must not be empty.'));
-                        } else if (data.code === 'SVL-0002') {
-                            notifications.yell('error',
-                               //#. %1$s the missing request parameter
-                               //#, c-format
-                               gt('Please enter the following data: %1$s', _.noI18n(data.error_params[0])));
-                        } else {
-                            notifications.yell('error', _.noI18n(data.error));
-                        }
-                        self.dialog.idle();
-                    });
+                    );
                 }
 
                 if (needToValidate(list, differences)) {
-                    validationCheck(this.model.attributes).done(function (response) {
-                        if (response) {
-                            saveAccount();
-                        } else {
-                            notifications.yell('error', gt('This account cannot be validated'));
+                    validationCheck(this.model.attributes).done(function (response, error) {
+                        //an undefined response variable implies an error (f.e. category 'USER_INPUT')
+                        var hasError = _.isUndefined(response) || (error ? [].concat(error.categories || []).indexOf('ERROR') > -1 : false),
+                            hasWarning = error && error.warnings;
+
+                        if (hasError) {
+                            //on error yell
+                            notifications.yell(error);
                             self.dialog.idle();
+                        } else if (hasWarning) {
+                            //on warning ask user
+                            require(['io.ox/core/tk/dialogs'], function (dialogs) {
+                                var messages = _.map([].concat(error.warnings), function (warn) {
+                                    return $('<div>')
+                                            .addClass('alert alert-warning')
+                                            .css('margin', '10px')
+                                            .text(warn.error);
+                                });
+
+                                new dialogs.ModalDialog()
+                                    .header(
+                                        $('<h4>').text(gt('Warnings'))
+                                    )
+                                    .build(function () {
+                                        this.getContentNode().append(messages);
+                                    })
+                                    .addPrimaryButton('proceed', gt('Ignore Warnings'))
+                                    .addButton('cancel', gt('Cancel'))
+                                    .show()
+                                    .done(function (action) {
+                                        if (action === 'proceed') {
+                                            saveAccount();
+                                        } else {
+                                            self.dialog.idle();
+                                        }
+                                    });
+                            });
+                        } else {
+                            //on success save
+                            saveAccount();
                         }
                     });
                 } else {
@@ -293,6 +379,8 @@ define('io.ox/mail/accounts/view-form',
             }
         });
 
-
-    return AccountDetailView;
+    return accountAPI.getDefaultDisplayName().then(function (name) {
+        defaultDisplayName = name;
+        return AccountDetailView;
+    });
 });
