@@ -264,7 +264,7 @@ define('io.ox/mail/api',
             },
             list: {
                 action: 'list',
-                columns: '102,600,601,602,603,604,605,607,610,611,614,652',
+                columns: '102,600,601,602,603,604,605,607,608,610,611,614,652',
                 extendColumns: 'io.ox/mail/api/list'
             },
             get: {
@@ -298,7 +298,7 @@ define('io.ox/mail/api',
         },
         // composite key for 'all' cache
         cid: function (o) {
-            return (o.action || 'all') + ':' + o.folder + DELIM + [o.sort, o.order, o.max || 0, !!o.unseen, !!o.deleted].join('.');
+            return (o.action || 'all') + ':' + o.folder + DELIM + [o.sort, o.order, o.limit || 0, o.max || 0, !!o.unseen, !!o.deleted].join('.');
         },
 
         fail: {
@@ -380,8 +380,8 @@ define('io.ox/mail/api',
         NORMAL:  '0',
         REPLY:   '1',
         FORWARD: '2',
-        DRAFT:   '3',
-        EDIT_DRAFT: '4'
+        EDIT_DRAFT: '3',
+        DRAFT:   '4'
     };
 
     api.FLAGS = {
@@ -417,7 +417,6 @@ define('io.ox/mail/api',
     var cacheControl = {},
         getAll = api.getAll,
         getList = api.getList,
-        get = api.get,
         remove = api.remove,
         search = api.search;
 
@@ -452,23 +451,6 @@ define('io.ox/mail/api',
         });
     };
 
-    /**
-     * pipes get() to remove typesuffix from sender
-     * @param  {object} options
-     * @param  {boolan} useCache (default is true)
-     * @fires api#refresh.list
-     * @return {deferred} (resolve returns response)
-     */
-    api.get = function (options, useCache) {
-        //TOOD: use this until backend removes channel suffix
-        return get.call(this, options, useCache).then(function (mail) {
-            if (_.isObject(mail)) {
-                util.removeChannelSuffix(mail);
-            }
-            return mail;
-        });
-    };
-
     api.search = function (query, options) {
         if (options.sort === 'from-to') {
             options.sort = accountAPI.is('sent|drafts', options.folder) ? 604 : 603;
@@ -1008,6 +990,19 @@ define('io.ox/mail/api',
             });
     };
 
+    api.autosave = function (obj) {
+        return http.PUT({
+            module: 'mail',
+            params: {
+                action: 'autosave'
+            },
+            data: obj,
+            appendColumns: false
+        }).pipe(function (data) {
+            return $.Deferred().resolve(data);
+        });
+    };
+
     var react = function (action, obj, view) {
 
         // get proper view first
@@ -1223,6 +1218,7 @@ define('io.ox/mail/api',
         }
 
         api.trigger('beforesend', { data: data, files: files, form: form });
+        ox.trigger('mail:send:start', data, files);
 
         if (Modernizr.filereader && 'FormData' in window) {
             deferred = handleSendXHR2(data, files, deferred);
@@ -1233,6 +1229,7 @@ define('io.ox/mail/api',
         return deferred
             .done(function () {
                 api.trigger('send', { data: data, files: files, form: form });
+                ox.trigger('mail:send:stop', data, files);
             })
             .then(function (text) {
                 // wait a moment, then update mail index
@@ -1243,7 +1240,7 @@ define('io.ox/mail/api',
                         accountAPI.getFoldersByType('sent'),
                         accountAPI.getFoldersByType('drafts')
                     );
-                    $.when.apply(
+                    $.when.apply($,
                         _(folders).map(function (id) {
                             return api.caches.all.grepRemove(id + DELIM);
                         })
@@ -1283,14 +1280,8 @@ define('io.ox/mail/api',
 
     function handleSendXHR2(data, files) {
 
-        var form = new FormData(),
-            deleteDraftOnTransport;
-        if (data.deleteDraft || settings.get('features/alwaysDeleteDraft', false)) {//don't send temporary flag
-            deleteDraftOnTransport = true;
-            delete data.deleteDraft;
-        } else if (settings.get('features/alwaysDeleteDraft', false)) {
-            deleteDraftOnTransport = data.sendtype === api.SENDTYPE.EDIT_DRAFT;
-        }
+        var form = new FormData();
+
         // add mail data
         form.append('json_0', JSON.stringify(data));
         // add files
@@ -1302,7 +1293,6 @@ define('io.ox/mail/api',
             module: 'mail',
             params: {
                 action: 'new',
-                deleteDraftOnTransport: deleteDraftOnTransport
             },
             data: form,
             dataType: 'text'
@@ -1310,9 +1300,7 @@ define('io.ox/mail/api',
     }
 
     function handleSendTheGoodOldWay(data, form) {
-        if (data.deleteDraft) {//don't send temporary flag
-            delete data.deleteDraft;
-        }
+
         return http.FORM({
             module: 'mail',
             action: 'new',
@@ -1392,7 +1380,7 @@ define('io.ox/mail/api',
                 });
             } else {
                 // single EML
-                url += (first.subject ? '/' + encodeURIComponent(first.subject.replace(/[\\:]/g, '_') + '.eml') : '') + '?' +
+                url += (first.subject ? '/' + encodeURIComponent(first.subject.replace(/[\\:\/]/g, '_') + '.eml') : '') + '?' +
                     $.param($.extend(api.reduce(first), {
                         action: 'get',
                         src: 1,
@@ -1403,7 +1391,7 @@ define('io.ox/mail/api',
             }
         } else {
             // inject filename for more convenient file downloads
-            url += (data.filename ? '/' + encodeURIComponent(data.filename.replace(/[\\:]/g, '_')) : '') + '?' +
+            url += (data.filename ? '/' + encodeURIComponent(data.filename.replace(/[\\:\/]/g, '_')) : '') + '?' +
                 $.param({
                     action: 'attachment',
                     folder: (data.parent || data.mail).folder_id,
@@ -1620,6 +1608,24 @@ define('io.ox/mail/api',
             });
     };
 
+    // send delivery receipt
+    // data must include "folder" and "id"
+    api.ack = function (data) {
+
+        return accountAPI.getPrimaryAddressFromFolder(data.folder).then(function (addressArray) {
+
+            var name = addressArray[0],
+                address = addressArray[1],
+                from = !name ? address : '"' + name + '" <' + address + '>';
+
+            return http.PUT({
+                module: 'mail',
+                params: { action: 'receipt_ack' },
+                data: _.extend({ from: from }, data)
+            });
+        });
+    };
+
     // change API's default options if allowHtmlMessages changes
     settings.on('change:allowHtmlMessages', function (e, value) {
         api.options.requests.get.view = value ? 'noimg' : 'text';
@@ -1659,17 +1665,30 @@ define('io.ox/mail/api',
      * @param  {boolean} state
      * @return {undefined}
      */
-    api.newMailTitle = function (state) {
-        if (_.device('!small')) {
-            if (state === true) {//show new mail title
-                document.fixedtitle = true;
-                document.title = gt('New Mail');
-            } else {//stop showing new mail title
-                document.fixedtitle = false;
-                document.title = document.temptitle;
-            }
+    api.newMailTitle = (function () {
+
+        var interval = null, alt = false;
+
+        function tick() {
+            document.title = (alt = !alt) ? gt('New Mail') : document.customTitle;
         }
-    };
+
+        function blink() {
+            if (interval) return;
+            interval = setInterval(tick, 1500); // 1s is fast, 2s feels slow, 1.5 is compromise
+        }
+
+        function original() {
+            document.title = document.customTitle;
+            if (interval) { clearInterval(interval); interval = null; }
+        }
+
+        return function (state) {
+            if (_.device('small')) return;
+            if (state === true) blink(); else original();
+        };
+
+    }());
 
     return api;
 });
