@@ -1,30 +1,26 @@
 /**
- * All content on this website (including text, images, source code and any
- * other original works), unless otherwise noted, is licensed under a Creative
- * Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011 Mail: info@open-xchange.com
+ * © 2011 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
-define('io.ox/mail/autoforward/settings/view-form', [
-    'io.ox/mail/autoforward/settings/model',
-    'io.ox/backbone/views',
-    'io.ox/backbone/forms',
-    'io.ox/core/extPatterns/actions',
-    'io.ox/core/extPatterns/links',
-    'io.ox/core/date',
-    'io.ox/core/notifications',
-    'gettext!io.ox/mail',
-    'less!io.ox/mail/autoforward/settings/style.less'
-], function (model, views, forms, actions, links, date, notifications, gt) {
+define('io.ox/mail/autoforward/settings/view-form',
+    ['io.ox/mail/autoforward/settings/model',
+     'io.ox/backbone/views',
+     'io.ox/backbone/forms',
+     'less!io.ox/mail/autoforward/settings/style.less'
+    ], function (model, views, forms) {
 
-    "use strict";
+    'use strict';
 
-    function createAutoForwardEdit(ref, multiValues) {
+    function createAutoForwardEdit(ref) {
         var point = views.point(ref + '/edit/view'),
             VacationEditView = point.createView({
                 tagName: 'div',
