@@ -5,11 +5,12 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Julian Bäume <julian.baeume@open-xchange.com>
  */
-define('io.ox/mail/emoji/settings/defaults', [], function () {
+define('io.ox/mail/emoji/settings/defaults', function () {
 
     'use strict';
 
