@@ -93,6 +93,52 @@ define('io.ox/mail/mailfilter/settings/filter/view-form',
             '$cl_10': '10'
         },
 
+        adjustRulePosition = function (models) {
+            var position, firstPos, secondPos,
+                posibleStaticFilters = _.last(models, 2),
+                getStaticFilterStatus =  function (model) {
+                if (model.length === 0) {
+                    return '0';
+                } else if (model.length === 1) {
+                    firstPos = _.isEqual(model[0].get('flags'), ['vacation']) ? _.isEqual(model[0].get('flags'), ['vacation']) : _.isEqual(model[0].get('flags'), ['autoforward']);
+                } else {
+                    firstPos = _.isEqual(model[0].get('flags'), ['vacation']) ? _.isEqual(model[0].get('flags'), ['vacation']) : _.isEqual(model[0].get('flags'), ['autoforward']);
+                    secondPos = _.isEqual(model[1].get('flags'), ['vacation']) ? _.isEqual(model[1].get('flags'), ['vacation']) : _.isEqual(model[1].get('flags'), ['autoforward']);
+                }
+                if (firstPos && secondPos === undefined) {
+                    return '3';
+                } else if (firstPos && secondPos) {
+                    return '2';
+                } else if (!firstPos && secondPos) {
+                    return '1';
+                } else if (!firstPos && !secondPos) {
+                    return '0';
+                }
+            };
+
+            switch (getStaticFilterStatus(posibleStaticFilters)) {
+            case '0':
+                break;
+            case '1':
+                position = posibleStaticFilters[1].attributes.position;
+                posibleStaticFilters[1].attributes.position = posibleStaticFilters[1].attributes.position + 1;
+                break;
+            case '2':
+                position = posibleStaticFilters[0].get('position');
+                posibleStaticFilters[0].set('position', posibleStaticFilters[0].attributes.position + 1);
+                posibleStaticFilters[1].set('position', posibleStaticFilters[1].attributes.position + 1);
+                break;
+            case '3':
+                position = posibleStaticFilters[0].attributes.position;
+                posibleStaticFilters[0].attributes.position = posibleStaticFilters[0].attributes.position + 1;
+                break;
+            default:
+                break;
+            }
+
+            return position;
+        },
+
         checkForMultipleTests = function (el) {
             return $(el).find('[data-test-id]');
         },
@@ -180,7 +226,34 @@ define('io.ox/mail/mailfilter/settings/filter/view-form',
             },
 
             onSave: function () {
-                var self = this;
+                var self = this,
+                    rulePosition,
+                    actionArray = this.model.get('actioncmds');
+
+                function returnKeyForStop(actionsArray) {
+                    var indicatorKey;
+                    _.each(actionsArray, function (action, key) {
+                        if (_.isEqual(action, {id: 'stop'})) {
+                            indicatorKey = key;
+                        }
+                    });
+                    return indicatorKey;
+                }
+
+                if (!this.model.has('id')) {
+                    rulePosition = adjustRulePosition(self.options.listView.collection.models);
+                    if (rulePosition !== undefined) {
+                        this.model.set('position', rulePosition);
+                    }
+                }
+
+                // if there is a stop action it should always be the last
+                if (returnKeyForStop(actionArray) !== undefined) {
+                    actionArray.splice(returnKeyForStop(actionArray), 1);
+                    actionArray.push({id: 'stop'});
+                    this.model.set('actioncmds', actionArray);
+                }
+
                 this.model.save().then(function (id) {
                     //first rule gets 0
                     if (!_.isUndefined(id) && !_.isNull(id)) {
@@ -357,7 +430,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form',
                 require(['io.ox/core/tk/dialogs', 'io.ox/core/tk/folderviews'], function (dialogs, views) {
 
                     var label = gt('Select folder'),
-                        dialog = new dialogs.ModalDialog({ easyOut: true, tabTrap: true })
+                        dialog = new dialogs.ModalDialog()
                         .header($('<h4>').text(label))
                         .addPrimaryButton('select', label, 'select', {tabIndex: '1'})
                         .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
@@ -640,7 +713,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form',
                     return currentPosition;
                 }
 
-                if (currentState === 'checked') {
+                if (currentState === true) {
                     arrayOfActions.splice(getCurrentPosition(arrayOfActions), 1);
 
                 } else {
@@ -656,7 +729,7 @@ define('io.ox/mail/mailfilter/settings/filter/view-form',
 
             function checkForStopAction(array) {
                 var stopAction;
-                if (!baton.model.id) { // default value
+                if (baton.model.id === undefined) { // default value
                     return true;
                 }
 
