@@ -39,7 +39,7 @@ define('io.ox/mail/main',
             e.preventDefault();
             var option = $(this).attr('data-option'),
                 grid = e.data.grid;
-            if (/^(603|607|610|102|thread|from-to)$/.test(option)) {
+            if (/^(603|607|608|610|102|thread|from-to)$/.test(option)) {
                 grid.prop('sort', option).refresh();
                 // sort must not react to the prop change event because autotoggle uses this too and would mess up the persistent settings
                 //grid.updateSettings('sort', option);
@@ -98,7 +98,12 @@ define('io.ox/mail/main',
             showSwipeButton = false,
             canDeletePermission;
         left = vsplit.left.addClass('border-right');
-        right = vsplit.right.addClass('mail-detail-pane').scrollable();
+        right = vsplit.right.addClass('mail-detail-pane')
+                .attr({
+                    'role': 'complementary',
+                    'aria-label': gt('Mail Details')
+                })
+                .scrollable();
 
         ext.point('io.ox/mail/vgrid/options').extend({
             max: _.device('smartphone') ? 50: settings.get('threadMax', 500),
@@ -181,31 +186,42 @@ define('io.ox/mail/main',
         // threadview is based on a 500 (default) mail limit
         // in order to view all mails in a folder we offer a link
         options.tail = function (all) {
-            var threadSort = this.prop('sort') === 'thread',
+            var isThread = this.prop('sort') === 'thread',
+                useLimit = this.prop('limit') || isThread,
                 inAllMode = this.getMode() === 'all',
                 isUnreadOnly = this.prop('unread'),
-                hideTail = !threadSort || !inAllMode || isUnreadOnly,
+                hideTail = !useLimit || !inAllMode || isUnreadOnly,
                 count = 0;
             // hide?
             if (hideTail) return $();
             // complex count
             count = _(all).reduce(function (sum, obj) {
-                return sum + obj.thread.length;
+                return sum + (obj.thread ? obj.thread.length : 1);
             }, 0);
-            if (count < this.option('max')) return $();
+            if (this.prop('limit')) {
+                if (all.length < this.prop('limit')) return $();
+            }
+            else if (isThread && count < this.option('max')) return $();
             // show tail
             return $('<div class="vgrid-cell tail">').append(
-                $('<a href="#" tabindex="-1">').text(gt('Show all mails. Note: Mails are no longer grouped by conversation.'))
+                $('<a href="#" tabindex="-1">').text(
+                    isThread ?
+                        gt('Show all mails. Note: Mails are no longer grouped by conversation.') :
+                        settings.get('gridLimitLabel') || gt('Show all mails.')
+                )
             );
         };
 
         grid = new VGrid(left, options);
         commons.addPropertyCaching(grid, {props: ['sort', 'order'], keyprop: 'folder'});
 
+        var LIMIT = settings.get('gridLimit', 0);
+        grid.prop('limit', LIMIT);
+
         // tail click
         left.on('click', '.vgrid-cell.tail', function (e) {
             e.preventDefault();
-            grid.prop('sort', '610').refresh();
+            grid.prop('limit', 0).prop('sort', 610).refresh();
         });
 
         // add template
@@ -217,12 +233,12 @@ define('io.ox/mail/main',
             canDeletePermission = undefined;
             // remove delete button
             removeButton();
+            // reset limit
+            grid.prop('limit', LIMIT);
             // reset "unread only"
             grid.prop('unread', false);
             // template changes for unified mail
-
             var unified = account.parseAccountId(folder, true) === 0 ? false : folderAPI.is('unifiedfolder', folder);
-
             if (unified !== tmpl.unified) {
                 tmpl.unified = unified;
                 grid.updateTemplates();
@@ -285,6 +301,7 @@ define('io.ox/mail/main',
                 buildOption('from-to', gt('From')),
                 buildOption(102, gt('Label')),
                 buildOption(607, gt('Subject')),
+                buildOption(608, gt('Size')),
                 $('<li class="divider">'),
                 buildOption('asc', gt('Ascending')),
                 buildOption('desc', gt('Descending')),
@@ -491,12 +508,23 @@ define('io.ox/mail/main',
             this.prop('sort', options.sort);
             call = options.sort === 'thread' ? 'getAllThreads' : 'getAll';
 
+            // limit?
+            if (this.prop('limit')) options.limit = '0,' + this.prop('limit');
+
             return api[call](options, 'auto').then(function (response) {
                 var data = response.data || response;
                 return unread ? filterUnread(data) : data;
             });
         });
 
+        var notify = function (response) {
+            //show 'In order to accomplish the search, x or more characters are required.'
+            if (response && response.code && response.code === 'MSG-0068') {
+                notifications.yell('error', response.error);
+            }
+            return this;
+        };
+
         grid.setAllRequest('search', function () {
             var options = win.search.getOptions(),
                 unread = grid.prop('unread');
@@ -506,7 +534,7 @@ define('io.ox/mail/main',
             options.order = grid.prop('order');
             return api.search(win.search.query, options).then(function (data) {
                 return unread ? filterUnread(data) : data;
-            });
+            }, notify);
         });
 
         grid.setListRequest(function (ids) {
@@ -589,7 +617,27 @@ define('io.ox/mail/main',
                     delete openThreads[index];
                     icon(cid, 'right');
                     api.getList(thread).done(function (list) {
-                        grid.selection.remove(list.slice(1));
+                        var items = list.slice(1),
+                            selected = grid.selection.get(),
+                            hash = {}, valid = [];
+
+                        //hash thread-summary-items
+                        _.each(items, function (item) {
+                            hash[_.cid(item)] = true;
+                        });
+                        //remove thread-summary-item from current selection
+                        valid = _.filter(selected, function (item) {
+                            return !hash[_.cid(item)];
+                        });
+                        //use latest thread mail when no valid targets exists
+                        valid = valid.length ? valid : valid.concat(list[0]);
+                        //special case: thread head is selected
+                        if (valid.length === 1 && (_.cid(valid[0]) === _.cid(list[0]))) {
+                            showMail(list[0]);
+                        } else {
+                            grid.selection.set(valid);
+                            grid.selection.remove(items);
+                        }
                         refresh();
                     });
                 }
@@ -628,6 +676,9 @@ define('io.ox/mail/main',
                         toggle(index, cid);
                     }
                 }
+                if (sel.length >= 1 && key === 46) { // delete
+                    actions.invoke('io.ox/mail/actions/delete', null, sel);
+                }
             });
 
             // reset on folder change
@@ -681,6 +732,9 @@ define('io.ox/mail/main',
         // customize selection
         grid.selection.unfold = function () {
             return _.flatten(_(this.get()).map(function (o) {
+                if (grid.prop('sort') !== 'thread') {
+                    return o;
+                }
                 return isInOpenThreadSummary(o) ? o : api.getThread(o);
             }), true);
         };
@@ -704,6 +758,8 @@ define('io.ox/mail/main',
                 }
                 // be busy
                 right.idle().busy(!update);
+                // global event
+                ox.trigger('mail:detail:start', thread[0]);
                 // get first mail first
                 api.get(api.reduce(thread[0]))
                     .done(_.lfo(drawThread, baton, update))
@@ -711,6 +767,9 @@ define('io.ox/mail/main',
             } else {
                 // be busy
                 right.idle().busy(true);
+                // global event
+                ox.trigger('mail:detail:start', obj);
+                // load
                 api.get(api.reduce(obj))
                     .done(_.lfo(drawMail))
                     .fail(_.lfo(drawFail, obj));
@@ -792,8 +851,8 @@ define('io.ox/mail/main',
                 start: function () {
                     win.busy();
                 },
-                progress: function (file) {
-                    return api.importEML({ file: file, folder: app.folder.get() })
+                progress: function (item) {
+                    return api.importEML({ file: item.file, folder: item.options.folder })
                         .done(function (data) {
                             var first = _(data.data || []).first() || {};
                             if ('Error' in first) {
@@ -838,15 +897,11 @@ define('io.ox/mail/main',
         });
 
         // search
-        (function () {
-
-            ext.point('io.ox/mail/search/defaults').extend({
-                from: true,
-                to: true,
-                cc: true,
-                subject: true
-            });
+        function initSearch() {
+            var isSentfolder = (app.folder.get() === app.settings.get('defaultFolder/sent')) ? true : false,
+                searchSettingId = isSentfolder ? 'mail.search.sent' : 'mail.search';
 
+            //available 'checkboxes'
             ext.point('io.ox/mail/search/checkboxes').extend({
                 from: true,
                 to: true,
@@ -855,36 +910,54 @@ define('io.ox/mail/main',
                 text: true
             });
 
+            //defines preselected 'checkboxes' when user enters search first time
+            ext.point('io.ox/mail/search/defaults').extend({
+                from: true,
+                to: true,
+                cc: true,
+                subject: true
+            });
+
             var translations = { from: gt('Sender'), to: gt('Recipient'), cc: gt('CC'), subject: gt('Subject'), text: gt('Mail text') },
                 checkboxes = ext.point('io.ox/mail/search/checkboxes').options(),
                 defaults = ext.point('io.ox/mail/search/defaults').options(),
+                dataSettings = settings.get('options/' + searchSettingId, {}),
                 data = {}, button;
 
-            //normalise data
-            _(checkboxes).each(function (flag, name) {
-                if (flag === true) {
-                    data[name] = {
-                        name: name,
-                        label: translations[name] || name,
-                        checked: defaults[name] || false
-                    };
+            //prepare data
+            _(checkboxes).each(function (enabled, name) {
+                //only available checkboxes
+                if (enabled) {
+                    data[name] = $.extend(
+                        //defaults
+                        { checked: defaults[name] || false, name: name, label: translations[name] || name },
+                        //checked last time?
+                        { checked: (dataSettings[name] || {}).checked }
+                    );
                 }
             });
 
             //add dropdown button
             button = $('<button type="button" data-action="search-options" class="btn fixed-btn search-options" aria-hidden="true">')
                     .append('<i class="icon-gear">');
+            win.nodes.search.find('.dropdown').remove();
             win.nodes.search.find('.search-query-container').after(button);
 
             //add dropdown menue
             dropdownOptions({
-                id: 'mail.search',
+                id: searchSettingId,
                 anchor: button,
                 defaults: data,
                 settings: settings
             });
 
-        }());
+        }
+
+        initSearch();
+
+        app.on('folder:change', function () {
+            initSearch();
+        });
 
         // drag & drop
         win.nodes.outer.on('selection:drop', function (e, baton) {
