@@ -1,26 +1,22 @@
 /**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+ * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
+ * LICENSE. This work is protected by copyright and/or other applicable
+ * law. Any use of the work other than as authorized under this license
+ * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2012
- * Mail: info@open-xchange.com
+ * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
-define('io.ox/mail/settings/model',
-      ['settings!io.ox/mail'], function (settings) {
+define('io.ox/mail/settings/model', ['settings!io.ox/mail'], function (settings) {
 
     'use strict';
 
     var mailSettingsModel = Backbone.Model.extend({
 
-
-        initialize: function (options) {
-
-        },
+        initialize: $.noop,
 
         save: function () {
             return settings.save(this.attributes);
@@ -31,7 +27,7 @@ define('io.ox/mail/settings/model',
         },
 
         destroy: function () {
-            console.log("destroy in model.js");
+            console.log('destroy in model.js');
         }
 
     });
