@@ -113,6 +113,7 @@ define('io.ox/mail/util',
          */
         getChannel: function (value, check) {
             //default value
+            value = String(value || '');
             check = check || typeof check === 'undefined';
             var type = value.indexOf(that.getChannelSuffixes().msisdn) > -1,
                 //no check OR activated cap
@@ -341,19 +342,15 @@ define('io.ox/mail/util',
         getPriority: function (data) {
             // normal?
             if (data && data.priority === 3) return $();
-            var i = '<i class="icon-exclamation"/>',
-                indicator = $('<span>').append(_.noI18n('\u00A0'), i, i, i);
-            if (data && data.priority < 3) {
-                return indicator.addClass('high').attr('title', gt('High priority'));
-            } else {
-                return indicator.addClass('low').attr('title', gt('Low priority'));
-            }
+            if (data && data.priority < 3) return $('<span class="high"><i class="icon-exclamation"/></span>').attr('title', gt('High priority'));
+            return $('<span class="low"><i class="icon-minus"/></span>').attr('title', gt('Low priority'));
         },
 
         getAccountName: function (data) {
             // primary account?
             var id = window.unescape(data ? data.id : '');
-            return (/^default0/).test(id) ? gt('Primary account') : (data ? data.account_name : 'N/A');
+            if ((/^default0/).test(id)) return gt('Primary account');
+            return (data && data.account_name) || 'N/A';
         },
 
         getTime: function (timestamp) {
@@ -458,6 +455,67 @@ define('io.ox/mail/util',
             return mailArray._wrapped[0];
         },
 
+        fixInlineImages: function (data) {
+            return data
+                .replace(new RegExp('(<img[^>]+src=")' + ox.abs + ox.apiRoot), '$1/ajax')
+                .replace(new RegExp('(<img[^>]+src=")' + ox.apiRoot, 'g'), '$1/ajax')
+                .replace(/on(mousedown|contextmenu)="return false;"\s?/g, '')
+                .replace(/data-mce-src="[^"]+"\s?/, '');
+        },
+
+        signatures: (function () {
+            var htmltags = /(<([^>]+)>)/ig,
+                nothing = /.^/,
+                general = function (text) {
+                    return String(text || '')
+                        //replace white-space and evil \r
+                        .replace(/(\r\n|\n|\r)/g, '\n')
+                        //replace subsequent white-space (except linebreaks)
+                        .replace(/[\t\f\v ][\t\f\v ]+/g, ' ')
+                        .trim();
+                },
+                add = function (text, isHTML) {
+                    return general(text)
+                        //remove html tags (for plaintext emails)
+                        .replace(isHTML ? nothing : htmltags, '');
+                },
+                preview = function (text) {
+                    return general(text)
+                        //remove ASCII art (intended to remove separators like '________')
+                        .replace(/([\-=+*°._!?\/\^]{4,})/g, '')
+                        //remove htmltags
+                        .replace(htmltags, '')
+                        .trim();
+                };
+            return {
+                cleanAdd: function (text, isHTML) {
+                    return add(text, !!isHTML);
+                },
+                cleanPreview: function (text) {
+                    return preview(text);
+                },
+                is: function (text, list, isHTML) {
+                    var clean,
+                        signatures = _(list).map(function (signature) {
+                            //consider changes applied by appsuite
+                            clean = add(signature.content, !!isHTML);
+                            //consider changes applied by tiny
+                            if (clean === '')
+                                return '<br>';
+                            else {
+                                return clean
+                                        //replace surrounding white-space (except linebreaks)
+                                        .replace(/>[\t\f\v ]+/g, '>')
+                                        .replace(/[\t\f\v ]+</g, '<')
+                                        //set breaks
+                                        .replace(/(\r\n|\n|\r)/g, '<br>');
+                            }
+                        });
+                    return _(signatures).indexOf(text) > - 1;
+                }
+            };
+        })(),
+
         getAttachments: (function () {
 
             var isWinmailDATPart = function (obj) {
