@@ -15,14 +15,16 @@
 define('io.ox/portal/main',
     ['io.ox/core/extensions',
      'io.ox/core/api/user',
+     'io.ox/contacts/api',
      'io.ox/core/date',
      'io.ox/core/tk/dialogs',
      'io.ox/portal/widgets',
+     'io.ox/portal/util',
      'io.ox/portal/settings/pane',
      'gettext!io.ox/portal',
      'settings!io.ox/portal',
      'less!io.ox/portal/style.less'
-    ], function (ext, userAPI, date, dialogs, widgets, settingsPane, gt, settings) {
+    ], function (ext, userAPI, contactAPI, date, dialogs, widgets, util, settingsPane, gt, settings) {
 
     'use strict';
 
@@ -47,13 +49,6 @@ define('io.ox/portal/main',
         });
     }
 
-    function setColor(node, model) {
-        var color = node.attr('data-color');
-        node.removeClass('widget-color-' + color);
-        color = model.get('color') || 'black';
-        node.addClass('widget-color-' + color).attr('data-color', color);
-    }
-
     // portal header
     ext.point('io.ox/portal/sections').extend({
         id: 'header',
@@ -110,48 +105,70 @@ define('io.ox/portal/main',
     });
 
     // widget scaffold
+
     ext.point('io.ox/portal/widget-scaffold').extend({
+        id: 'attributes',
+        index: 100,
         draw: function (baton) {
-
-            this
-                .attr({
-                    'data-widget-cid': baton.model.cid,
-                    'data-widget-id': baton.model.get('id'),
-                    'data-widget-type': baton.model.get('type')
-                })
-                .addClass('widget' + (baton.model.get('inverse') ? ' inverse' : ''))
-                .append(
-                    // border decoration
-                    $('<div>')
-                        .addClass('decoration pending')
-                        .append(
-                            $('<h2>').append(
-                                // add remove icon
-                                baton.model.get('protectedWidget') ? [] :
-                                    $('<a class="disable-widget"><i class="icon-remove"/></a>')
-                                    .attr({
-                                        href: '#',
-                                        role: 'button',
-                                        'title': gt('Disable widget'),
-                                        'aria-label': gt('Disable widget'),
-                                        tabindex: 1
-                                    }),
-                                // title span
-                                $('<span class="title">').text('\u00A0')
-                            )
-                        )
-                );
-
-            setColor(this, baton.model);
+            this.attr({
+                'data-widget-cid': baton.model.cid,
+                'data-widget-id': baton.model.get('id'),
+                'data-widget-type': baton.model.get('type')
+            });
         }
     });
 
+    ext.point('io.ox/portal/widget-scaffold').extend({
+        id: 'classes',
+        index: 200,
+        draw: function (baton) {
+            this.addClass('widget' + (baton.model.get('inverse') ? ' inverse' : ''))
+                .addClass(baton.model.get('protectedWidget') || false ? ' protected' : ' draggable');
+        }
+    });
+
+    ext.point('io.ox/portal/widget-scaffold').extend({
+        id: 'default',
+        index: 300,
+        draw: function (baton) {
+            this.append(
+                // border decoration
+                $('<div class="decoration pending">').append(
+                    $('<h2>').append(
+                        // add remove icon
+                        baton.model.get('protectedWidget') ? [] :
+                            $('<a class="disable-widget"><i class="icon-remove"/></a>')
+                            .attr({
+                                href: '#',
+                                role: 'button',
+                                'title': gt('Disable widget'),
+                                'aria-label': gt('Disable widget'),
+                                tabindex: 1
+                            }),
+                        // title span
+                        $('<span class="title">').text('\u00A0')
+                    )
+                )
+            );
+        }
+    });
+
+    ext.point('io.ox/portal/widget-scaffold').extend({
+        id: 'color',
+        index: 400,
+        draw: function (baton) {
+            util.setColor(this, baton.model.get('color'));
+        }
+    });
+
+
+
     // application object
     var app = ox.ui.createApp({ name: 'io.ox/portal', title: 'Portal' }),
         win,
         scrollPos = window.innerHeight,
         appBaton = ext.Baton({ app: app }),
-        sidepopup = new dialogs.SidePopup(),
+        sidepopup = new dialogs.SidePopup({tabTrap: true}),
         collection = widgets.getCollection();
 
     app.settings = settings;
@@ -166,6 +183,7 @@ define('io.ox/portal/main',
                 model.set('baton', null, {validate: true});
                 model.isDeleted = true;
             }
+            widgets.save(appBaton.$.widgets);
         })
         .on('add', function (model) {
             app.drawScaffold(model, true);
@@ -185,7 +203,10 @@ define('io.ox/portal/main',
                     app.getWidgetNode(model).hide();
                 }
             } else if ('color' in model.changed) {
-                setColor(app.getWidgetNode(model), model);
+                util.setColor(app.getWidgetNode(model), model.get('color'));
+            } else if ('title' in model.changed) {
+                //change name
+                app.getWidgetNode(model).find('.title').text(model.get('title'));
             } else if (this.wasElementDeleted(model)) {
                 // element was removed, no need to refresh it.
                 return;
@@ -214,8 +235,6 @@ define('io.ox/portal/main',
         return !_(haystack).some(function (suspiciousHay) {return suspiciousHay.cid === needle; });
     };
 
-
-
     app.getWidgetCollection = function () {
         return collection;
     };
@@ -282,8 +301,13 @@ define('io.ox/portal/main',
         baton.model.node
             .addClass('requires-setup')
             .append(
-                $('<div class="content">').text(gt('Click here to add your account'))
+                $('<div class="content" tabindex="1" role="button">').text(gt('Click here to add your account'))
                 .on('click', { baton: baton }, setup)
+                .on('keypress', { baton: baton }, function (e) {
+                    if (e.which === 13) {
+                        setup(e);
+                    }
+                })
             );
     };
 
@@ -304,6 +328,10 @@ define('io.ox/portal/main',
             decoration = node.find('.decoration');
         return $.when.apply($, defs).done(function () {
                 node.find('.content').remove();
+                // draw summary only on small devices, i.e. smartphones
+                if (_.device('smartphone')) {
+                    point.invoke('summary', node, baton);
+                }
                 point.invoke('preview', node, baton);
                 node.removeClass('error-occurred');
                 decoration.removeClass('pending error-occurred');
@@ -428,12 +456,20 @@ define('io.ox/portal/main',
             simple: _.device('smartphone')
         }));
 
-        win.nodes.main.addClass('io-ox-portal f6-target').attr('tabindex', '1');
+        win.nodes.main.addClass('io-ox-portal f6-target').attr({
+            'tabindex': '1',
+            'role': 'main',
+            'aria-label': gt('Portal Widgets')
+        });
 
         ext.point('io.ox/portal/sections').invoke('draw', win.nodes.main, appBaton);
 
         app.updateTitle();
         _.tick(1, 'hour', app.updateTitle);
+        //change name if username changes
+        userAPI.get(ox.user_id).done(function (userData) {
+            contactAPI.on('update:' + _.ecid({folder_id: userData.folder_id, id: userData.contact_id}), app.updateTitle);
+        });
 
         win.show(function () {
             // draw scaffolds now for responsiveness
@@ -461,13 +497,13 @@ define('io.ox/portal/main',
                         .append($('<span>').text(gt('Do you really want to delete this widget?')))
                         .addPrimaryButton('delete',
                             //#. Really delete portal widget - in contrast to "just disable"
-                            gt('Delete')
+                            gt('Delete'), 'delete', {tabIndex: '1'}
                         )
-                        .addButton('cancel', gt('Cancel'));
+                        .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
                         if (model.get('enabled')) {
                             dialog.addAlternativeButton('disable',
                                 //#. Just disable portal widget - in contrast to delete
-                                gt('Just disable widget')
+                                gt('Just disable widget'), 'disable', {tabIndex: '1'}
                             );
                         }
                         dialog.show().done(function (action) {
@@ -506,6 +542,8 @@ define('io.ox/portal/main',
             if (!Modernizr.touch) {
                 require(['apps/io.ox/core/tk/jquery-ui.min.js']).done(function () {
                     appBaton.$.widgets.sortable({
+                        items: '> li.draggable',
+                        cancel: 'li.protected',
                         containment: win.nodes.main,
                         scroll: true,
                         delay: 150,
@@ -526,7 +564,7 @@ define('io.ox/portal/main',
 
         $(window).on('scrollstop resize', lazyLayout);
     });
-    window.kacke = app;
+
     return {
         getApp: app.getInstance
     };
