@@ -205,7 +205,7 @@ define('io.ox/portal/settings/pane',
 
         var node = $(this),
             list = node.closest('.widget-list'),
-            items = list.children(),
+            items = list.children('.draggable'),
             current = node.parent(),
             index = items.index(current),
             id = current.attr('data-widget-id');
@@ -219,14 +219,14 @@ define('io.ox/portal/settings/pane',
         case 38:
             if (index > 0) { // up
                 e.preventDefault();
-                current.insertBefore(current.prev());
+                current.insertBefore(current.prevAll('.draggable:first'));
                 cont();
             }
             break;
         case 40:
             if (index < items.length) { // down
                 e.preventDefault();
-                current.insertAfter(current.next());
+                current.insertAfter(current.nextAll('.draggable:first'));
                 cont();
             }
             break;
@@ -244,12 +244,15 @@ define('io.ox/portal/settings/pane',
                 point = ext.point(baton.view.point),
                 title = widgets.getTitle(data, point.prop('title'));
             this
-                .addClass('draggable')
-                .attr('title', gt('Drag to reorder widget'))
+                .addClass(data.protectedWidget && data.protectedWidget === true ? ' protected' : ' draggable')
                 .append(
-                    $('<a href="#" class="drag-handle">')
+                    data.protectedWidget && data.protectedWidget === true ? $() :
+                    $('<a>')
+                    .addClass('drag-handle')
                     .attr({
+                        href: '#',
                         'aria-label': title + ', ' + gt('Use cursor keys to change the item position'),
+                        'title': gt('Drag to reorder widget'),
                         role: 'button',
                         tabindex: 1
                     })
@@ -365,15 +368,19 @@ define('io.ox/portal/settings/pane',
             this.append(list.empty());
 
             collection.each(function (model) {
-                list.append(createView(model).render().el);
+                if (model.get('protectedWidget') !== true || model.get('enabled') !== false) {
+                    list.append(createView(model).render().el);
+                }
             });
 
             // make sortable
             list.sortable({
                 axis: 'y',
-                containment: this,
+                containment: list.parent().parent(),
                 delay: 150,
                 handle: '.drag-handle',
+                cancel: 'li.protected',
+                items: '> li.draggable',
                 start: function (e, ui) {
                     ui.item.attr('aria-grabbed', 'true');
                 },
@@ -397,7 +404,9 @@ define('io.ox/portal/settings/pane',
                     this.sort({ silent: true });
                     list.empty();
                     this.each(function (model) {
-                        list.append(createView(model).render().el);
+                        if (model.get('protectedWidget') !== true || model.get('enabled') !== false) {
+                            list.append(createView(model).render().el);
+                        }
                     });
                 });
         }
