@@ -111,13 +111,13 @@ define('io.ox/portal/settings/widgetview',
                 .append($('<span>').text(gt('Do you really want to delete this widget?')))
                 .addPrimaryButton('delete',
                     //#. Really delete portal widget - in contrast to "just disable"
-                    gt('Delete')
+                    gt('Delete'), 'delete', {tabIndex: '1'}
                 )
-                .addButton('cancel', gt('Cancel'));
+                .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
                 if (this.model.get('enabled')) {
                     dialog.addAlternativeButton('disable',
                         //#. Just disable portal widget - in contrast to delete
-                        gt('Just disable widget')
+                        gt('Just disable widget'), 'disable', {tabIndex: '1'}
                     );
                 }
                 dialog.show().done(function (action) {
