@@ -32,6 +32,12 @@ define('io.ox/portal/util', ['settings!io.ox/portal'], function (settings) {
             return _(this.getWidgets()).filter(function (obj) {
                 return obj.type === type;
             });
+        },
+
+        setColor: function (node, color) {
+            color = color || 'black';
+            node.removeClass('widget-color-' + node.attr('data-color'));
+            node.addClass('widget-color-' + color).attr('data-color', color);
         }
     };
 });
