@@ -5,12 +5,13 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2012 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/settings/accounts/settings/defaults', [], function () {
+define('io.ox/settings/accounts/settings/defaults', function () {
 
     'use strict';
 
