@@ -17,8 +17,9 @@ define('io.ox/tasks/actions',
      'io.ox/core/extPatterns/links',
      'gettext!io.ox/tasks',
      'io.ox/core/notifications',
-     'io.ox/core/print'
-    ], function (ext, util, links, gt, notifications, print) {
+     'io.ox/core/print',
+     'io.ox/core/extPatterns/actions'
+    ], function (ext, util, links, gt, notifications, print, actions) {
 
     'use strict';
 
@@ -37,9 +38,7 @@ define('io.ox/tasks/actions',
     });
 
     new Action('io.ox/tasks/actions/edit', {
-        requires: function (e) {
-            return e.collection.has('one');
-        },
+        requires: 'one modify',
         action: function (baton) {
             ox.load(['io.ox/tasks/edit/main']).done(function (m) {
                 if (m.reuse('edit', baton.data)) return;
@@ -56,8 +55,8 @@ define('io.ox/tasks/actions',
             ox.load(['io.ox/core/tk/dialogs']).done(function (dialogs) {
                 //build popup
                 var popup = new dialogs.ModalDialog({async: true})
-                    .addPrimaryButton('deleteTask', gt('Delete'))
-                    .addButton('cancel', gt('Cancel'));
+                    .addPrimaryButton('deleteTask', gt('Delete'), 'deleteTask', {tabIndex: '1'})
+                    .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
                 //Header
                 popup.getBody()
                     .append($('<h4>')
@@ -98,7 +97,10 @@ define('io.ox/tasks/actions',
 
     new Action('io.ox/tasks/actions/done', {
         requires: function (e) {
-            return (e.baton.data.length  !== undefined || e.baton.data.status !== 3);
+            if (!(e.collection.has('some') && e.collection.has('modify'))) {
+                return false;
+            }
+            return (e.baton.data.status !== 3);
         },
         action: function (baton) {
             changeState(baton, 1);
@@ -107,6 +109,9 @@ define('io.ox/tasks/actions',
 
     new Action('io.ox/tasks/actions/undone', {
         requires: function (e) {
+            if (!(e.collection.has('some') && e.collection.has('modify'))) {
+                return false;
+            }
             return (e.baton.data.length  !== undefined || e.baton.data.status === 3);
         },
         action: function (baton) {
@@ -165,7 +170,30 @@ define('io.ox/tasks/actions',
     }
 
     new Action('io.ox/tasks/actions/move', {
-        requires: 'some delete',
+        requires: function (e) {
+            if (!(e.collection.has('some') && e.collection.has('delete'))) {
+                return false;
+            } else {
+                var def = $.Deferred();
+                ox.load(['io.ox/core/api/folder'])
+                    .done(function (folderApi) {
+                        var data = e.baton.data;
+                        if (data.length) {//multiselection
+                            data = data[0];
+                        }
+                        folderApi.get({folder: data.folder_id}).done(function (folder) {
+                            if (folderApi.is('shared', folder)) {//no move in shared folders see Bug 33706
+                                def.resolve(false);
+                            } else {
+                                def.resolve(true);
+                            }
+                        }).fail(function () {
+                            def.resolve(false);
+                        });
+                    });
+                return def;
+            }
+        },
         multiple: function (list, baton) {
             var task = baton.data,
                 numberOfTasks = task.length || 1,
@@ -186,21 +214,35 @@ define('io.ox/tasks/actions',
                 }
 
                 if (baton.target) {
-                    commit(baton.target);
+                    var curFolder;
+
+                    if (task.length) {//multiselection
+                        curFolder = task[0].folder_id;
+                    } else {
+                        curFolder = task.folder_id;
+                    }
+                    $.when(folderAPI.get({folder: curFolder}), folderAPI.get({folder: baton.target})).done(function (currentFolder, targetFolder) {
+                        if (folderAPI.is('shared', currentFolder) || folderAPI.is('shared', targetFolder)) {//no move in shared folders see Bug 33706
+                            notifications.yell('error', gt('Tasks can not be moved to or out of shared folders'));
+                        } else {
+                            commit(baton.target);
+                        }
+                    });
                 } else {
 
                     //build popup
                     var popup = new dialogs.ModalDialog()
                         .header($('<h4>').text(gt('Move')))
-                        .addPrimaryButton('ok', gt('Move'))
-                        .addButton('cancel', gt('Cancel'));
+                        .addPrimaryButton('ok', gt('Move'), 'ok', {tabIndex: '1'})
+                        .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
                     popup.getBody().css({ height: '250px' });
                     var tree = new views.FolderList(popup.getBody(), {
                             type: 'tasks',
-                            tabindex: 0
+                            tabindex: 0,
+                            dialogmode: true
                         }),
                         id = String(task.folder || task.folder_id);
-                    //go
+
                     popup.show(function () {
                         tree.paint().done(function () {
                             tree.select(id).done(function () {
@@ -223,10 +265,10 @@ define('io.ox/tasks/actions',
                                     node.parent().idle();
                                     notifications.yell('success', gt.ngettext('Task moved.', 'Tasks moved.', numberOfTasks));
                                 })
-                                .fail(function () {
+                                .fail(function (e) {
                                     node.show();
                                     node.parent().idle();
-                                    notifications.yell('error', gt('A severe error occurred!'));
+                                    notifications.yell(e);
                                 });
                             }
                         }
@@ -368,7 +410,7 @@ define('io.ox/tasks/actions',
                      'io.ox/preview/main',
                      'io.ox/core/api/attachment']).done(function (dialogs, p, attachmentAPI) {
                 //build Sidepopup
-                new dialogs.SidePopup().show(baton.e, function (popup) {
+                new dialogs.SidePopup({ tabTrap: true }).show(baton.e, function (popup) {
                     _(list).each(function (data) {
                         data.dataURL = attachmentAPI.getUrl(data, 'view');
                         var pre = new p.Preview(data, {
@@ -393,7 +435,7 @@ define('io.ox/tasks/actions',
 
     new Action('io.ox/tasks/actions/open-attachment', {
         id: 'open',
-        requires: 'some',
+        requires: 'one',
         multiple: function (list) {
             ox.load(['io.ox/core/api/attachment']).done(function (attachmentAPI) {
                 _(list).each(function (data) {
@@ -484,6 +526,7 @@ define('io.ox/tasks/actions',
 
     //strange workaround because extend only takes new links instead of plain objects with draw method
     new Action('io.ox/tasks/actions/placeholder', {
+        requires: 'one modify',
         action: $.noop
     });
 
@@ -501,29 +544,25 @@ define('io.ox/tasks/actions',
                     .text(gt('Change due date')).append($('<b class="caret">')).dropdown(),
                     // drop down
                     $('<ul class="dropdown-menu dropdown-right" role="menu">').append(
-                        util.buildDropdownMenu({time: new Date(), bootstrapDropdown: true, daysOnly: true})
+                        util.buildDropdownMenu({bootstrapDropdown: true, daysOnly: true})
                     )
-                    .on('click', 'li>a:not([data-action="close-menu"])', {task: data}, function (e) {
+                    .on('click', 'li>a:not([data-action="close-menu"])', { task: data }, function (e) {
                         e.preventDefault();
                         var finderId = $(e.target).val();
                         ox.load(['io.ox/tasks/api']).done(function (api) {
-                            var endDate = util.computePopupTime(new Date(), finderId).alarmDate, modifications;
-                            //remove Time
-                            endDate.setHours(0);
-                            endDate.setMinutes(0);
-                            endDate.setSeconds(0);
-                            endDate.setMilliseconds(0);
-
-                            modifications = {end_date: endDate.getTime(),
-                                             id: e.data.task.id,
-                                             folder_id: e.data.task.folder_id || e.data.task.folder};
+                            var endDate = util.computePopupTime(finderId).endDate,
+                                modifications = {
+                                    end_date: endDate,
+                                    id: e.data.task.id,
+                                    folder_id: e.data.task.folder_id || e.data.task.folder
+                                };
 
                             //check if startDate is still valid with new endDate, if not, show dialog
-                            if (e.data.task.start_date && e.data.task.start_date > endDate.getTime()) {
+                            if (e.data.task.start_date && e.data.task.start_date > endDate) {
                                 require(['io.ox/core/tk/dialogs'], function (dialogs) {
                                     var popup = new dialogs.ModalDialog()
-                                        .addButton('cancel', gt('Cancel'))
-                                        .addPrimaryButton('change', gt('Adjust start date'));
+                                        .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'})
+                                        .addPrimaryButton('change', gt('Adjust start date'), 'changechange', {tabIndex: '1'});
                                     //text
                                     popup.getBody().append(
                                         $('<h4>').text(gt('Inconsistent dates')),
@@ -556,6 +595,94 @@ define('io.ox/tasks/actions',
         }
     }));
 
+    // delete tasks
+    ext.point('io.ox/tasks/mobileMultiSelect/toolbar').extend({
+        id: 'delete',
+        index: 10,
+        draw: function (data) {
+            var baton = new ext.Baton({data: data.data});
+            $(this).append($('<div class="toolbar-button">')
+                .append($('<a href="#">')
+                    .append(
+                        $('<i class="fa fa-trash-o">')
+                            .on('click', {grid: data.grid}, function (e) {
+                                e.preventDefault();
+                                e.stopPropagation();
+                                actions.invoke('io.ox/tasks/actions/delete', null, baton);
+                                e.data.grid.selection.clear();
+                            })
+                    )
+                )
+            );
+        }
+    });
+
+    // tasks done
+    ext.point('io.ox/tasks/mobileMultiSelect/toolbar').extend({
+        id: 'done',
+        index: 20,
+        draw: function (data) {
+            var baton = new ext.Baton({data: data.data});
+            $(this).append($('<div class="toolbar-button">')
+                .append($('<a href="#">')
+                    .append(
+                        $('<i class="fa fa-check-square-o">')
+                            .on('click', {grid: data.grid}, function (e) {
+                                e.preventDefault();
+                                e.stopPropagation();
+                                actions.invoke('io.ox/tasks/actions/done', null, baton);
+                                e.data.grid.selection.clear();
+                            })
+                    )
+                )
+            );
+        }
+    });
+
+    // tasks undone
+    ext.point('io.ox/tasks/mobileMultiSelect/toolbar').extend({
+        id: 'unDone',
+        index: 30,
+        draw: function (data) {
+            var baton = new ext.Baton({data: data.data});
+            $(this).append($('<div class="toolbar-button">')
+                .append($('<a href="#">')
+                    .append(
+                        $('<i class="fa fa-square-o">')
+                            .on('click', {grid: data.grid}, function (e) {
+                                e.preventDefault();
+                                e.stopPropagation();
+                                actions.invoke('io.ox/tasks/actions/undone', null, baton);
+                                e.data.grid.selection.clear();
+                            })
+                    )
+                )
+            );
+        }
+    });
+
+    // tasks move
+    ext.point('io.ox/tasks/mobileMultiSelect/toolbar').extend({
+        id: 'move',
+        index: 40,
+        draw: function (data) {
+            var baton = new ext.Baton({data: data.data});
+            $(this).append($('<div class="toolbar-button">')
+                .append($('<a href="#">')
+                    .append(
+                        $('<i class="fa fa-sign-in">')
+                            .on('click', {grid: data.grid}, function (e) {
+                                e.preventDefault();
+                                e.stopPropagation();
+                                actions.invoke('io.ox/tasks/actions/move', null, baton);
+                                e.data.grid.selection.clear();
+                            })
+                    )
+                )
+            );
+        }
+    });
+
     ext.point('io.ox/tasks/links/inline').extend(new links.Link({
         id: 'move',
         index: 500,
@@ -612,7 +739,7 @@ define('io.ox/tasks/actions',
     ext.point('io.ox/tasks/attachment/links').extend(new links.Link({
         id: 'save',
         index: 400,
-        label: gt('Save in file store'),
+        label: gt('Save to drive'),
         ref: 'io.ox/tasks/actions/save-attachment'
     }));
 });
