@@ -244,7 +244,7 @@ define('io.ox/tasks/api',
                 } else if (obj.folder_id) {
                     folder = obj.folder_id;
                 } else {
-                    console.log('no folderAttribute for cache Keygen found, using default');
+                    //no folderAttribute for cache Keygen found, using default
                     folder = folderAPI.getDefaultFolder('tasks');
                 }
             }
@@ -263,7 +263,7 @@ define('io.ox/tasks/api',
             },
             list: {
                 action: 'list',
-                columns: '1,20,101,200,202,203,220,300,301,309',
+                columns: '1,2,20,101,200,202,203,220,300,301,309',
                 extendColumns: 'io.ox/tasks/api/list',
                 timezone: 'UTC'
             },
@@ -532,7 +532,7 @@ define('io.ox/tasks/api',
         }
 
         function filter(task) {
-            return task.participants.length === 0 || delegatedToMe(task.participants);
+            return !task.participants || task.participants.length === 0 || delegatedToMe(task.participants);
         }
 
         return function () {
