@@ -36,6 +36,7 @@ define('io.ox/tasks/main',
         // nodes
         left,
         right,
+        dropdownNode,
         //VGridToolbarOptions
         taskToolbarOptions = function (e) {
             e.preventDefault();
@@ -71,7 +72,13 @@ define('io.ox/tasks/main',
 
         var vsplit = commons.vsplit(win.nodes.main, app);
         left = vsplit.left.addClass('border-right');
-        right = vsplit.right.addClass('default-content-padding f6-target task-detail-container').attr('tabindex', 1).scrollable();
+        right = vsplit.right.addClass('default-content-padding f6-target task-detail-container')
+            .attr({
+                'tabindex': 1,
+                'role': 'complementary',
+                'aria-label': gt('Task Details')
+            })
+            .scrollable();
 
         var removeButton = function () {
             if (showSwipeButton) {
@@ -127,7 +134,7 @@ define('io.ox/tasks/main',
         grid = new VGrid(left, {
             settings: settings,
             swipeRightHandler: swipeRightHandler,
-            showToggle: _.device('smartphone') ? false: true,
+            showToggle: true,
         });
 
         grid.addTemplate(template.main);
@@ -135,6 +142,16 @@ define('io.ox/tasks/main',
         commons.wireGridAndAPI(grid, api);
         commons.wireGridAndSearch(grid, win, api);
 
+        var notify = function (response) {
+            //show 'In order to accomplish the search, x or more characters are required.'
+            if (response && response.code && response.code === 'TSK-0051') {
+                require(['io.ox/core/notifications'], function (notifications) {
+                    notifications.yell('error', response.error);
+                });
+            }
+            return this;
+        };
+
         //custom requests
         var allRequest = function () {
                 var datacopy,
@@ -197,7 +214,7 @@ define('io.ox/tasks/main',
                         });
                     }
                     return datacopy;
-                });
+                }, notify);
             };
 
         grid.setAllRequest(allRequest);
@@ -252,13 +269,16 @@ define('io.ox/tasks/main',
         grid.prop('order', 'asc');
 
         function updateGridOptions() {
+            if (!dropdownNode) {
+                return;
+            }
             var dropdown = grid.getToolbar().find('.grid-options'),
-                list = dropdown.find('ul'),
                 props = grid.prop();
+
             // uncheck all
-            list.find('i').attr('class', 'icon-none');
+            dropdownNode.find('i').removeClass('icon-ok');
             // check right options
-            list.find(
+            dropdownNode.find(
                     '[data-option="' + props.sort + '"], ' +
                     '[data-option="' + props.order + '"], ' +
                     '[data-option="' + (props.done ? 'done' : '~done') + '"]'
@@ -312,7 +332,7 @@ define('io.ox/tasks/main',
                     $('<a href="#" tabindex="1" data-toggle="dropdown" role="menuitem" aria-haspopup="true">').attr('aria-label', gt('Sort options'))
                     .append($('<i class="icon-arrow-down">'), $('<i class="icon-arrow-up">'))
                     .dropdown(),
-                    $('<ul class="dropdown-menu" role="menu">')
+                    dropdownNode = $('<ul class="dropdown-menu" role="menu">')
                     .append(
                         $('<li>').append($('<a href="#" data-option="state">').text(gt('Status')).prepend($('<i>'))), // state becomes Bundesland :)
                         $('<li>').append($('<a href="#" data-option="202">').text(gt('Due date')).prepend($('<i>'))),
