@@ -5,12 +5,13 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('plugins/mobile/ios-resize/register', [], function () {
+define('plugins/mobile/ios-resize/register', function () {
 
     'use strict';
 
