@@ -30,23 +30,25 @@ define('plugins/portal/birthdays/register',
         return String(name).toLowerCase().replace(/ä/g, 'ae').replace(/ö/g, 'oe').replace(/ü/g, 'ue').replace(/ß/g, 'ss');
     }
 
-    function markDuplicate(name, hash) {
-        name = unifySpelling(name);
-        hash[name] = true;
+    function cid(name, birthday) {
+        return unifySpelling(name) + ':' + birthday.format('YYYYMMDD');
     }
 
-    function isDuplicate(name, hash) {
-        name = unifySpelling(name);
-        return name in hash;
+    function markDuplicate(name, birthday, hash) {
+        hash[cid(name, birthday)] = true;
+    }
+
+    function isDuplicate(name, birthday, hash) {
+        return cid(name, birthday) in hash;
     }
 
     ext.point('io.ox/portal/widget/birthdays').extend({
 
-        title: gt('Next birthdays'),
+        title: gt('Birthdays'),
 
         load: function (baton) {
             var aDay = 24 * 60 * 60 * 1000,
-                start = _.now() - aDay, // yes, one could try to calculate 00:00Z this day, but hey...
+                start = new date.UTC().setHours(0, 0, 0, 0).getTime() - aDay,
                 end = start + WEEKS * aDay * 7;
             return api.birthdays({ start: start, end: end, right_hand_limit: 25 }).done(function (data) {
                 baton.data = data;
@@ -55,7 +57,7 @@ define('plugins/portal/birthdays/register',
 
         preview: function (baton) {
 
-            var $list = $('<div class="content">'),
+            var $list = $('<ul class="content list-unstyled" tabindex="1" role="button" aria-label="' +  gt('Press [enter] to jump to complete list of Birthdays.') + '">'),
                 hash = {},
                 contacts = baton.data,
                 numOfItems = _.device('small') ? 5 : 15;
@@ -68,27 +70,36 @@ define('plugins/portal/birthdays/register',
 
             if (contacts.length === 0) {
                 $list.append(
-                    $('<div class="line">').text(gt('No birthdays within the next %1$d weeks', WEEKS))
+                    $('<li class="line">').text(gt('No birthdays within the next %1$d weeks', WEEKS))
                 );
             } else {
                 $list.addClass('pointer');
                 _(contacts.slice(0, numOfItems)).each(function (contact) {
-                    var birthday = new date.UTC(contact.birthday),
+                    var birthday = new date.UTC(contact.birthday).setHours(0, 0, 0, 0),//just to be sure hours are the same
+                        birthdayText = '',
+                        today = new date.UTC().setHours(0, 0, 0, 0).setYear(birthday.getYear()),//it's not really today, its today in the year of the birthday
                         name = util.getFullName(contact);
-                    if (birthday.getYear() === 1) {//Year 0 is special for birthdays without year (backend changes this to 1...)
-                        birthday = birthday.format(date.DATE_NOYEAR);
+
+                    if (birthday.getTime() === today.getTime()) {//today
+                        birthdayText = gt('Today');
+                    } else if (birthday.getTime() === today.getTime() + date.DAY) {//tomorrow
+                        birthdayText = gt('Tomorrow');
+                    } else if (birthday.getTime() === today.getTime() - date.DAY) {//yesterday
+                        birthdayText = gt('Yesterday');
+                    } else if (birthday.getYear() === 1) {//Year 0 is special for birthdays without year (backend changes this to 1...)
+                        birthdayText = birthday.format(date.DATE_NOYEAR);
                     } else {
-                        birthday = birthday.format(date.DATE);
+                        birthdayText = birthday.format(date.DATE);
                     }
 
-                    if (!isDuplicate(name, hash)) {
+                    if (!isDuplicate(name, birthday, hash)) {
                         $list.append(
-                            $('<div class="line">').append(
+                            $('<li class="line">').append(
                                 $('<span class="bold">').text(name), $.txt(' '),
-                                $('<span class="accent">').text(_.noI18n(birthday))
+                                $('<span class="accent">').text(_.noI18n(birthdayText))
                             )
                         );
-                        markDuplicate(name, hash);
+                        markDuplicate(name, birthday, hash);
                     }
                 });
             }
@@ -101,7 +112,7 @@ define('plugins/portal/birthdays/register',
             var hash = {}, $list;
 
             $list = $('<div class="io-ox-portal-birthdays">').append(
-                $('<h1>').text(gt('Next birthdays'))
+                $('<h1>').text(gt('Birthdays'))
             );
 
             if (baton.data.length === 0) {
@@ -122,15 +133,15 @@ define('plugins/portal/birthdays/register',
                 }
                 // loop
                 _(baton.data).each(function (contact) {
-                    var utc = date.Local.utc(contact.birthday), birthday, next, now, days, delta,
+                    var utc = date.Local.utc(contact.birthday), next, now, days, delta,
+                        birthday = new date.Local(utc),
                         // we use fullname here to avoid haveing duplicates like "Jon Doe" and "Doe, Jon"
                         name = util.getFullName(contact);
 
-                    if (!isDuplicate(name, hash)) {
+                    if (!isDuplicate(name, birthday, hash)) {
 
                         // get delta
                         now = new date.Local();
-                        birthday = new date.Local(utc);
                         next = new date.Local(now.getYear(), birthday.getMonth(), birthday.getDate());
                         //add 23h 59min and 59s, so it refers to the end of the day
                         next.add(date.DAY - 1);
@@ -139,11 +150,14 @@ define('plugins/portal/birthdays/register',
                         // get human readable delta
                         days = birthday.getDate() - now.getDate();
                         delta = (next - now) / date.DAY;
-                        delta = days === 0 && delta <= 1 ? gt('Today') : days === 1 && delta <= 2 ? gt('Tomorrow') : gt('In %1$d days', Math.ceil(delta));
+                        delta = days === 0 && delta <= 1 ? gt('Today') : days === 1 && delta <= 2 ? gt('Tomorrow') : days === -1 && delta >= 364 ? gt('Yesterday') : gt('In %1$d days', Math.ceil(delta));
 
                         $list.append(
-                            $('<div class="birthday">').data('contact', contact).append(
-                                api.getPicture(contact, { width: 48, height: 48, scaleType: 'cover' }).addClass('picture'),
+                            $('<div class="birthday" tabindex="1">').data('contact', contact).append(
+                                api.pictureHalo(
+                                    $('<div class="picture">'),
+                                    $.extend(contact, { width: 48, height: 48, scaleType: 'cover' })
+                                ),
                                 $('<div class="name">').text(_.noI18n(name)),
                                 $('<div>').append(
                                     $('<span class="date">').text(_.noI18n(birthday.format(birthday.getYear() === 1 ? date.DATE_NOYEAR : date.DATE))), $.txt(' '),
@@ -151,12 +165,12 @@ define('plugins/portal/birthdays/register',
                                 )
                             )
                         );
-                        markDuplicate(name, hash);
+                        markDuplicate(name, birthday, hash);
                     }
                 });
                 // init sidepopup
                 require(['io.ox/core/tk/dialogs'], function (dialogs) {
-                    sidepopup = sidepopup || new dialogs.SidePopup({ modal: false });
+                    sidepopup = sidepopup || new dialogs.SidePopup({ modal: false, tabTrap: true });
                     sidepopup.delegate($list, '.birthday', function (popup, e, target) {
                         var data = target.data('contact');
                         require(['io.ox/contacts/view-detail'], function (view) {
@@ -172,7 +186,7 @@ define('plugins/portal/birthdays/register',
     });
 
     ext.point('io.ox/portal/widget/birthdays/settings').extend({
-        title: gt('Next birthdays'),
+        title: gt('Birthdays'),
         type: 'birthdays',
         editable: false,
         unique: true
