@@ -76,12 +76,13 @@ define('plugins/portal/facebook/register',
 
         if (!wall || wall.length === 0) {
             content.append(
-                $('<div class="paragraph">').text(gt('No wall posts yet.')));
+                $('<li class="paragraph">').text(gt('No wall posts yet.')));
         } else {
+            wall = wall.slice(0, _.device('smartphone') ? 1 : 10);
             _(wall).each(function (post) {
                 var message = _.ellipsis(post.message || post.description || post.attachment.caption || '', {max: 150});
                 content.append(
-                    $('<div class="paragraph">').append(
+                    $('<li class="paragraph">').append(
                         $('<span class="bold">').text(getProfile(profiles, post.actor_id).name + ': '),
                         $('<span class="normal">').text(message)
                     )
@@ -129,10 +130,6 @@ define('plugins/portal/facebook/register',
             });
         },
 
-        action: function () {
-            window.open('https://www.facebook.com/me', 'facebook');
-        },
-
         isEnabled: function () {
             return keychain.isEnabled('facebook');
         },
@@ -152,7 +149,7 @@ define('plugins/portal/facebook/register',
         },
 
         preview: function (baton) {
-            var content = $('<div class="content">');
+            var content = $('<ul class="content list-unstyled" tabindex="1" role="button "aria-label="' + gt('Press [enter] to jump to the facebook stream.') + '">');
             baton.contentNode = content;
             drawPreview(baton);
             this.append(content);
@@ -253,7 +250,7 @@ define('plugins/portal/facebook/register',
             );
         },
 
-        error: function (error) {
+        error: function (error, baton) {
 
             if (error.code !== 'OAUTH-0006') return; // let the default handling do the job
 
@@ -266,7 +263,7 @@ define('plugins/portal/facebook/register',
                 ),
                 $('<div class="content">').text(gt('Click here to add your account'))
                 .on('click', {}, function () {
-                    ext.point('io.ox/portal/widget/facebook').invoke('performSetUp');
+                    ext.point('io.ox/portal/widget/facebook').invoke('performSetUp', null, baton);
                 })
             );
         }
