@@ -41,10 +41,6 @@ define('plugins/portal/flickr/register',
 
         title: 'Flickr',
 
-        action: function () {
-            window.open('http://www.flickr.com/', 'flickr');
-        },
-
         initialize: function (baton) {
 
             function initFeed() {
@@ -106,7 +102,7 @@ define('plugins/portal/flickr/register',
                     });
                     // use size
                     this.addClass('photo-stream').append(
-                        $('<div class="content pointer">')
+                        $('<div class="content pointer" tabindex="1" role="button" aria-label="' +  gt('Press [enter] to jump to the flicker stream.') + '">')
                         .css('backgroundImage', 'url(' + url + ')')
                         .addClass('decoration')
                     );
