@@ -61,15 +61,15 @@ define('plugins/portal/rss/register',
         preview: function (baton) {
 
             var data = baton.data,
-                count = _.device('small') ? 5 : 10,
-                $content = $('<div class="content pointer">');
+                count = _.device('small') ? 1 : 10,
+                $content = $('<ul class="content pointer list-unstyled" tabindex="1" role="button" aria-label="' + gt('Press [enter] to jump to the rss stream.') + '">');
 
             if (data.items.length === 0) {
-                $('<div class="item">').text(gt('No RSS feeds found.')).appendTo($content);
+                $('<li class="item">').text(gt('No RSS feeds found.')).appendTo($content);
             } else {
                 $(data.items).slice(0, count).each(function (index, entry) {
                     $content.append(
-                        $('<div class="paragraph">').append(
+                        $('<li class="paragraph">').append(
                             function () {
                                 if (data.urls.length > 1) {
                                     return $('<span class="gray">').text(_.noI18n(entry.feedTitle + ' '));
@@ -77,7 +77,7 @@ define('plugins/portal/rss/register',
                                     return '';
                                 }
                             },
-                            $('<span class="bold">').html(_.noI18n(entry.subject)), $.txt('')
+                            $('<span class="bold">').text(_.noI18n(entry.subject)), $.txt('')
                         )
                     );
                 });
@@ -100,7 +100,7 @@ define('plugins/portal/rss/register',
 
                 this.append(
                     $('<div class="text">').append(
-                        $('<h4>').html(_.noI18n(item.subject)),
+                        $('<h4>').text(_.noI18n(item.subject)),
                         $('<div class="text-body noI18n">').append($body),
                         $('<div class="rss-url">').append(
                             $('<a>').attr({ href: item.url, target: '_blank' }).text(_.noI18n(item.feedTitle + ' - ' + publishedDate))
