@@ -201,7 +201,7 @@ define('plugins/portal/twitter/register',
         var content = baton.contentNode;
         if (baton.data.length === 0) {
             content.append(
-                $('<div class="paragraph">').text(gt('No Tweets yet.'))
+                $('<li class="paragraph">').text(gt('No Tweets yet.'))
             );
 
         } else if (baton.data.errors && baton.data.errors.length > 0) {
@@ -213,11 +213,12 @@ define('plugins/portal/twitter/register',
             });
 
         } else {
+            var list = baton.data.slice(0, _.device('smartphone') ? 1 : 10);
             content.addClass('pointer');
-            _(baton.data).each(function (tweet) {
+            _(list).each(function (tweet) {
                 var message = String(tweet.text).replace(/((#|@)[\wäöüß]+)/ig, '<span class="accent">$1</span>');
                 content.append(
-                    $('<div class="paragraph">').append(
+                    $('<li class="paragraph">').append(
                         $('<span class="bold">').text('@' + tweet.user.name + ': '),
                         $('<span class="normal">').html(message)
                     )
@@ -267,9 +268,9 @@ define('plugins/portal/twitter/register',
             });
         },
 
-        action: function () {
-            window.open('https://twitter.com/', 'twitter');
-        },
+        // action: function () {
+        //     window.open('https://twitter.com/', 'twitter');
+        // },
 
         isEnabled: function () {
             return keychain.isEnabled('twitter');
@@ -279,9 +280,13 @@ define('plugins/portal/twitter/register',
             return keychain.isEnabled('twitter') && !keychain.hasStandardAccount('twitter');
         },
 
-        performSetUp: function () {
+        performSetUp: function (baton) {
             var win = window.open(ox.base + '/busy.html', '_blank', 'height=400, width=600');
-            return keychain.createInteractively('twitter', win);
+            return keychain.createInteractively('twitter', win)
+                .then(function () {
+                    baton.model.node.removeClass('requires-setup');
+                    ox.trigger('refresh^');
+                });
         },
 
         load: function (baton) {
@@ -298,7 +303,7 @@ define('plugins/portal/twitter/register',
 
         preview: function (baton) {
             if (!baton.data) { return; }
-            var content = $('<div class="content pointer">');
+            var content = $('<ul class="content pointer list-unstyled" tabindex="1" role="button" aria-label="' +  gt('Press [enter] to jump to the twitter feed.') + '">');
             baton.contentNode = content;
             drawPreview(baton);
             this.append(content);
@@ -370,7 +375,7 @@ define('plugins/portal/twitter/register',
             );
         },
 
-        error: function (error) {
+        error: function (error, baton) {
 
             if (error.code !== 'OAUTH-0006') return; // let the default handling do the job
 
@@ -383,7 +388,7 @@ define('plugins/portal/twitter/register',
                 ),
                 $('<div class="content">').text(gt('Click here to add your account'))
                 .on('click', {}, function () {
-                    ext.point('io.ox/portal/widget/twitter').invoke('performSetUp');
+                    ext.point('io.ox/portal/widget/twitter').invoke('performSetUp', null, baton);
                 })
             );
         }
