@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2013 Open-Xchange Inc., Tarrytown, NY, USA. info@open-xchange.com
  *
  * @author Julian Bäume <julian.baeume@open-xchange.com>
@@ -16,15 +17,17 @@ define(
 
     var testData = {
         create: {
-            "entity": {"folder":"14657"}
+            'entity': {'folder': '14657'}
         }
     };
 
-    describe('publication API', function () {
-        sharedExamplesFor(api.publications, {testData: testData});
-    });
+    describe('Pub/Sub API', function () {
+        describe('publication API', function () {
+            sharedExamplesFor(api.publications, {testData: testData});
+        });
 
-    describe('subscription API', function () {
-        sharedExamplesFor(api.subscriptions, {testData: testData});
+        describe('subscription API', function () {
+            sharedExamplesFor(api.subscriptions, {testData: testData});
+        });
     });
 });
