@@ -15,7 +15,7 @@
 if (jasmine) {
     var objectMatchers = {
             //used to see if a key is present. undefined, null or false do still pass this test
-            hasKey: function (key) {
+            toHaveKey: function (key) {
                 var notText = this.isNot ? ' not' : '';
                 this.message = function () {return 'Expected ' + JSON.stringify(this.actual) + ' to' + notText + ' contain ' + key + ' .'; };
                 return key in this.actual;
