@@ -34,7 +34,6 @@ $(window).load(function () {
     var DURATION = 250,
         // functions
         boot,
-        appCache = $.Deferred(),
         cont,
         cleanUp,
         gotoCore,
@@ -91,17 +90,7 @@ $(window).load(function () {
 
     }
 
-    // check for supported browser
-    function isBrowserSupported() {
-        var supp = false;
-        _.each(_.browserSupport, function(value, key) {
-            if (_.browser[key] >= value) {
-                supp =  true;
-            }
-        });
-        return supp;
-    }
-    window.isBrowserSupported = isBrowserSupported;
+
 
     // continuation
     cont = function () {
@@ -136,6 +125,7 @@ $(window).load(function () {
     }
 
     if (_.device('Android')) {
+        $('html').addClass('android');
         if (_.browser.chrome === 18 || !_.browser.chrome) {
              $('html').addClass('legacy-chrome');
         }
@@ -146,6 +136,14 @@ $(window).load(function () {
         };
     }
 
+    if (_.device('tablet')) {
+        // dismiss dropdown on rotation change due to
+        // positioning issues
+        $(document).on('orientationchange', function () {
+            $('body').trigger('click');
+        });
+    }
+
     // be busy
     $('#background-loader').busy();
 
@@ -569,7 +567,7 @@ $(window).load(function () {
 
         function gotoSignin(hash) {
             var ref = (location.hash || '').replace(/^#/, ''),
-                path = String(ox.serverConfig.logoutLocation || ox.logoutLocation),
+                path = String(ox.serverConfig.loginLocation || ox.loginLocation),
                 glue = path.indexOf('#') > -1 ? '&' : '#';
             path = path.replace("[hostname]", window.location.hostname);
             hash = (hash || '') + (ref ? '&ref=' + enc(ref) : '');
@@ -609,6 +607,7 @@ $(window).load(function () {
                                 document.title = _.noI18n(ox.serverConfig.pageTitle || '') + ' ' + 'Login';
                             } else {
                                 document.title = _.noI18n(ox.serverConfig.pageTitle || '');
+                                $('[name="apple-mobile-web-app-title"]').attr({ content: document.title });
                             }
 
                             themes.set(ox.serverConfig.signinTheme || 'login');
@@ -737,6 +736,7 @@ $(window).load(function () {
                                 // apply session data (again) & page title
                                 session.set(data);
                                 document.title = _.noI18n(ox.serverConfig.pageTitle || '');
+                                $('[name="apple-mobile-web-app-title"]').attr({ content: document.title });
                                 debug('boot.js: autoLogin > loginSuccess > loadCoreFiles ...');
                                 return loadCoreFiles();
                             })
@@ -846,6 +846,14 @@ $(window).load(function () {
             // hide checkbox?
             if (!capabilities.has("autologin")) {
                 $('#io-ox-login-store').remove();
+            } else {
+                // check/uncheck?
+                var box = $('#io-ox-login-store-box'), cookie = _.getCookie('staySignedIn');
+                if (cookie !== undefined) box.prop('checked', cookie === 'true');
+                else if ('staySignedIn' in sc) box.prop('checked', !!sc.staySignedIn);
+                box.on('change', function () {
+                    _.setCookie('staySignedIn', $(this).prop('checked'));
+                });
             }
 
             // hide forgot password?
@@ -869,6 +877,12 @@ $(window).load(function () {
                 $('#io-ox-login-username')[0].type = 'text';
             }
 
+            //show errors saved inlocalstorage
+            if (localStorage.getItem('errormsg')) {
+                feedback('error', $.txt(localStorage.getItem('errormsg')));
+                localStorage.removeItem('errormsg');//remove errormessages from localstorage
+            }
+
             debug('boot.js: Load "signin" plugins & set default language');
 
             // make sure we get 'signin' plugins
@@ -884,7 +898,9 @@ $(window).load(function () {
 
                 // autologout message
                 if (_.url.hash("autologout")) {
-                    feedback('info', $.txt(gt('You have been automatically signed out')));
+                    feedback('info', function () {
+                        return $.txt(gt('You have been automatically signed out'));
+                    });
                 }
 
                 debug('boot.js: Check browser support');
@@ -917,6 +933,14 @@ $(window).load(function () {
                                 .add($('<div>').text(gt('Please update your browser.')));
                         });
 
+                    } else if (_.browser.unknown) {
+                        // warning about all unknown browser-platform combinations, might be chrome on iOS
+                        feedback('info', function () {
+                            return $('<b>').text(gt('Your browser is not supported!'))
+                                .add($.txt(_.noI18n('\xa0')))
+                                //#. Should tell the user that his combination of browser and operating system is not supported
+                                .add($('<div>').text(gt('This browser is not supported on your current platform.')));
+                        });
                     } else {
                         // general warning about browser
                         feedback('info', function () {
@@ -957,10 +981,8 @@ $(window).load(function () {
             });
         };
 
-        appCache.done(function () {
-            // try auto login first
-            autoLogin();
-        });
+        // try auto login first
+        autoLogin();
     }
 
     function loadFail(e) {
@@ -977,43 +999,4 @@ $(window).load(function () {
         'themes', 'io.ox/core/settings'],
         loadSuccess, loadFail
     );
-
-    // reload if files have change; need this during development
-    if (Modernizr.applicationcache && _.browser.chrome && ox.debug && $('html').attr('manifest')) {
-
-        (function () {
-
-            var ac = window.applicationCache, clear, updateReady, cont;
-
-            clear = function () {
-                ac.removeEventListener('cached', cont, false);
-                ac.removeEventListener('noupdate', cont, false);
-                ac.removeEventListener('error', cont, false);
-                ac.removeEventListener('updateready', updateReady, false);
-            };
-
-            updateReady = function () {
-                // if manifest has changed, we have to swap caches and reload
-                if (ac.status === ac.UPDATEREADY) {
-                    clear();
-                    serverUp(); // avoid error
-                    location.reload();
-                }
-            };
-
-            cont = function (e) {
-                clear();
-                debug('boot.js: applicationcache > resolve');
-                appCache.resolve();
-            };
-
-            ac.addEventListener('cached', cont, false);
-            ac.addEventListener('noupdate', cont, false);
-            ac.addEventListener('error', cont, false);
-            ac.addEventListener('updateready', updateReady, false);
-
-        }());
-    } else {
-        appCache.resolve();
-    }
 });
