@@ -213,13 +213,28 @@
                            "url($1" + path);
     }
 
-    function insert(name, css, selector, node) {
+    var concatCSS = {}, nodes = {};
+
+    function insertCommon(name, css, selector, node) {
         if (node) return node.text(css);
-        return $('<style type="text/css">' + css + '</style>')
+        return $('<style type="text/css">').text(css)
             .attr("data-require-src", name)
             .insertBefore(selector);
     }
 
+    function insertIE9(name, css, selector, node) {
+        if (node) return node.text(css);
+        // need new node?
+        if (!nodes[selector]) nodes[selector] = $('<style type="text/css">').insertBefore(selector);
+        if (!concatCSS[selector]) concatCSS[selector] = '';
+        // append css
+        concatCSS[selector] += '/* ' + name + ' */\n\n' + css + '\n\n';
+        // update
+        return nodes[selector].text(concatCSS[selector]);
+    }
+
+    var insert = _.device('IE === 9') ? insertIE9 : insertCommon;
+
     // Replace the load function of RequireJS with our own, which fetches
     // dynamically concatenated files.
     (function () {
@@ -234,7 +249,7 @@
         req.load = function (context, modulename, url) {
             var prefix = context.config.baseUrl;
             if (modulename.slice(0, 5) === 'apps/') {
-                url = ox.apiRoot + '/apps/load/' + ox.base + ',' + url.slice(5);
+                url = ox.apiRoot + '/apps/load/' + ox.version + ',' + url.slice(5);
                 return oldload.apply(this, arguments);
             } else if (modulename.charAt(0) !== '/') {
                 if (url.slice(0, prefix.length) !== prefix) {
@@ -257,7 +272,7 @@
             }
             if (_.url.hash('debug-js')) {
                 oldload(context, modulename,
-                    [ox.apiRoot, '/apps/load/', ox.base, ',', url].join(''));
+                    [ox.apiRoot, '/apps/load/', ox.version, ',', url].join(''));
                 return;
             }
 
@@ -293,9 +308,9 @@
             );
 
             function load(module, modulename) {
-                 $.ajax({ url: [ox.apiRoot, '/apps/load/', ox.base, ',', module].join(''), dataType: "text" })
+                 $.ajax({ url: [ox.apiRoot, '/apps/load/', ox.version, ',', module].join(''), dataType: "text" })
                  .done(function (concatenatedText) {
-                        runCode([ox.apiRoot, '/apps/load/', ox.base, ',', module].join(''), concatenatedText);
+                        runCode([ox.apiRoot, '/apps/load/', ox.version, ',', module].join(''), concatenatedText);
                         context.completeLoad(modulename);
                         // Chop up the concatenated modules and put them into file cache
                         _(concatenatedText.split("/*:oxsep:*/")).each(function (moduleText) {
